@@ -1,6 +1,6 @@
 /*
 
- $Id: ar.cpp,v 1.1.2.1 2002/06/13 00:29:00 helio Exp $
+ $Id: ar.cpp,v 1.2.2.1 2003/01/13 10:32:43 helio Exp $
 
  ark -- archiver for the KDE project
 
@@ -34,7 +34,7 @@
 #include <string.h>
 
 // QT includes
-#include <qfile.h>
+#include <qdir.h>
 
 // KDE includes
 #include <kdebug.h>
@@ -44,7 +44,6 @@
 
 // ark includes
 #include "arkwidgetbase.h"
-#include "arch.h"
 #include "arksettings.h"
 #include "ar.h"
 
@@ -100,7 +99,7 @@ void ArArch::open()
   m_buffer = "";
 
   KProcess *kp = new KProcess;
-  *kp << m_archiver_program << "vt" << m_filename.local8Bit();
+  *kp << m_archiver_program << "vt" << m_filename;
   connect( kp, SIGNAL(receivedStdout(KProcess*, char*, int)),
 	   this, SLOT(slotReceivedTOC(KProcess*, char*, int)));
   connect( kp, SIGNAL(receivedStderr(KProcess*, char*, int)),
@@ -121,7 +120,7 @@ void ArArch::create()
 {
   KProcess *kp = new KProcess;
   kp->clearArguments();
-  *kp << m_archiver_program << "c" << m_filename.local8Bit();
+  *kp << m_archiver_program << "c" << m_filename;
 
   connect( kp, SIGNAL(receivedStdout(KProcess*, char*, int)),
 	   this, SLOT(slotReceivedOutput(KProcess*, char*, int)));
@@ -151,7 +150,7 @@ void ArArch::addFile( QStringList *urls )
   if (m_settings->getAddReplaceOnlyWithNewer())
     *kp << "u";
 
-  *kp << m_filename.local8Bit() ;
+  *kp << m_filename;
 
   QString base;
   QString url;
@@ -174,7 +173,7 @@ void ArArch::addFile( QStringList *urls )
       pos = file.findRev( '/' );
       base = file.left( pos );
       pos++;
-      chdir( QFile::encodeName(base) );
+      QDir::setCurrent(base);
       base = file.right( file.length()-pos );
       file = base;
     }
@@ -216,9 +215,9 @@ void ArArch::unarchFile(QStringList *_fileList, const QString & _destDir,
   // ar has no option to specify the destination directory
   // so I have to change to it.
 
-  int ret = chdir(QFile::encodeName(dest));
+  bool ret = QDir::setCurrent(dest);
  // I already checked the validity of the dir before coming here
-  Q_ASSERT(ret == 0); 
+  Q_ASSERT(ret); 
 
   KProcess *kp = new KProcess;
   kp->clearArguments();
@@ -234,7 +233,7 @@ void ArArch::unarchFile(QStringList *_fileList, const QString & _destDir,
       for ( QStringList::Iterator it = _fileList->begin();
 	    it != _fileList->end(); ++it ) 
 	{
-	  *kp << (*it).local8Bit() ;
+	  *kp << (*it);
 	}
     }
  
@@ -264,12 +263,12 @@ void ArArch::remove(QStringList *list)
   KProcess *kp = new KProcess;
   kp->clearArguments();
   
-  *kp << m_archiver_program << "d" << m_filename.local8Bit();
+  *kp << m_archiver_program << "d" << m_filename;
   for ( QStringList::Iterator it = list->begin();
 	it != list->end(); ++it )
     {
       QString str = *it;
-      *kp << str.local8Bit();
+      *kp << str;
     }
 
   connect( kp, SIGNAL(receivedStdout(KProcess*, char*, int)),
