@@ -1,7 +1,4 @@
 /*
-
-  $Id: compressedfile.cpp,v 1.2.2.1 2002/06/13 00:29:01 helio Exp $
-
     ark: A program for modifying archives via a GUI.
 
     Copyright (C)
@@ -28,6 +25,7 @@
 // C includes
 #include <unistd.h>
 #include <stdlib.h>
+#include <fcntl.h>
 
 // Qt includes
 #include <qdir.h>
@@ -40,9 +38,8 @@
 #include <kprocess.h>
 
 // ark includes
-#include "arch.h"
-#include "arksettings.h"
 #include "arkwidgetbase.h"
+#include "arksettings.h"
 #include "compressedfile.h"
 
 // encapsulates the idea of a compressed file
@@ -53,12 +50,21 @@ CompressedFile::CompressedFile( ArkSettings *_settings, ArkWidgetBase *_gui,
 {
   kdDebug(1601) << "CompressedFile constructor" << endl;
   QString directory;
-  directory.sprintf("ark.%d/", getpid());
-  m_tmpdir = locateLocal( "tmp", directory );
-  //m_tmpdir.sprintf("/tmp/ark.%d", getpid());
+  m_tmpdir = _settings->getTmpDir();
   m_archiver_program = getCompressor();
   m_unarchiver_program = getUnCompressor();
   verifyUtilityIsAvailable(m_archiver_program, m_unarchiver_program);
+
+  if (!QFile::exists(_fileName))
+    {
+      KMessageBox::information(0,
+			       i18n("You are creating a simple compressed archive which contains only one input file.\n"
+				    "When uncompressed, the file name will be based on the name of the archive file.\n"
+				    "If you add more files you will be prompted to convert it to a real archive."),
+			       i18n("Simple Compressed Archive"),
+			       "CreatingCompressedArchive"
+			       );
+    }
 }
 
 void CompressedFile::setHeaders()
@@ -126,9 +132,9 @@ void CompressedFile::open()
   // and when the uncompression is done, obtain an ls -l of it
   // (that code is in the slot slotOpenDone)
 
-  QString command;
-  command = "cp '" + m_filename + "' " + m_tmpdir;
-  system(QFile::encodeName(command));
+  KProcess proc;
+  proc << "cp" << m_filename << m_tmpdir;
+  proc.start(KProcess::Block);
 
   m_tmpfile = m_filename.right(m_filename.length()
 			       - m_filename.findRev("/")-1);
@@ -188,17 +194,17 @@ void CompressedFile::slotUncompressDone(KProcess *_kp)
       // now do the ls -l. Just a simple system() call
       m_tmpfile = m_tmpfile.left(m_tmpfile.findRev("."));
       kdDebug(1601) << "Temp file is " << m_tmpfile << endl;
-      chdir(QFile::encodeName(m_tmpdir));
+      QDir::setCurrent(m_tmpdir);
       QString command = "ls -l " +
-	m_tmpfile.right(m_tmpfile.length() - 1 - m_tmpfile.findRev("/"));
+	KProcess::quote(m_tmpfile.right(m_tmpfile.length() - 1 - m_tmpfile.findRev("/")));
 
       char line[4096];
       char columns[7][80];
       char filename[4096];
 
       FILE *readHandle = popen(QFile::encodeName(command), "r");
-      fscanf(readHandle, "%[-A-Za-z:0-9_+-. ]", line);
-      sscanf(line, "%[-drwxst] %[0-9] %[0-9.a-zA-Z_] %[0-9.a-zA-Z_] %[0-9] %12[A-Za-z0-9: ]%1[ ]%[^\n]", columns[0], columns[5],
+      fscanf(readHandle, "%4095[-A-Za-z:0-9_+-. ]", line);
+      sscanf(line, "%79[-drwxst] %79[0-9] %79[0-9.a-zA-Z_] %79[0-9.a-zA-Z_] %79[0-9] %12[A-Za-z0-9: ]%1[ ]%79[^\n]", columns[0], columns[5],
 	     columns[1], columns[2], columns[3],
 	     columns[4], columns[6], filename);
 
@@ -244,9 +250,9 @@ void CompressedFile::addFile( QStringList *urls )
   if (file.left(5) == "file:")
     file = file.right(file.length() - 5);
 
-  QString command;
-  command = "cp '" + file + "' " + m_tmpdir;
-  system(QFile::encodeName(command));
+  KProcess proc;
+  proc << "cp" << file << m_tmpdir;
+  proc.start(KProcess::Block);
 
   m_tmpfile = file.right(file.length()
 			 - file.findRev("/")-1);
@@ -260,7 +266,7 @@ void CompressedFile::addFile( QStringList *urls )
   kp->clearArguments();
   QString compressor = m_archiver_program;
 
-  *kp << compressor << "-c" << file.local8Bit();
+  *kp << compressor << "-c" << file;
 
   connect( kp, SIGNAL(receivedStdout(KProcess*, char*, int)),
 	   this, SLOT(slotAddInProgress(KProcess*, char*, int)));
@@ -269,7 +275,7 @@ void CompressedFile::addFile( QStringList *urls )
   connect( kp, SIGNAL(processExited(KProcess*)), this,
 	   SLOT(slotAddDone(KProcess*)));
 
-  fd = fopen( m_filename.local8Bit(), "w" );
+  fd = fopen( QFile::encodeName(m_filename), "w" );
 
   if (kp->start(KProcess::NotifyOnExit, KProcess::AllOutput) == false)
     {
@@ -312,9 +318,10 @@ void CompressedFile::unarchFile(QStringList *, const QString & _destDir,
 	}
       else
 	dest=_destDir;
-      QString command;
-      command = QString::fromLocal8Bit("cp %1 %2").arg(m_tmpfile).arg(dest);
-      system(QFile::encodeName(command));
+
+      KProcess proc;
+      proc << "cp" << m_tmpfile << dest;
+      proc.start(KProcess::Block);
     }
   emit sigExtract(true);
 }
@@ -322,13 +329,13 @@ void CompressedFile::unarchFile(QStringList *, const QString & _destDir,
 void CompressedFile::remove(QStringList *)
 {
   kdDebug(1601) << "+CompressedFile::remove" << endl;
-  unlink(QFile::encodeName(m_tmpfile));
+  QFile::remove(m_tmpfile);
 
   // delete the compressed file but then create it empty in case someone
   // does a reload and finds it no longer exists!
-  unlink(QFile::encodeName(m_filename));
-  QString command = "touch '" + m_filename + "'";
-  system(QFile::encodeName(command));
+  QFile::remove(m_filename);
+  
+  ::close(::open(QFile::encodeName(m_filename), O_WRONLY | O_CREAT | O_EXCL));
 
   m_tmpfile = "";
   emit sigDelete(true);
