@@ -1,7 +1,7 @@
 //  -*-C++-*-           emacs magic for .h files
 /*
 
- $Id: filelistview.h,v 1.14.4.2 2002/06/13 00:29:01 helio Exp $
+ $Id: filelistview.h,v 1.15.2.1 2003/01/13 10:32:44 helio Exp $
 
   ark -- archiver for the KDE project
 
@@ -30,6 +30,8 @@
 #define FILELISTVIEW_H
 
 #include <qlistview.h>
+#include <qdatetime.h>
+
 #include <klistview.h>
 
 class QString;
@@ -49,15 +51,21 @@ class FileListView;
 class FileLVI : public KListViewItem
 {
 public:
-  FileLVI(KListView* lv) : KListViewItem(lv), parent(lv) {}
+  FileLVI(KListView* lv);
+
+  QString fileName() const;
+  long fileSize() const;
+  QDateTime timeStamp() const;
 
-  QString getFileName() const;
   virtual QString key(int column, bool) const;
-	virtual void setText(int column, const QString &text);
+  virtual void setText(int column, const QString &text);
 
 private:
-  KListView *parent;
-  bool fileIndent;	
+  bool fileIndent;
+  long m_fileSize;
+  long m_packedFileSize;
+  double m_ratio;
+  QDateTime m_timeStamp;
 };
 
 
