@@ -1,6 +1,6 @@
 /*
 
- $Id: generalOptDlg.cpp,v 1.11.2.1 2002/06/13 00:29:01 helio Exp $
+ $Id: generalOptDlg.cpp,v 1.14.2.1 2003/01/13 10:32:44 helio Exp $
 
  ark -- archiver for the KDE project
 
@@ -28,7 +28,6 @@
 */
 
 // Qt includes
-#include <qvbox.h>
 #include <qlayout.h>
 #include <qgroupbox.h>
 #include <qcheckbox.h>
@@ -43,17 +42,17 @@
 #include "generalOptDlg.h"
 
 #define DLG_NAME i18n("Settings")
-#define TAB_ADD_NAME i18n("&Adding")
+#define TAB_ADD_NAME i18n("Addi&ng")
 #define TAB_EXTRACT_NAME i18n("&Extracting")
 #define TAB_PATH_NAME i18n("&Directories")
 
 #define GRP_ADDSET i18n("Add Settings")
 #define GRP_EXTRACTSET i18n("Extract Settings")
 
-#define OPT_REPLACE_NEWER i18n("Replace &old files only with newer files")
+#define OPT_REPLACE_NEWER i18n("Replace old files only &with newer files")
 #define OPT_MAKEGENERIC i18n("Keep entries &generic (Lha)")
 #define OPT_DOS_FILENAMES i18n("Force &MS-DOS short filenames (Zip)")
-#define OPT_CONV_CRLF i18n("Tranlate LF to DOS &CRLF (Zip)")
+#define OPT_CONV_CRLF i18n("Translate &LF to DOS CRLF (Zip)")
 #define OPT_RECURSE_SUBDIRS i18n("&Recursively add subdirectories (Zip, Rar)")
 #define OPT_STORE_SYMLINKS i18n("&Store symlinks as links (Zip, Rar)")
 
@@ -77,15 +76,15 @@ GeneralOptDlg::GeneralOptDlg(ArkSettings *_d, QWidget *_parent, const char *_nam
     m_settings = _d;
     QFrame *frame;
     
-    frame = addPage( i18n( "Addition" ), i18n( "File addition settings" ),
+    frame = addPage( i18n( "Addition" ), i18n( "File Addition Settings" ),
                      loadIcon( "ark_addfile" ) );
     createAddTab( frame );
     
-    frame = addPage( i18n( "Extraction" ), i18n( "Extraction settings" ),
+    frame = addPage( i18n( "Extraction" ), i18n( "Extraction Settings" ),
                      loadIcon( "ark_extract" ) );
     createExtractTab( frame );
     
-    frame = addPage( i18n( "Directories" ), i18n( "Directory settings" ),
+    frame = addPage( i18n( "Directories" ), i18n( "Directory Settings" ),
                      loadIcon( "folder" ) );
     createDirectoryTab( frame );	
 }
