@@ -1,6 +1,6 @@
 /*
 
- $Id: lha.cpp,v 1.1.2.1 2002/06/13 00:29:01 helio Exp $
+ $Id: lha.cpp,v 1.5.2.3 2003/01/13 10:32:44 helio Exp $
 
  ark -- archiver for the KDE project
 
@@ -27,8 +27,9 @@
 
 */
 
+#include <config.h>
+
 // C includes
-#include <iostream.h>
 #include <stdio.h>
 #include <unistd.h>
 #include <stdlib.h>
@@ -37,6 +38,7 @@
 
 // QT includes
 #include <qfile.h>
+#include <qdir.h>
 
 // KDE includes
 #include <kdebug.h>
@@ -49,6 +51,7 @@
 #include "arksettings.h"
 #include "arch.h"
 #include "lha.h"
+#include "arkutils.h"
 
 LhaArch::LhaArch( ArkSettings *_settings, ArkWidgetBase *_gui,
 		  const QString & _fileName )
@@ -68,18 +71,18 @@ bool LhaArch::processLine(const QCString &line)
   char columns[13][80];
   char filename[4096];
 
-  if (QString(_line).contains("[generic]") ) 
+  if (QCString(_line).contains("[generic]") )
     {
-      sscanf(_line, " %[]\[generic] %[0-9] %[0-9] %[0-9.%*] %10[-a-z0-9 ] %3[A-Za-z]%1[ ]%2[0-9 ]%1[ ]%5[ 0-9:]%1[ ]%[^\n]",
+      sscanf(_line, " %79[]\\[generic] %79[0-9] %79[0-9] %79[0-9.%*] %10[-a-z0-9 ] %3[A-Za-z]%1[ ]%2[0-9 ]%1[ ]%5[ 0-9:]%1[ ]%4095[^\n]",
 	     columns[0], columns[2], columns[3], columns[4], columns[5],
 	     columns[6], columns[10], columns[7], columns[11], columns[8],
 	     columns[9], filename );
       strcpy( columns[1], " " );
     }
   else
-  if (QString(_line).contains("[MS-DOS]") ) 
+  if (QCString(_line).contains("[MS-DOS]") )
     {
-      sscanf(_line, " %[]\[MS-DOS] %[0-9] %[0-9] %[0-9.%*] %10[-a-z0-9 ] %3[A-Za-z]%1[ ]%2[0-9 ]%1[ ]%5[ 0-9:]%1[ ]%[^\n]",
+      sscanf(_line, " %79[]\\[MS-DOS] %79[0-9] %79[0-9] %79[0-9.%*] %10[-a-z0-9 ] %3[A-Za-z]%1[ ]%2[0-9 ]%1[ ]%5[ 0-9:]%1[ ]%4095[^\n]",
 	     columns[0], columns[2], columns[3], columns[4], columns[5],
 	     columns[6], columns[10], columns[7], columns[11], columns[8],
 	     columns[9], filename );
@@ -87,7 +90,7 @@ bool LhaArch::processLine(const QCString &line)
     }
   else
     {
-      sscanf(_line, " %[-drlwxst] %[0-9/] %[0-9] %[0-9] %[0-9.%*] %10[-a-z0-9 ] %3[A-Za-z]%1[ ]%2[0-9 ]%1[ ]%5[ 0-9:]%1[ ]%[^\n]",
+      sscanf(_line, " %79[-drlwxst] %79[0-9/] %79[0-9] %79[0-9] %79[0-9.%*] %10[-a-z0-9 ] %3[A-Za-z]%1[ ]%2[0-9 ]%1[ ]%5[ 0-9:]%1[ ]%4095[^\n]",
 	     columns[0], columns[1], columns[2], columns[3],
 	     columns[4], columns[5], columns[6], columns[10], columns[7],
 	     columns[11], columns[8], columns[9], filename);
@@ -96,9 +99,9 @@ bool LhaArch::processLine(const QCString &line)
   kdDebug(1601) << "The actual file is " << (const char *)filename << endl;
 
   // make the time stamp sortable
-  QString massagedTimeStamp = Utils::getTimeStamp(columns[6], columns[7],
+  QString massagedTimeStamp = ArkUtils::getTimeStamp(columns[6], columns[7],
 						  columns[8]);
-  strcpy(columns[6], massagedTimeStamp.ascii());
+  strlcpy(columns[6], massagedTimeStamp.ascii(), sizeof(columns[6]));
 
   kdDebug(1601) << "New timestamp is " << columns[6] << endl;
 
@@ -118,13 +121,14 @@ bool LhaArch::processLine(const QCString &line)
     name = file;
 
   QStringList list;
-  list.append(name.local8Bit());
+  list.append(name);
+  kdDebug(1601) << "Added file " << name << endl;
   for (int i=0; i<7; i++)
     {
       list.append(QString::fromLocal8Bit(columns[i]));
     }
   if (bLink)
-    list.append(link.local8Bit());
+    list.append(link);
   else
     list.append("");
 
@@ -144,7 +148,7 @@ void LhaArch::open()
 
 
   KProcess *kp = new KProcess;
-  *kp << m_archiver_program << "v" << m_filename.local8Bit();
+  *kp << m_archiver_program << "v" << m_filename;
   connect( kp, SIGNAL(receivedStdout(KProcess*, char*, int)),
 	   this, SLOT(slotReceivedTOC(KProcess*, char*, int)));
   connect( kp, SIGNAL(receivedStderr(KProcess*, char*, int)),
@@ -181,7 +185,7 @@ void LhaArch::setHeaders()
   alignRightCols[0] = 3;
   alignRightCols[1] = 4;
   alignRightCols[2] = 5;
-  
+
   m_gui->setHeaders(&list, alignRightCols, 3);
   delete [] alignRightCols;
 
@@ -192,7 +196,7 @@ void LhaArch::setHeaders()
 void LhaArch::create()
 {
   emit sigCreate(this, true, m_filename,
-		 Arch::Extract | Arch::Delete | Arch::Add 
+		 Arch::Extract | Arch::Delete | Arch::Add
 		 | Arch::View);
 }
 
@@ -212,7 +216,7 @@ void LhaArch::addFile( QStringList *urls )
   KProcess *kp = new KProcess;
   kp->clearArguments();
   *kp << m_archiver_program;
-	
+
   QString strOptions;
   if (m_settings->getAddReplaceOnlyWithNewer())
     strOptions = "u";
@@ -221,13 +225,13 @@ void LhaArch::addFile( QStringList *urls )
   if (m_settings->getLhaGeneric())
     strOptions += "g";
 
-  *kp << strOptions << m_filename.local8Bit() ;
+  *kp << strOptions << m_filename;
 
   QString base;
   QString url;
   QString file;
 
-	
+
   QStringList::ConstIterator iter;
   for (iter = urls->begin(); iter != urls->end(); ++iter )
   {
@@ -244,7 +248,7 @@ void LhaArch::addFile( QStringList *urls )
       pos = file.findRev( '/' );
       base = file.left( pos );
       pos++;
-      chdir( QFile::encodeName(base) );
+      QDir::setCurrent(base);
       base = file.right( file.length()-pos );
       file = base;
     }
@@ -284,23 +288,23 @@ void LhaArch::unarchFile(QStringList *_fileList, const QString & _destDir,
   else dest = _destDir;
 
   QString tmp;
-	
+
   KProcess *kp = new KProcess;
   kp->clearArguments();
-  
+
   *kp << m_archiver_program << "xfw="+dest << m_filename;
-  
+
   // if the list is empty, no filenames go on the command line,
   // and we then extract everything in the archive.
   if (_fileList)
     {
       for ( QStringList::Iterator it = _fileList->begin();
-	    it != _fileList->end(); ++it ) 
+	    it != _fileList->end(); ++it )
 	{
-	  *kp << (*it).local8Bit() ;
+	  *kp << (*it);
 	}
     }
- 
+
   connect( kp, SIGNAL(receivedStdout(KProcess*, char*, int)),
 	   this, SLOT(slotReceivedOutput(KProcess*, char*, int)));
   connect( kp, SIGNAL(receivedStderr(KProcess*, char*, int)),
@@ -308,7 +312,7 @@ void LhaArch::unarchFile(QStringList *_fileList, const QString & _destDir,
 
   connect( kp, SIGNAL(processExited(KProcess*)), this,
 	   SLOT(slotExtractExited(KProcess*)));
-  
+
   if (kp->start(KProcess::NotifyOnExit, KProcess::AllOutput) == false)
     {
       KMessageBox::error( 0, i18n("Couldn't start a subprocess.") );
@@ -326,13 +330,13 @@ void LhaArch::remove(QStringList *list)
   m_shellErrorData = "";
   KProcess *kp = new KProcess;
   kp->clearArguments();
-  
-  *kp << m_archiver_program << "df" << m_filename.local8Bit();
+
+  *kp << m_archiver_program << "df" << m_filename;
   for ( QStringList::Iterator it = list->begin();
 	it != list->end(); ++it )
     {
       QString str = *it;
-      *kp << str.local8Bit();
+      *kp << str;
     }
 
   connect( kp, SIGNAL(receivedStdout(KProcess*, char*, int)),
@@ -348,7 +352,7 @@ void LhaArch::remove(QStringList *list)
       KMessageBox::error( 0, i18n("Couldn't start a subprocess.") );
       emit sigDelete(false);
     }
-  
+
   kdDebug(1601) << "-LhaArch::remove" << endl;
 }
 
