@@ -1,6 +1,6 @@
 /*
 
- $Id: rar.cpp,v 1.1.2.1 2002/06/13 00:29:01 helio Exp $
+ $Id: rar.cpp,v 1.3.2.3 2003/01/13 10:32:44 helio Exp $
 
  ark -- archiver for the KDE project
 
@@ -24,6 +24,8 @@
 
 */
 
+#include <config.h>
+
 #include <stdio.h>
 #include <unistd.h>
 #include <stdlib.h>
@@ -31,6 +33,7 @@
 #include <string.h>
 
 #include <qfile.h>
+#include <qdir.h>
 
 // KDE includes
 #include <kdebug.h>
@@ -43,6 +46,7 @@
 #include "arch.h"
 #include "arksettings.h"
 #include "rar.h"
+#include "arkutils.h"
 
 RarArch::RarArch( ArkSettings *_settings, ArkWidgetBase *_gui,
 		  const QString & _fileName )
@@ -83,8 +87,8 @@ bool RarArch::processLine(const QCString &line)
 
   char columns[11][80];
   char filename[4096];
-  sscanf(QFile::encodeName(m_line1), " %[^\n]", filename);
-  sscanf((const char *)m_line2.ascii(), " %[0-9] %[0-9] %[0-9%<>-] %2[0-9]-%2[0-9]-%2[0-9] %5[0-9:] %[drwxlst-] %[A-F0-9] %[A-Za-z0-9] %[0-9.]",
+  sscanf(QFile::encodeName(m_line1), " %4095[^\n]", filename);
+  sscanf((const char *)m_line2.ascii(), " %79[0-9] %79[0-9] %79[0-9%<>-] %2[0-9]-%2[0-9]-%2[0-9] %5[0-9:] %79[drwxlst-] %79[A-F0-9] %79[A-Za-z0-9] %79[0-9.]",
 	 columns[0], columns[1], columns[2], columns[3],
 	 columns[8], columns[9], columns[10],
 	 columns[4], columns[5], columns[6],
@@ -95,7 +99,7 @@ bool RarArch::processLine(const QCString &line)
   // columns[8] is the month
   // columns[9] is a 2-digit year. Ugh. Y2K junk here.
   
-  QString year = Utils::fixYear(columns[9]);
+  QString year = ArkUtils::fixYear(columns[9]);
 
   // put entire timestamp in columns[3]
 
@@ -105,12 +109,12 @@ bool RarArch::processLine(const QCString &line)
 
   kdDebug(1601) << "Year is: " << year << "; Month is: " << columns[8] << "; Day is: " << columns[3] << "; Time is: " << columns[10] << endl;
 
-  strcpy(columns[3], timestamp.ascii());
+  strlcpy(columns[3], timestamp.ascii(), sizeof(columns[3]));
 
   kdDebug(1601) << "The actual file is " << filename << endl;
 
   QStringList list;
-  list.append(QString::fromLocal8Bit(filename));
+  list.append(QFile::decodeName(filename));
   for (int i=0; i<8; i++)
     {
       list.append(QString::fromLocal8Bit(columns[i]));
@@ -131,7 +135,7 @@ void RarArch::open()
   
   
   KProcess *kp = new KProcess;
-  *kp << m_archiver_program << "vt" << m_filename.local8Bit();
+  *kp << m_archiver_program << "vt" << m_filename;
   connect( kp, SIGNAL(receivedStdout(KProcess*, char*, int)),
 	   this, SLOT(slotReceivedTOC(KProcess*, char*, int)));
   connect( kp, SIGNAL(receivedStderr(KProcess*, char*, int)),
@@ -209,7 +213,7 @@ void RarArch::addFile( QStringList *urls )
   if (m_settings->getRarRecurseSubdirs())
     *kp << "-r";
 
-  *kp << m_filename.local8Bit() ;
+  *kp << m_filename;
 
   QString base;
   QString url;
@@ -232,7 +236,7 @@ void RarArch::addFile( QStringList *urls )
       pos = file.findRev( '/' );
       base = file.left( pos );
       pos++;
-      chdir( QFile::encodeName(base) );
+      QDir::setCurrent(base);
       base = file.right( file.length()-pos );
       file = base;
     }
@@ -293,7 +297,7 @@ void RarArch::unarchFile(QStringList *_fileList, const QString & _destDir,
   }
 #endif
 
-  *kp << m_filename.local8Bit();
+  *kp << m_filename;
 
   // if the file list is empty, no filenames go on the command line,
   // and we then extract everything in the archive.
@@ -302,7 +306,7 @@ void RarArch::unarchFile(QStringList *_fileList, const QString & _destDir,
       for ( QStringList::Iterator it = _fileList->begin();
 	    it != _fileList->end(); ++it ) 
 	{
-	  *kp << (*it).local8Bit();/*.latin1() ;*/
+	  *kp << (*it);/*.latin1() ;*/
 	}
     }
 
@@ -334,12 +338,12 @@ void RarArch::remove(QStringList *list)
   KProcess *kp = new KProcess;
   kp->clearArguments();
   
-  *kp << m_archiver_program << "d" << m_filename.local8Bit();
+  *kp << m_archiver_program << "d" << m_filename;
   for ( QStringList::Iterator it = list->begin();
 	it != list->end(); ++it )
     {
       QString str = *it;
-      *kp << str.local8Bit();
+      *kp << str;
     }
 
   connect( kp, SIGNAL(receivedStdout(KProcess*, char*, int)),
