@@ -1,5 +1,5 @@
 /*
-    $Id: dlabel.cpp,v 1.5 2001/10/19 03:23:22 teran Exp $
+    $Id: dlabel.cpp,v 1.6 2002/05/22 01:05:19 teran Exp $
 
     KCalc, a scientific calculator for the X window system using the
     Qt widget libraries, available at no cost at http://www.troll.no
@@ -41,17 +41,13 @@ DLabel::DLabel(QWidget *parent, const char *name)
 //-------------------------------------------------------------------------
 void DLabel::mousePressEvent(QMouseEvent *e)
 {
-	if(e->button() == LeftButton)
-	{
+	if(e->button() == LeftButton) {
 		lit = !lit;
 		button = LeftButton;
-	}
-	else
-	{
+	} else {
 		button = MidButton;
 	}
-
-
+	
 	emit clicked();
 }
 
