@@ -1,5 +1,5 @@
 /*
-    $Id: kcalc.cpp,v 1.63 2002/03/19 15:09:01 mlaurent Exp $
+    $Id: kcalc.cpp,v 1.75.2.1 2002/12/16 09:33:05 waba Exp $
 
     kCalculator, a simple scientific calculator for KDE
 
@@ -31,22 +31,14 @@
 
 #include <qlayout.h>
 #include <qobjectlist.h>
-
 #include <qaccel.h>
 #include <qbuttongroup.h>
-#include <qcheckbox.h>
 #include <qclipboard.h>
-#include <qfont.h>
 #include <qgroupbox.h>
 #include <qlabel.h>
-#include <qptrlist.h>
-#include <qlistbox.h>
-#include <qpixmap.h>
-#include <qpushbutton.h>
 #include <qradiobutton.h>
 #include <qtimer.h>
 #include <qtooltip.h>
-#include <qwidget.h>
 #include <qstyle.h>
 
 #include <kapplication.h>
@@ -58,8 +50,9 @@
 #include <kcmdlineargs.h>
 #include <knotifyclient.h>
 #include <kaboutdata.h>
-
-#include <qfont.h>
+#include <khelpmenu.h>
+#include <kpushbutton.h>
+#include <kpopupmenu.h>
 
 #include "dlabel.h"
 #include "kcalc.h"
@@ -91,14 +84,12 @@ extern bool				display_error;
 // Name: QtCalculator(QWidget *parent, const char *name)
 //-------------------------------------------------------------------------
 QtCalculator::QtCalculator(QWidget *parent, const char *name)
-	: KDialog(parent, name),
-	inverse(false), hyp_mode(false), eestate(false), refresh_display(false),
-	display_size(DEC_SIZE), angle_mode(ANG_DEGREE), input_limit(0),
-	input_count(0), decimal_point(0), precedence_base(0),
-	current_base(NB_DECIMAL), memory_num(0.0), history_index(0),
-	selection_timer(new QTimer), key_pressed(false),
-        mInternalSpacing(4), status_timer(new QTimer), mConfigureDialog(0),
-	last_input(DIGIT)
+	: KDialog(parent, name), inverse(false), hyp_mode(false), eestate(false), 
+	refresh_display(false), display_size(DEC_SIZE),  angle_mode(ANG_DEGREE), 
+	input_limit(0), input_count(0), decimal_point(0), precedence_base(0),
+	current_base(NB_DECIMAL), memory_num(0.0), last_input(DIGIT), 
+	history_index(0), selection_timer(new QTimer), key_pressed(false),
+	mInternalSpacing(4), status_timer(new QTimer), mConfigureDialog(0)
 {
 	// make sure the display_str is NULL terminated so we can
 	// user library string functions
@@ -121,14 +112,19 @@ QtCalculator::QtCalculator(QWidget *parent, const char *name)
 	accel->connectItem(accel->insertItem(Key_X+CTRL), this, SLOT(quitCalc()));
 
 	// Create uppermost bar with buttons and numberdisplay
-	mConfigButton = new QPushButton(i18n("Configure"), this, "configbutton");
+	mConfigButton = new KPushButton(KGuiItem( i18n("Config&ure"), "configure" ),
+            this, "configbutton");
 	mConfigButton->setAutoDefault(false);
 	QToolTip::add(mConfigButton, i18n("Click to configure KCalc"));
 	connect(mConfigButton, SIGNAL(clicked()), this, SLOT(configclicked()));
+	if (KGlobal::config()->isImmutable())
+	   mConfigButton->hide();
 
-	mHelpButton = new QPushButton("?", this, "helpbutton");
+	mHelpMenu = new KHelpMenu(this, KGlobal::instance()->aboutData());
+
+	mHelpButton = new KPushButton(KStdGuiItem::help(), this);
 	mHelpButton->setAutoDefault(false);
-	connect(mHelpButton, SIGNAL(clicked()), this, SLOT(helpclicked()));
+	mHelpButton->setPopup(mHelpMenu->menu());
 
 	calc_display = new DLabel(this, "display");
 	calc_display->setFrameStyle(QFrame::WinPanel | QFrame::Sunken);
@@ -155,53 +151,60 @@ QtCalculator::QtCalculator(QWidget *parent, const char *name)
 	statusERRORLabel->setFrameStyle(QFrame::Panel | QFrame::Sunken);
 	statusERRORLabel->setAlignment(AlignLeft|AlignVCenter);
 
-	// create angle button group
-	QButtonGroup *angle_group = new QButtonGroup(3, Horizontal, this, "angle");
-	angle_group->setTitle(i18n( "Angle") );
-	connect( angle_group, SIGNAL(clicked(int)), SLOT(angle_selected(int)));
-
-	anglebutton[0] = new QRadioButton(angle_group);
-	anglebutton[0]->setText("&Deg");
-	anglebutton[0]->setChecked(true);
-	accel->connectItem(accel->insertItem(Key_D+ALT),
-		this, SLOT(Deg_Selected()));
-
-	anglebutton[1] = new QRadioButton(angle_group);
-	anglebutton[1]->setText("&Rad");
-	accel->connectItem(accel->insertItem(Key_R+ALT),
-		this, SLOT(Rad_Selected()));
-
-	anglebutton[2] = new QRadioButton(angle_group);
-	anglebutton[2]->setText( "&Gra" );
-	accel->connectItem(accel->insertItem(Key_G+ALT),
-		this, SLOT(Gra_Selected()));
-
 	// Create Number Base Button Group
 	QButtonGroup *base_group = new QButtonGroup(4, Horizontal,  this, "base");
 	base_group->setTitle(i18n("Base"));
-	connect(base_group, SIGNAL(clicked(int)), SLOT(base_selected(int)));
+	connect(base_group, SIGNAL(clicked(int)), SLOT(Base_Selected(int)));
 
 	basebutton[0] = new QRadioButton(base_group);
 	basebutton[0]->setText("&Hex");
+	QToolTip::add(basebutton[0], i18n("Hexadecimal"));
 	accel->connectItem(accel->insertItem(Key_H+ALT),
 		this, SLOT(Hex_Selected()));
 
 	basebutton[1] = new QRadioButton(base_group);
 	basebutton[1]->setText("D&ec");
+	QToolTip::add(basebutton[1], i18n("Decimal"));
 	basebutton[1]->setChecked(true);
 	accel->connectItem(accel->insertItem(Key_E+ALT),
 		this, SLOT(Dec_Selected()));
 
 	basebutton[2] = new QRadioButton(base_group);
 	basebutton[2]->setText("&Oct");
+	QToolTip::add(basebutton[2], i18n("Octal"));
 	accel->connectItem(accel->insertItem(Key_O+ALT),
 		this, SLOT(Oct_Selected()));
 
 	basebutton[3] = new QRadioButton(base_group);
 	basebutton[3]->setText("&Bin");
+	QToolTip::add(basebutton[3], i18n("Binary"));
 	accel->connectItem(accel->insertItem(Key_B+ALT),
 		this, SLOT(Bin_Selected()));
 
+	// create angle button group
+	angle_group = new QButtonGroup(3, Horizontal, this, "angle");
+	angle_group->setTitle(i18n( "Angle") );
+	connect( angle_group, SIGNAL(clicked(int)), SLOT(angle_selected(int)));
+
+	anglebutton[0] = new QRadioButton(angle_group);
+	anglebutton[0]->setText("&Deg");
+	QToolTip::add(anglebutton[0], i18n("Degrees"));
+	anglebutton[0]->setChecked(true);
+	accel->connectItem(accel->insertItem(Key_D+ALT),
+		this, SLOT(Deg_Selected()));
+
+	anglebutton[1] = new QRadioButton(angle_group);
+	anglebutton[1]->setText("&Rad");
+	QToolTip::add(anglebutton[1], i18n("Radians"));
+	accel->connectItem(accel->insertItem(Key_R+ALT),
+		this, SLOT(Rad_Selected()));
+
+	anglebutton[2] = new QRadioButton(angle_group);
+	anglebutton[2]->setText("&Gra");
+	QToolTip::add(anglebutton[2], i18n("Gradians"));
+	accel->connectItem(accel->insertItem(Key_G+ALT),
+		this, SLOT(Gra_Selected()));
+
 	//
 	//  Create Calculator Buttons
 	//
@@ -216,6 +219,7 @@ QtCalculator::QtCalculator(QWidget *parent, const char *name)
 	pbhyp->setToggleButton(true);
 
 	pbinv = new QPushButton("Inv", mSmallPage, "InverseButton");
+	QToolTip::add(pbinv, i18n("Inverse mode"));
 	pbinv->setAutoDefault(false);
 	connect(pbinv, SIGNAL(toggled(bool)), SLOT(pbinvtoggled(bool)));
 	pbinv->setToggleButton(true);
@@ -231,6 +235,7 @@ QtCalculator::QtCalculator(QWidget *parent, const char *name)
 	pbSin->setToggleButton(true);
 
 	pbplusminus = new QPushButton("+/-", mSmallPage, "plusminusbutton");
+	QToolTip::add(pbplusminus, i18n("Change sign"));
 	pbplusminus->setAutoDefault(false);
 	connect(pbplusminus, SIGNAL(toggled(bool)), SLOT(pbplusminustoggled(bool)));
 	pbplusminus->setToggleButton(true);
@@ -246,6 +251,7 @@ QtCalculator::QtCalculator(QWidget *parent, const char *name)
 	pbCos->setToggleButton(true);
 
 	pbreci = new QPushButton("1/x", mSmallPage, "recibutton");
+	QToolTip::add(pbreci, i18n("Reciprocal"));
 	pbreci->setAutoDefault(false);
 	connect(pbreci, SIGNAL(toggled(bool)), SLOT(pbrecitoggled(bool)));
 	pbreci->setToggleButton(true);
@@ -261,6 +267,7 @@ QtCalculator::QtCalculator(QWidget *parent, const char *name)
 	pbTan->setToggleButton(true);
 
 	pbfactorial = new QPushButton("x!", mSmallPage, "factorialbutton");
+	QToolTip::add(pbfactorial, i18n("Factorial"));
 	pbfactorial->setAutoDefault(false);
 	connect(pbfactorial, SIGNAL(toggled(bool)),SLOT(pbfactorialtoggled(bool)));
 	pbfactorial->setToggleButton(true);
@@ -276,6 +283,7 @@ QtCalculator::QtCalculator(QWidget *parent, const char *name)
 	pblog->setToggleButton(true);
 
 	pbsquare = new QPushButton("x^2", mSmallPage, "squarebutton");
+	QToolTip::add(pbsquare, i18n("Square"));
 	pbsquare->setAutoDefault(false);
 	connect(pbsquare, SIGNAL(toggled(bool)), SLOT(pbsquaretoggled(bool)));
 	pbsquare->setToggleButton(true);
@@ -306,6 +314,7 @@ QtCalculator::QtCalculator(QWidget *parent, const char *name)
 	connect(pbEE, SIGNAL(toggled(bool)), SLOT(EEtoggled(bool)));
 
 	pbMR = new QPushButton("MR", mLargePage, "MRbutton");
+	QToolTip::add(pbMR, i18n("Memory recall"));
 	pbMR->setAutoDefault(false);
 	connect(pbMR, SIGNAL(toggled(bool)), SLOT(pbMRtoggled(bool)));
 	pbMR->setToggleButton(true);
@@ -316,16 +325,19 @@ QtCalculator::QtCalculator(QWidget *parent, const char *name)
 	pbMplusminus->setToggleButton(true);
 
 	pbMC = new QPushButton("MC", mLargePage, "MCbutton");
+	QToolTip::add(pbMC, i18n("Clear memory"));
 	pbMC->setAutoDefault(false);
 	connect(pbMC, SIGNAL(toggled(bool)), SLOT(pbMCtoggled(bool)));
 	pbMC->setToggleButton(true);
 
 	pbClear = new QPushButton("C", mLargePage, "Clearbutton");
+	QToolTip::add(pbClear, i18n("Clear"));
 	pbClear->setAutoDefault(false);
 	connect(pbClear, SIGNAL(toggled(bool)), SLOT(pbCleartoggled(bool)));
 	pbClear->setToggleButton(true);
 
 	pbAC = new QPushButton("AC", mLargePage, "ACbutton");
+	QToolTip::add(pbAC, i18n("Clear all"));
 	pbAC->setAutoDefault(false);
 	connect(pbAC, SIGNAL(toggled(bool)), SLOT(pbACtoggled(bool)));
 	pbAC->setToggleButton(true);
@@ -356,6 +368,7 @@ QtCalculator::QtCalculator(QWidget *parent, const char *name)
 	pbparenclose->setToggleButton(true);
 
 	pband = new QPushButton("And", mLargePage, "andbutton");
+	QToolTip::add(pband, i18n("Bitwise AND"));
 	pband->setAutoDefault(false);
 	connect(pband, SIGNAL(toggled(bool)), SLOT(pbandtoggled(bool)));
 	pband->setToggleButton(true);
@@ -376,16 +389,19 @@ QtCalculator::QtCalculator(QWidget *parent, const char *name)
 	pb6->setToggleButton(true);
 
 	pbX = new QPushButton("X", mLargePage, "Multiplybutton");
+	QToolTip::add(pbX, i18n("Multiplication"));
 	pbX->setAutoDefault(false);
 	connect(pbX, SIGNAL(toggled(bool)), SLOT(pbXtoggled(bool)));
 	pbX->setToggleButton(true);
 
 	pbdivision = new QPushButton("/", mLargePage, "divisionbutton");
+	QToolTip::add(pbdivision, i18n("Division"));
 	pbdivision->setAutoDefault(false);
 	connect(pbdivision, SIGNAL(toggled(bool)), SLOT(pbdivisiontoggled(bool)));
 	pbdivision->setToggleButton(true);
 
 	pbor = new QPushButton("Or", mLargePage, "orbutton");
+	QToolTip::add(pbor, i18n("Bitwise OR"));
 	pbor->setAutoDefault(false);
 	connect(pbor, SIGNAL(toggled(bool)), SLOT(pbortoggled(bool)));
 	pbor->setToggleButton(true);
@@ -416,11 +432,13 @@ QtCalculator::QtCalculator(QWidget *parent, const char *name)
 	pbminus->setToggleButton(true);
 
 	pbshift = new QPushButton("Lsh", mLargePage, "shiftbutton");
+	QToolTip::add(pbshift, i18n("Bit shift"));
 	pbshift->setAutoDefault(false);
 	connect(pbshift, SIGNAL(toggled(bool)), SLOT(pbshifttoggled(bool)));
 	pbshift->setToggleButton(true);
 
 	pbperiod = new QPushButton(".", mLargePage, "periodbutton");
+	QToolTip::add(pbperiod, i18n("Decimal point"));
 	pbperiod->setAutoDefault(false);
 	connect(pbperiod, SIGNAL(toggled(bool)), SLOT(pbperiodtoggled(bool)));
 	pbperiod->setToggleButton(true);
@@ -436,16 +454,19 @@ QtCalculator::QtCalculator(QWidget *parent, const char *name)
 	pbequal->setToggleButton(true);
 
 	pbpercent = new QPushButton("%", mLargePage, "percentbutton");
+	QToolTip::add(pbpercent, i18n("Percent"));
 	pbpercent->setAutoDefault(false);
 	connect(pbpercent, SIGNAL(toggled(bool)), SLOT(pbpercenttoggled(bool)));
 	pbpercent->setToggleButton(true);
 
 	pbnegate = new QPushButton("Cmp", mLargePage, "OneComplementbutton");
+	QToolTip::add(pbnegate, i18n("One's complement"));
 	pbnegate->setAutoDefault(false);
 	connect(pbnegate, SIGNAL(toggled(bool)), SLOT(pbnegatetoggled(bool)));
 	pbnegate->setToggleButton(true);
 
 	pbmod = new QPushButton("Mod", mLargePage, "modbutton");
+	QToolTip::add(pbmod, i18n("Modulo"));
 	pbmod->setAutoDefault(false);
 	connect(pbmod, SIGNAL(toggled(bool)), SLOT(pbmodtoggled(bool)));
 	pbmod->setToggleButton(true);
@@ -629,10 +650,11 @@ QtCalculator::QtCalculator(QWidget *parent, const char *name)
 	set_display_font();
 	set_precision();
 	set_style();
+	Base_Selected(1);
 	InitializeCalculator();
 
 	updateGeometry();
-	setFixedHeight(minimumHeight());
+	setFixedSize(minimumSize());
 }
 
 //-------------------------------------------------------------------------
@@ -655,22 +677,6 @@ void QtCalculator::updateGeometry()
     QSize s;
     int margin;
 
-    //
-    // Uppermost bar
-    //
-    mHelpButton->setFixedWidth(mHelpButton->fontMetrics().width("MM") +
-                               QApplication::style().
-                               pixelMetric(QStyle::PM_ButtonMargin,
-                                           mHelpButton)*2);
-    calc_display->setMinimumWidth(calc_display->fontMetrics().maxWidth() * 15);
-
-    //
-    // Button groups (base and angle)
-    //
-    //QButtonGroup *g;
-    //g = (QButtonGroup*)(anglebutton[0]->parentWidget());
-    //g = (QButtonGroup*)(basebutton[0]->parentWidget());
-
     //
     // Calculator buttons
     //
@@ -723,6 +729,40 @@ void QtCalculator::updateGeometry()
     //setFixedSize(minimumSize());
 }
 
+//-------------------------------------------------------------------------
+// Name: Base_Selected()
+//-------------------------------------------------------------------------
+void QtCalculator::Base_Selected(int base)
+{
+	// Enable the hexit buttons if we're in hex mode
+	// (Base 0 == hexidecimal)
+
+	for(QPushButton *p = mHexButtonList.first(); p; p=mHexButtonList.next())
+	{
+		p->setEnabled(base == 0);
+	}
+
+	// Enable 8 & 9 if we're in dec mode or better
+	// (Base 1 == decimal)
+	pb9->setEnabled(base <= 1);
+	pb8->setEnabled(base <= 1);
+
+	// Enable 2,3,4,5,6,7 if we're in oct mode or better
+	// (Base 2 == decimal)
+	pb7->setEnabled(base <= 2);
+	pb6->setEnabled(base <= 2);
+	pb5->setEnabled(base <= 2);
+	pb4->setEnabled(base <= 2);
+	pb3->setEnabled(base <= 2);
+	pb2->setEnabled(base <= 2);
+
+	// Only enable the decimal point in decimal
+	pbperiod->setEnabled(base == 1);
+
+	// Call down to the core
+	base_selected(base);
+}
+
 //-------------------------------------------------------------------------
 // Name: Hex_Selected()
 //-------------------------------------------------------------------------
@@ -732,7 +772,7 @@ void QtCalculator::Hex_Selected()
 	basebutton[1]->setChecked(false);
 	basebutton[2]->setChecked(false);
 	basebutton[3]->setChecked(false);
-	base_selected(0);
+	Base_Selected(0);
 }
 
 //-------------------------------------------------------------------------
@@ -744,7 +784,7 @@ void QtCalculator::Dec_Selected()
 	basebutton[1]->setChecked(true);
 	basebutton[2]->setChecked(false);
 	basebutton[3]->setChecked(false);
-	base_selected(1);
+	Base_Selected(1);
 }
 
 //-------------------------------------------------------------------------
@@ -756,7 +796,7 @@ void QtCalculator::Oct_Selected()
 	basebutton[1]->setChecked(false);
 	basebutton[2]->setChecked(true);
 	basebutton[3]->setChecked(false);
-	base_selected(2);
+	Base_Selected(2);
 }
 
 //-------------------------------------------------------------------------
@@ -768,7 +808,7 @@ void QtCalculator::Bin_Selected()
 	basebutton[1]->setChecked(false);
 	basebutton[2]->setChecked(false);
 	basebutton[3]->setChecked(true);
-	base_selected(3);
+	Base_Selected(3);
 }
 
 //-------------------------------------------------------------------------
@@ -804,14 +844,6 @@ void QtCalculator::Gra_Selected()
 	angle_selected(2);
 }
 
-//-------------------------------------------------------------------------
-// Name: helpclicked()
-//-------------------------------------------------------------------------
-void QtCalculator::helpclicked()
-{
-	kapp->invokeHelp();
-}
-
 //-------------------------------------------------------------------------
 // Name: configurationChanged(const DefStruct &state)
 //-------------------------------------------------------------------------
@@ -842,7 +874,7 @@ void QtCalculator::keyPressEvent(QKeyEvent *e)
 	switch (e->key())
 	{
 	case Key_F1:
-		helpclicked();
+		kapp->invokeHelp();
 		break;
 	case Key_F2:
 		configclicked();
@@ -1848,7 +1880,7 @@ void QtCalculator::configclicked()
 {
 	if(mConfigureDialog == 0)
 	{
-		mConfigureDialog = new ConfigureDialog( this, 0, false );
+		mConfigureDialog = new ConfigureDialog( 0, 0, false );
 		mConfigureDialog->setState( kcalcdefaults );
 
 		connect( mConfigureDialog, SIGNAL( valueChanged(const DefStruct &)),
@@ -1856,6 +1888,8 @@ void QtCalculator::configclicked()
 	}
 
 	mConfigureDialog->show();
+        mConfigureDialog->setActiveWindow();
+        mConfigureDialog->raise();
 }
 
 
@@ -1868,25 +1902,38 @@ void QtCalculator::set_style()
 	{
 	case  0:
 		pbhyp->setText( "Hyp" );
+		QToolTip::add(pbhyp, i18n("Hyperbolic mode"));
 		pbSin->setText( "Sin" );
+		QToolTip::add(pbSin, i18n("Sine"));
 		pbCos->setText( "Cos" );
+		QToolTip::add(pbCos, i18n("Cosine"));
 		pbTan->setText( "Tan" );
+		QToolTip::add(pbTan, i18n("Tangent"));
 		pblog->setText( "Log" );
+		QToolTip::remove(pblog);
 		pbln ->setText( "Ln"  );
+		QToolTip::add(pbln, i18n("Natural log"));
 		break;
 
 	case 1:
 		pbhyp->setText( "N" );
 		pbSin->setText( "Mea" );
+		QToolTip::add(pbSin, i18n("Mean"));
 		pbCos->setText( "Std" );
+		QToolTip::add(pbCos, i18n("Standard deviation"));
 		pbTan->setText( "Med" );
+		QToolTip::add(pbTan, i18n("Median"));
 		pblog->setText( "Dat" );
+		QToolTip::add(pblog, i18n("Enter data"));
 		pbln ->setText( "CSt"  );
+		QToolTip::add(pbln, i18n("Clear data store"));
 		break;
 
 	default:
 		break;
 	}
+
+	angle_group->setEnabled(kcalcdefaults.style == 0);
 }
 
 //-------------------------------------------------------------------------
@@ -1898,8 +1945,6 @@ void QtCalculator::readSettings()
 
 	KConfig *config = KGlobal::config();
 	config->setGroup("Font");
-
-
 	QFont tmpFont("helvetica",14,QFont::Bold);
 	kcalcdefaults.font = config->readFontEntry("Font",&tmpFont);
 
@@ -1979,26 +2024,29 @@ void QtCalculator::writeSettings()
 //-------------------------------------------------------------------------
 void QtCalculator::display_selected()
 {
-	if(calc_display->Button() == LeftButton)
-	{
-		if(calc_display->isLit())
-		{
+	if(calc_display->Button() == LeftButton) {
+	
+		if(calc_display->isLit()) {
 			QClipboard *cb = QApplication::clipboard();
+			bool oldMode = cb->selectionModeEnabled();
+			cb->setSelectionMode(true);
 			cb->setText(calc_display->text());
+			cb->setSelectionMode(oldMode);
 			selection_timer->start(100);
-		}
-		else
+		} else {
 			selection_timer->stop();
+		}
 
 		invertColors();
-	}
-	else
-	{
+	} else {
 		QClipboard *cb = QApplication::clipboard();
+		bool oldMode = cb->selectionModeEnabled();
+		cb->setSelectionMode(true);
 
 		CALCAMNT result;
 		bool was_ok;
 		result = (CALCAMNT) cb->text().toDouble(&was_ok);
+		cb->setSelectionMode(oldMode);
 
 		if (!was_ok)
 			result = (CALCAMNT) (0);
@@ -2077,7 +2125,6 @@ void QtCalculator::quitCalc()
 {
 	writeSettings();
 	qApp->quit();
-	delete this;
 }
 
 
@@ -2270,21 +2317,39 @@ bool QtCalculator::eventFilter(QObject *o, QEvent *e)
 
 #include "kcalc.moc"
 
-
 //-------------------------------------------------------------------------
 // Name: main(int argc, char *argv[])
 //-------------------------------------------------------------------------
 int main(int argc, char *argv[])
 {
+        QString precisionStatement;
+        
+#ifdef HAVE_LONG_DOUBLE
+        precisionStatement = QString(I18N_NOOP("Built with %1 bit (long double) precision"))
+                                     .arg(sizeof(long double) * 8);
+#else
+        precisionStatement =  QString(I18N_NOOP("Built with %1 bit precision"
+                                         "\n\nNote: Due to a broken C library, KCalc's precision \n"
+                                         "was conditionally reduced at compile time from\n"
+                                         "'long double' to 'double'. \n\n"
+                                         "Owners of systems with a working libc may \n"
+                                         "want to recompile KCalc with 'long double' \n"
+                                         "precision enabled. See the README for details."))
+                                     .arg(sizeof(long) * 8);
+#endif
+
 	KAboutData aboutData( "kcalc", I18N_NOOP("KCalc"),
 		version, description, KAboutData::License_GPL,
-		"(c) 1996-2000, Bernd Johannes Wuebben");
+		"(c) 1996-2000, Bernd Johannes Wuebben\n"
+		"(c) 2000-2002, The KDE Team",
+                precisionStatement.latin1());
 
 	aboutData.addAuthor("Bernd Johannes Wuebben", 0, "wuebben@kde.org");
-	aboutData.addAuthor("Charles Samuels",
-		I18N_NOOP("Support for the new Backspace Action"), "charles@altair.dhs.org");
 	aboutData.addAuthor("Evan Teran", 0, "emt3734@rit.edu");
-
+	aboutData.addAuthor("Espen Sand", 0, "espen@kde.org");
+	aboutData.addAuthor("Chris Howells", 0, "howells@kde.org");	
+        aboutData.addAuthor("Aaron J. Seigo", 0, "aseigo@olympusproject.org");
+        aboutData.addAuthor("Charles Samuels", 0, "charles@altair.dhs.org");
 	KCmdLineArgs::init(argc, argv, &aboutData);
 
 	KApplication app;
@@ -2300,6 +2365,7 @@ int main(int argc, char *argv[])
 	calc->show();
 
 	int exitCode = app.exec();
+	delete calc;
 
 	return(exitCode);
 }
