@@ -1,5 +1,5 @@
 /*
-    $Id: kcalc_core.cpp,v 1.46.2.3 2002/08/05 15:53:22 mlaurent Exp $
+    $Id: kcalc_core.cpp,v 1.59 2002/09/23 21:25:21 waba Exp $
 
     kCalculator, a scientific calculator for the X window system using the
     Qt widget libraries, available at no cost at http://www.troll.no
@@ -35,6 +35,9 @@
 #include <limits.h>
 #include <signal.h>
 #include <stdio.h>
+#include <assert.h>
+
+using namespace std;
 
 #include <klocale.h>
 #include <kmessagebox.h>
@@ -65,6 +68,24 @@ stack_ptr	top_type_stack[2] = { NULL, NULL };
 int 		stack_next, stack_last;
 stack_item	process_stack[STACK_SIZE];
 
+#ifdef HAVE_LONG_DOUBLE
+	#define PRINT_FLOAT		"%.*Lf"
+	#define PRINT_LONG_BIG	"%.*Lg"
+	#define PRINT_LONG		"%Lg"
+#else
+	#define PRINT_FLOAT		"%.*f"
+	#define PRINT_LONG_BIG	"%.*g"
+	#define PRINT_LONG		"%g"
+#endif
+
+#ifdef HAVE_LONG_LONG
+	#define PRINT_OCTAL	"%llo"
+	#define PRINT_HEX	"%llX"
+#else
+	#define PRINT_OCTAL	"%lo"
+	#define PRINT_HEX	"%lX"
+#endif
+
 item_contents 	display_data;
 
 int precedence[14] = { 0, 1, 2, 3, 4, 4, 5, 5, 6, 6, 6, 7, 7, 6 };
@@ -87,26 +108,6 @@ int adjust_op[14][3] =
 	{FUNC_INTDIV,   FUNC_INTDIV,   FUNC_INTDIV},
 };
 
-/*
-char *function_desc[] =
-{
-	"Null",
-	"Or",
-	"Exclusive Or",
-	"And",
-	"Left Shift",
-	"Right Shift",
-	"Add",
-	"Subtract",
-	"Multiply",
-	"Divide",
-	"Modulus"
-	"Power"
-	"Reciprocal Power"
-	"Integer Division"
-};
-*/
-
 Arith Arith_ops[14] =
 {
 	NULL,
@@ -133,14 +134,14 @@ Prcnt Prcnt_ops[14] =
 	NULL,
 	NULL,
 	NULL,
-	QtCalculator::ExecAddSubP,
-	QtCalculator::ExecAddSubP,
+	QtCalculator::ExecAddP,
+	QtCalculator::ExecSubP,
 	QtCalculator::ExecMultiplyP,
 	QtCalculator::ExecDivideP,
-	QtCalculator::ExecDivideP,
-	QtCalculator::ExecPowerP,
-	QtCalculator::ExecPwrRootP,
-	QtCalculator::ExecDivideP
+        NULL,
+        NULL,
+	NULL,
+	NULL
 };
 
 
@@ -312,11 +313,11 @@ void QtCalculator::InitializeCalculator()
 	void fpe_handler(int fpe_parm);
 	struct sigaction fpe_trap;
 
+        sigemptyset(&fpe_trap.sa_mask);
 	fpe_trap.sa_handler = &fpe_handler;
 #ifdef SA_RESTART
 	fpe_trap.sa_flags = SA_RESTART;
 #endif
-
 	sigaction(SIGFPE, &fpe_trap, NULL);
 
 	RefreshCalculator();
@@ -356,81 +357,76 @@ void QtCalculator::RefreshCalculator()
 //-------------------------------------------------------------------------
 void QtCalculator::EnterDigit(int data)
 {
-	if(eestate)
-	{
+	if(eestate) {
 		QString string;
 		string.setNum(data);
 		strcat(display_str, string.latin1());
-		DISPLAY_AMOUNT = (CALCAMNT) strtod(display_str,0);
+		DISPLAY_AMOUNT = (CALCAMNT) STRTOD(display_str,0);
 		UpdateDisplay();
 		return;
 	}
 
 	last_input = DIGIT;
 
-	if (refresh_display)
-	{
+	if (refresh_display) {
 		DISPLAY_AMOUNT = 0L;
 		decimal_point = 0;
 		refresh_display = false;
 		input_count = 0;
 	}
 
-	if (!(input_limit && input_count >= input_limit))
-		if (DISPLAY_AMOUNT < 0)
+	if (!(input_limit && input_count >= input_limit)) {
+		if (DISPLAY_AMOUNT < 0) {
 			DISPLAY_AMOUNT = decimal_point ?
 			DISPLAY_AMOUNT - ((CALCAMNT)data /
-			POW(current_base, decimal_point++)) :
+			POW((CALCAMNT)current_base, decimal_point++)) :
 			(current_base * DISPLAY_AMOUNT) - data;
-		else
+		} else {
 			DISPLAY_AMOUNT = decimal_point ?
 			DISPLAY_AMOUNT + ((CALCAMNT)data /
-			POW(current_base, decimal_point++)) :
+			POW((CALCAMNT)current_base, decimal_point++)) :
 			(current_base * DISPLAY_AMOUNT) + data;
-
-		if (decimal_point)
-		{
-			input_count ++;
-#ifdef MYDEBUG
-	printf("EnterDigit() inc dec.point:%d\n",input_count);
-#endif
 		}
+	}
+
+	if (decimal_point) {
+		input_count ++;
+	}
 
 	UpdateDisplay();
 }
-
 //-------------------------------------------------------------------------
 // Name: SubtractDigit()
 //-------------------------------------------------------------------------
 void QtCalculator::SubtractDigit()
 {
-	// This function could be better, possibly, but am I glad to see it!
-	if (DISPLAY_AMOUNT != 0 || decimal_point!=0)
-	{
-                if (current_base == NB_DECIMAL && (DISPLAY_AMOUNT != floor(DISPLAY_AMOUNT)))
-                {
-                        if (decimal_point < 3)
-                        {
-                            decimal_point = 0;
-                            DISPLAY_AMOUNT = floor(DISPLAY_AMOUNT);
-                        }
-                        else
-                        {
-                            --decimal_point;
-                            DISPLAY_AMOUNT = floor(DISPLAY_AMOUNT * POW(current_base, decimal_point - 1)) /
-                                             POW(current_base, (decimal_point - 1));
-                        }
-                }
-                else
-                {
-                        DISPLAY_AMOUNT = floor(DISPLAY_AMOUNT / current_base);
-                }
+   // This function could be better, possibly, but am I glad to see it!
+   if (DISPLAY_AMOUNT != 0||decimal_point!=0)
+   {
+      if (current_base == NB_DECIMAL && (DISPLAY_AMOUNT != floor(DISPLAY_AMOUNT)))
+      {
+          if (decimal_point < 3)
+         {
+             decimal_point = 0;
+            DISPLAY_AMOUNT = floor(DISPLAY_AMOUNT);
+         }
+         else
+         {
+            --decimal_point;
+            DISPLAY_AMOUNT = floor(DISPLAY_AMOUNT * POW((CALCAMNT)current_base, decimal_point - 1)) /
+               POW((CALCAMNT)current_base, (decimal_point - 1));
+         }
+      }
+      else
+      {
+         DISPLAY_AMOUNT = floor(DISPLAY_AMOUNT / current_base);
+      }
 
-                if (input_count > 0)
-                {
-                        --input_count;
-                }
-	}
+      if (input_count > 0)
+      {
+         --input_count;
+      }
+   }
 
 #ifdef MYDEBUG
 	printf("SubtractDigit()");
@@ -464,22 +460,25 @@ void QtCalculator::EnterDecimal()
 
 	if(last_input == DIGIT)
 	{
-		if (!strpbrk(display_str,"."))
+      if (decimal_point==0)  //strpbrk() doesn't work in fixed precision mode
 		{
 			// if the last input was a DIGIT and we don't
 			// have already a period in our
 			// display string then display a period
+			if (strlen(display_str) >= DSP_SIZE)
+			   return;
 
-			calc_display->setText(strcat(display_str, "."));
+         if (!kcalcdefaults.fixed)
+            calc_display->setText(strcat(display_str, "."));
 			decimal_point = 1;
 		}
 	}
 	else
 	{
 		// the last input wasn't a DIGIT so we are about to
-		// input a new number in particular we neet do display a "0.".
+		// input a new number in particular we need to display a "0.".
 
-		if (!strpbrk(display_str,"."))
+      if (decimal_point==0)  //strpbrk() doesn't work in fixed precision mode
 		{
 
 			DISPLAY_AMOUNT = 0L;
@@ -489,7 +488,8 @@ void QtCalculator::EnterDecimal()
 			//	  decimal_point = 1;
 			//	  input_count = 1;
 
-			strcpy(display_str, "0.");
+         if (!kcalcdefaults.fixed)
+            strcpy(display_str, "0.");
 			calc_display->setText(display_str);
 		}
 	}
@@ -635,9 +635,7 @@ void QtCalculator::EnterStackFunction(int data)
 	}
 	*/
 
-	//	printf("data %d dummy %d\n",data,dummy);
 	data = adjust_op[data][dummy];
-	//	printf("data %d \n",data );
 
 	PushStack(&display_data);
 
@@ -647,8 +645,10 @@ void QtCalculator::EnterStackFunction(int data)
 		new_precedence = precedence[data] + precedence_base;
 
 	refresh_display = true;
-	if (UpdateStack(new_precedence))
+	if (UpdateStack(new_precedence)) {
 		UpdateDisplay();
+	}
+
 	PushStack(&new_item);
 }
 
@@ -678,7 +678,7 @@ void QtCalculator::EnterNegate()
 			}
 		}
 
-		DISPLAY_AMOUNT = (CALCAMNT)strtod(display_str,0);
+		DISPLAY_AMOUNT = (CALCAMNT)STRTOD(display_str,0);
 		UpdateDisplay();
 	}
 	else
@@ -822,15 +822,15 @@ void QtCalculator::EnterNotCmp()
 {
 	eestate = false;
 	CALCAMNT boh_work_d;
-	long boh_work;
+	KCALC_LONG boh_work;
 
 	MODF(DISPLAY_AMOUNT, &boh_work_d);
 
-	if (FABS(boh_work_d) > LONG_MAX)
+	if (FABS(boh_work_d) > KCALC_LONG_MAX)
 		display_error = true;
 	else
 	{
-		boh_work = (long int)boh_work_d;
+		boh_work = (KCALC_LONG)boh_work_d;
 		DISPLAY_AMOUNT = ~boh_work;
 	}
 
@@ -1401,7 +1401,7 @@ void QtCalculator::base_selected(int number)
 		current_base	= NB_HEX;
 		display_size	= HEX_SIZE;
 		decimal_point	= 0;
-		input_limit		= 8;
+		input_limit		= sizeof(KCALC_LONG)*2;
 		break;
 	case 1:
 		current_base	= NB_DECIMAL;
@@ -1481,6 +1481,9 @@ void QtCalculator::EE()
 	}
 	else
 	{
+		if (strlen(display_str) >= DSP_SIZE)
+		   return;
+
 		if(!eestate)
 			strcat(display_str,"e");
 
@@ -1607,8 +1610,8 @@ void QtCalculator::UpdateDisplay()
 	// are correctly displayed.
 
 	CALCAMNT	boh_work_d;
-	long 		boh_work = 0;
-	int			str_size = 0;
+	KCALC_LONG	boh_work = 0;
+	int		str_size = 0;
 
 	if(eestate && (current_base == NB_DECIMAL))
 	{
@@ -1620,7 +1623,7 @@ void QtCalculator::UpdateDisplay()
 	{
 		MODF(DISPLAY_AMOUNT, &boh_work_d);
 
-		if (boh_work_d < LONG_MIN || boh_work_d > ULONG_MAX)
+		if (boh_work_d < KCALC_LONG_MIN || boh_work_d > KCALC_ULONG_MAX)
 			display_error = true;
 
 		//
@@ -1629,15 +1632,15 @@ void QtCalculator::UpdateDisplay()
 		// just that, allowing boh negative numbers to be entered
 		// as read (from dumps and the like!)
 		//
-		else if (boh_work_d > LONG_MAX)
+		else if (boh_work_d > KCALC_LONG_MAX)
 		{
-			DISPLAY_AMOUNT = LONG_MIN + (boh_work_d - LONG_MAX - 1);
-			boh_work = (long)DISPLAY_AMOUNT;
+			DISPLAY_AMOUNT = KCALC_LONG_MIN + (boh_work_d - KCALC_LONG_MAX - 1);
+			boh_work = (KCALC_LONG)DISPLAY_AMOUNT;
 		}
 		else
 		{
 			DISPLAY_AMOUNT = boh_work_d;
-			boh_work = (long)boh_work_d;
+			boh_work = (KCALC_LONG)boh_work_d;
 		}
 	}
 
@@ -1650,68 +1653,40 @@ void QtCalculator::UpdateDisplay()
 			break;
 
 		case NB_OCTAL:
-			str_size = sprintf(display_str, "%lo", boh_work);
+			str_size = snprintf(display_str, DSP_SIZE, PRINT_OCTAL, boh_work);
 			break;
 
 		case NB_HEX:
-			str_size = sprintf(display_str, "%lX", boh_work);
+			str_size = snprintf(display_str, DSP_SIZE, PRINT_HEX, boh_work);
 			break;
 
 		case NB_DECIMAL:
-                        if (kcalcdefaults.fixed)
-                        {
-                                str_size = sprintf(display_str,
-
-#ifdef HAVE_LONG_DOUBLE
-                                        "%.*Lf", // was *Lg
-                                        kcalcdefaults.fixedprecision,
-#else
-                                        "%.*f",
-                                        kcalcdefaults.fixedprecision,
-#endif
-                                        DISPLAY_AMOUNT);
-                        }
-			else if(last_input == DIGIT || DISPLAY_AMOUNT > 1.0e+16)
-			{
+			if (kcalcdefaults.fixed && DISPLAY_AMOUNT <= 1.0e+16) {
+				str_size = snprintf(display_str, DSP_SIZE,
+						PRINT_FLOAT,
+						kcalcdefaults.fixedprecision,
+						DISPLAY_AMOUNT);
+			} else if(last_input == DIGIT || DISPLAY_AMOUNT > 1.0e+16) {
 
 				// if I don't guard against the DISPLAY_AMOUNT being too large
 				// kcalc will segfault on larger amount. Such as from typing
 				// from 5*5*******
-				str_size = sprintf(display_str,
-#ifdef HAVE_LONG_DOUBLE
-					"%.*Lg", // was *Lg
-					kcalcdefaults.precision + 1,
-#else
-					"%.*g",
-					kcalcdefaults.precision + 1,
-#endif
-					DISPLAY_AMOUNT);
+				str_size = snprintf(display_str, DSP_SIZE,
+							PRINT_LONG_BIG,
+							kcalcdefaults.precision + 1,
+							DISPLAY_AMOUNT);
+			} else {
+				str_size = snprintf(display_str, DSP_SIZE, PRINT_LONG, DISPLAY_AMOUNT);
 			}
-                        else
-                        {
-#ifdef HAVE_LONG_DOUBLE
-                            str_size = sprintf(display_str, "%Lg", DISPLAY_AMOUNT);
-#else
-                            str_size = sprintf(display_str, "%g", DISPLAY_AMOUNT);
-#endif
-                        }
 
 			if (input_count > 0 && !strpbrk(display_str,"e") &&
 				last_input == DIGIT )
 			{
-#ifdef HAVE_LONG_DOUBLE
-				str_size = sprintf(display_str,
-					"%.*Lf",
+				str_size = snprintf(display_str, DSP_SIZE,
+					PRINT_FLOAT,
 					(kcalcdefaults.precision +1 > input_count)?
 					input_count : kcalcdefaults.precision ,
 					DISPLAY_AMOUNT);
-#else
-				str_size = sprintf(display_str,
-					"%.*f",
-					(kcalcdefaults.precision +1 > input_count)?
-					input_count : kcalcdefaults.precision ,
-					DISPLAY_AMOUNT);
-#endif
 			}
 			break;
 
@@ -1739,61 +1714,30 @@ void QtCalculator::UpdateDisplay()
 }
 
 //-------------------------------------------------------------------------
-// Name: cvb(char *out_str, long amount, int max_digits)
+// Name: cvb(char *out_str, KCALC_LONG amount, int max_digits)
 //-------------------------------------------------------------------------
-int QtCalculator::cvb(char *out_str, long amount, int max_digits)
+int QtCalculator::cvb(char *out_str, KCALC_LONG amount, int max_digits)
 {
 	/*
 	* A routine that converts a long int to
 	* binary display format
 	*/
 
-	/*
-	char		work_str[(sizeof(amount) * CHAR_BIT) + 1];
-	int		work_char = 0,
-	lead_zero = 1,
-	lead_one = 1,
-	lead_one_count = 0,
-	work_size = sizeof(amount) * CHAR_BIT;
-	unsigned long	bit_mask = ((unsigned long) 1 << ((sizeof(amount) * CHAR_BIT) - 1));
-
-	while (bit_mask) {
-
-	if (amount & bit_mask) {
-	if (lead_one)
-	lead_one_count++;
-	lead_zero = 0;
-	work_str[work_char++] = '1';
-	} else {
-	lead_one = 0;
-	if (!lead_zero)
-	work_str[work_char++] = '0';
-	}
-	bit_mask >>= 1;
-	bit_mask &= 0x7fffffff; //Sven: Uwe's Alpha adition
-	}
-	if (!work_char)
-	work_str[work_char++] = '0';
-	work_str[work_char] = '\0';
-
-	if (work_char-lead_one_count < max_digits)
-	return strlen(strcpy(out_str,
-	&work_str[lead_one_count ?
-	work_size - max_digits :
-	0]));
-	else
-	return -1;
-	*/
-
 	char *strPtr	= out_str;
 	bool hitOne		= false;
-	unsigned long bit_mask =
-		((unsigned long) 1 << ((sizeof(amount) * CHAR_BIT) - 1));
+	unsigned KCALC_LONG bit_mask =
+		((unsigned KCALC_LONG) 1 << (BIN_SIZE - 1));
+	unsigned KCALC_LONG bit_mask_mask = bit_mask - 1;
+	unsigned int count = 0 ;
 
 	while(bit_mask != 0 && max_digits > 0)
 	{
 		char tmp = (bit_mask & amount) ? '1' : '0';
 
+		if (hitOne && (count%4==0))
+			*strPtr++ = ' ';
+		count++;
+
 		if(!hitOne && tmp == '1')
 			hitOne = true;
 
@@ -1805,7 +1749,7 @@ int QtCalculator::cvb(char *out_str, long amount, int max_digits)
 		// this will fix a prob with some processors using an
 		// arithmetic right shift (which would maintain sign on
 		// negative numbers and cause a loop that's too long)
-		bit_mask &= 0x7fffffff; //Sven: Uwe's Alpha adition
+		bit_mask &= bit_mask_mask; //Sven: Uwe's Alpha adition
 
 		max_digits--;
 	}
@@ -1860,26 +1804,24 @@ int QtCalculator::UpdateStack(int run_precedence)
 
 		left_op = top_item->s_item_data.item_amount;
 
-		new_item.s_item_data.item_amount =
+		if ( ! percent_mode || Prcnt_ops[op_function] == NULL )
+                {
+                    new_item.s_item_data.item_amount =
 			(Arith_ops[op_function])(left_op, right_op);
-
-		PushStack(&new_item);
-	}
-
-	if (return_value &&
-		percent_mode &&
-		!display_error &&
-		Prcnt_ops[op_function] != NULL)
-	{
-		new_item.s_item_data.item_amount =
-			(Prcnt_ops[op_function])
-				(left_op, right_op, new_item.s_item_data.item_amount);
+                }
+                else
+                {
+                    new_item.s_item_data.item_amount =
+                        (Prcnt_ops[op_function])(left_op, right_op);
+                    percent_mode = false;
+                };
 
 		PushStack(&new_item);
 	}
 
 	if (return_value)
 		DISPLAY_AMOUNT = new_item.s_item_data.item_amount;
+
    decimal_point=1;
 	return return_value;
 }
@@ -1902,26 +1844,26 @@ CALCAMNT QtCalculator::ExecOr(CALCAMNT left_op, CALCAMNT right_op)
 {
 	// printf("ExecOr\n");
 	CALCAMNT	boh_work_d;
-	long 		boh_work_l;
-	long		boh_work_r;
+	KCALC_LONG	boh_work_l;
+	KCALC_LONG	boh_work_r;
 
 	MODF(left_op, &boh_work_d);
-	if (FABS(boh_work_d) > LONG_MAX)
+	if (FABS(boh_work_d) > KCALC_LONG_MAX)
 	{
 		display_error = true;
 		return 0;
 	}
 
-	boh_work_l = (long int)boh_work_d;
+	boh_work_l = (KCALC_LONG)boh_work_d;
 	MODF(right_op, &boh_work_d);
 
-	if (FABS(boh_work_d) > LONG_MAX)
+	if (FABS(boh_work_d) > KCALC_LONG_MAX)
 	{
 		display_error = true;
 		return 0;
 	}
 
-	boh_work_r = (long int) boh_work_d;
+	boh_work_r = (KCALC_LONG) boh_work_d;
 	return (boh_work_l | boh_work_r);
 }
 
@@ -1932,26 +1874,26 @@ CALCAMNT QtCalculator::ExecXor(CALCAMNT left_op, CALCAMNT right_op)
 {
 	// printf("ExecXOr\n");
 	CALCAMNT	boh_work_d;
-	long 		boh_work_l;
-	long		boh_work_r;
+	KCALC_LONG	boh_work_l;
+	KCALC_LONG	boh_work_r;
 
 	MODF(left_op, &boh_work_d);
-	if (FABS(boh_work_d) > LONG_MAX)
+	if (FABS(boh_work_d) > KCALC_LONG_MAX)
 	{
 		display_error = true;
 		return 0;
 	}
 
-	boh_work_l = (long int)boh_work_d;
+	boh_work_l = (KCALC_LONG)boh_work_d;
 	MODF(right_op, &boh_work_d);
 
-	if (FABS(boh_work_d) > LONG_MAX)
+	if (FABS(boh_work_d) > KCALC_LONG_MAX)
 	{
 		display_error = true;
 		return 0;
 	}
 
-	boh_work_r = (long int)boh_work_d;
+	boh_work_r = (KCALC_LONG)boh_work_d;
 	return (boh_work_l ^ boh_work_r);
 }
 
@@ -1962,26 +1904,26 @@ CALCAMNT QtCalculator::ExecAnd(CALCAMNT left_op, CALCAMNT right_op)
 {
 	// printf("ExecAnd\n");
 	CALCAMNT	boh_work_d;
-	long 		boh_work_l;
-	long		boh_work_r;
+	KCALC_LONG	boh_work_l;
+	KCALC_LONG	boh_work_r;
 
 	MODF(left_op, &boh_work_d);
-	if (FABS(boh_work_d) > LONG_MAX)
+	if (FABS(boh_work_d) > KCALC_LONG_MAX)
 	{
 		display_error = true;
 		return 0;
 	}
 
-	boh_work_l = (long int)boh_work_d;
+	boh_work_l = (KCALC_LONG)boh_work_d;
 	MODF(right_op, &boh_work_d);
 
-	if (FABS(boh_work_d) > LONG_MAX)
+	if (FABS(boh_work_d) > KCALC_LONG_MAX)
 	{
 		display_error = true;
 		return 0;
 	}
 
-	boh_work_r = (long int)boh_work_d;
+	boh_work_r = (KCALC_LONG)boh_work_d;
 	return (boh_work_l & boh_work_r);
 }
 
@@ -1992,26 +1934,26 @@ CALCAMNT QtCalculator::ExecLsh(CALCAMNT left_op, CALCAMNT right_op)
 {
 	// printf("ExecLsh\n");
 	CALCAMNT	boh_work_d;
-	long 		boh_work_l;
-	long		boh_work_r;
+	KCALC_LONG	boh_work_l;
+	KCALC_LONG	boh_work_r;
 
 	MODF(left_op, &boh_work_d);
-	if (FABS(boh_work_d) > LONG_MAX)
+	if (FABS(boh_work_d) > KCALC_LONG_MAX)
 	{
 		display_error = true;
 		return 0;
 	}
 
-	boh_work_l = (long int) boh_work_d;
+	boh_work_l = (KCALC_LONG) boh_work_d;
 	MODF(right_op, &boh_work_d);
 
-	if (FABS(boh_work_d) > LONG_MAX)
+	if (FABS(boh_work_d) > KCALC_LONG_MAX)
 	{
 		display_error = true;
 		return 0;
 	}
 
-	boh_work_r = (long int ) boh_work_d;
+	boh_work_r = (KCALC_LONG) boh_work_d;
 	return (boh_work_l << boh_work_r);
 }
 
@@ -2022,26 +1964,26 @@ CALCAMNT QtCalculator::ExecRsh(CALCAMNT left_op, CALCAMNT right_op)
 {
 	// printf("ExecRsh\n");
 	CALCAMNT	boh_work_d;
-	long 		boh_work_l;
-	long		boh_work_r;
+	KCALC_LONG	boh_work_l;
+	KCALC_LONG	boh_work_r;
 
 	MODF(left_op, &boh_work_d);
-	if (FABS(boh_work_d) > LONG_MAX)
+	if (FABS(boh_work_d) > KCALC_LONG_MAX)
 	{
 		display_error = true;
 		return 0;
 	}
 
-	boh_work_l = (long int)boh_work_d;
+	boh_work_l = (KCALC_LONG)boh_work_d;
 	MODF(right_op, &boh_work_d);
 
-	if (FABS(boh_work_d) > LONG_MAX)
+	if (FABS(boh_work_d) > KCALC_LONG_MAX)
 	{
 		display_error = true;
 		return 0;
 	}
 
-	boh_work_r = (long int)boh_work_d;
+	boh_work_r = (KCALC_LONG)boh_work_d;
 	return (boh_work_l >> boh_work_r);
 }
 
@@ -2187,84 +2129,44 @@ CALCAMNT QtCalculator::ExecPwrRoot(CALCAMNT left_op, CALCAMNT right_op)
 //-------------------------------------------------------------------------
 // Name: ExecAddSubP(CALCAMNT left_op, CALCAMNT right_op, CALCAMNT result)
 //-------------------------------------------------------------------------
-CALCAMNT QtCalculator::ExecAddSubP(CALCAMNT left_op, CALCAMNT right_op, CALCAMNT result)
+CALCAMNT QtCalculator::ExecAddP(CALCAMNT left_op, CALCAMNT right_op)
 {
-	// printf("ExecAddsubP\n");
-	UNUSED(left_op);
+    return (left_op + left_op * right_op/100 );
+}
 
-	if (result == 0)
-	{
-		display_error = true;
-		return 0;
-	}
-	else
-		return (result * 100L) / right_op;
+//-------------------------------------------------------------------------
+// Name: ExecAddSubP(CALCAMNT left_op, CALCAMNT right_op, CALCAMNT result)
+//-------------------------------------------------------------------------
+CALCAMNT QtCalculator::ExecSubP(CALCAMNT left_op, CALCAMNT right_op)
+{
+    return (left_op - left_op * right_op/100 );
 }
 
 //-------------------------------------------------------------------------
 // Name: ExecMultiplyP(CALCAMNT left_op, CALCAMNT right_op, CALCAMNT result)
 //-------------------------------------------------------------------------
-CALCAMNT QtCalculator::ExecMultiplyP(CALCAMNT left_op, CALCAMNT right_op, CALCAMNT result)
+CALCAMNT QtCalculator::ExecMultiplyP(CALCAMNT left_op, CALCAMNT right_op)
 {
-	// printf("ExecMultiplyP\n");
-	UNUSED(left_op);
-	UNUSED(right_op);
-	return (result / 100L);
+    return left_op*right_op/100;
 }
 
 //-------------------------------------------------------------------------
 // Name: ExecPowerP(CALCAMNT left_op, CALCAMNT right_op, CALCAMNT result)
 //-------------------------------------------------------------------------
-CALCAMNT QtCalculator::ExecDivideP(CALCAMNT left_op, CALCAMNT right_op, CALCAMNT result)
+CALCAMNT QtCalculator::ExecDivideP(CALCAMNT left_op, CALCAMNT right_op)
 {
-	// printf("ExecDivideP\n");
-	UNUSED(left_op);
-	UNUSED(right_op);
-	return (result * 100L);
+    return left_op*100/right_op;
 }
 
-//-------------------------------------------------------------------------
-// Name: ExecPowerP(CALCAMNT left_op, CALCAMNT right_op, CALCAMNT result)
-//-------------------------------------------------------------------------
-CALCAMNT QtCalculator::ExecPowerP(CALCAMNT left_op, CALCAMNT right_op, CALCAMNT result)
-{
-	// printf("ExecPowerP\n");
-	UNUSED(result);
-	return ExecPower(left_op, (right_op / 100L));
-}
-
-//-------------------------------------------------------------------------
-// Name: ExecPwrRootP(CALCAMNT left_op, CALCAMNT right_op, CALCAMNT result)
-//-------------------------------------------------------------------------
-CALCAMNT QtCalculator::ExecPwrRootP(CALCAMNT left_op, CALCAMNT right_op, CALCAMNT result)
-{
-	// printf("ExePwrRootP\n");
-	UNUSED(result);
-
-	if (right_op == 0)
-	{
-		display_error = true;
-		return 0;
-	}
-	else
-		return ExecPower(left_op, (100L / right_op));
-}
-
-
 //-------------------------------------------------------------------------
 // Name: AllocStackItem()
 //-------------------------------------------------------------------------
 stack_ptr AllocStackItem()
 {
-	if (stack_next <= stack_last)
-	{
-		process_stack[stack_next].prior_item = NULL;
-		process_stack[stack_next].prior_type = NULL;
-		return (process_stack + (stack_next++));
-	}
-
-	KMessageBox::error(0L, i18n("Stack Error!") );
-	return (process_stack + stack_next);
+	assert(stack_next <= stack_last);
+	process_stack[stack_next].prior_item = NULL;
+	process_stack[stack_next].prior_type = NULL;
+	return (process_stack + (stack_next++));
 }
 
 //-------------------------------------------------------------------------
@@ -2272,8 +2174,9 @@ stack_ptr AllocStackItem()
 //-------------------------------------------------------------------------
 void UnAllocStackItem(stack_ptr return_item)
 {
-	if (return_item != (process_stack + (--stack_next)))
-		KMessageBox::error(0L, i18n("Stack Error!") );
+	if (return_item != (process_stack + (--stack_next))) {
+		assert(false); // stack error
+	}
 }
 
 //-------------------------------------------------------------------------
