@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: sshdlg.h,v 1.1 2000/03/15 11:22:55 jansen Exp $
+ * $Id: sshdlg.h,v 1.3 2000/07/31 19:33:42 bieker Exp $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
@@ -17,15 +17,15 @@ class KDEsshDialog
     Q_OBJECT
 
 public:
-    KDEsshDialog(QCString host, QCString user, QCString prompt, 
-	    bool enableKeep);
+    KDEsshDialog(QCString host, QCString user, QCString stub, 
+	    QString prompt, bool enableKeep);
     ~KDEsshDialog();
 
 protected:
     bool checkPassword(const char *password);
     
 private:
-    QCString m_User, m_Host;
+    QCString m_User, m_Host, m_Stub;
 };
     
 
