@@ -1,7 +1,7 @@
 /*
  * disklist.cpp
  *
- * $Id: disklist.cpp,v 1.23 2002/01/26 04:10:31 wolff Exp $
+ * $Id: disklist.cpp,v 1.27 2002/08/07 02:24:10 orlovich Exp $
  *
  * Copyright (c) 1999 Michael Kropfberger <michael.kropfberger@gmx.net>
  *
@@ -27,7 +27,7 @@
 
 #include <math.h>
 #include <stdlib.h>
-
+#include <kdebug.h>
 #include <kapplication.h>
 
 #include "disklist.h"
@@ -62,6 +62,7 @@ DiskList::DiskList(QObject *parent, const char *name)
   kdDebug() << "_OS_UNIX_" << endl;
 #endif
   */
+ updatesDisabled = false;
 
 if (NO_FS_TYPE)
   kdDebug() << "df gives no FS_TYPE" << endl;
@@ -93,6 +94,13 @@ DiskList::~DiskList()
 {
 };
 
+/**
+Updated need to be disabled sometimes to avoid pulling the DiskEntry out from the popupmenu handler
+*/
+void DiskList::setUpdatesDisabled(bool disable)
+{
+    updatesDisabled = disable;
+}
 
 /***************************************************************************
   * saves the KConfig for special mount/umount scripts
@@ -217,10 +225,9 @@ void DiskList::receivedDFStdErrOut(KProcess *, char *data, int len )
    * df: /home_tu1/ijzerman/floppy: Stale NFS file handle
    * but this shouldn't cause a real problem
    */
+   
 
-  QString tmp = QString(data) + QString("\0");  // adds a zero-byte
-  tmp.truncate(len);
-
+  QString tmp = QString::fromLatin1(data, len);
   dfStringErrOut.append(tmp);
 }
 
@@ -237,7 +244,7 @@ int DiskList::readDF()
   setenv("LANGUAGE", "en_US", 1);
   dfStringErrOut=""; // yet no data received
   dfProc->clearArguments();
-  (*dfProc) << DF_COMMAND << DF_ARGS;
+  (*dfProc) << "env" << "LC_ALL=POSIX" << DF_COMMAND << DF_ARGS;
   if (!dfProc->start( KProcess::NotifyOnExit, KProcess::AllOutput ))
     qFatal(i18n("could not execute [%s]").local8Bit().data(), DF_COMMAND);
   return 1;
@@ -249,6 +256,9 @@ int DiskList::readDF()
 **/
 void DiskList::dfDone()
 {
+  if (updatesDisabled)
+      return; //Don't touch the data for now..
+	  
   readingDFStdErrOut=TRUE;
   for ( DiskEntry *disk=disks->first(); disk != 0; disk=disks->next() )
     disk->setMounted(FALSE);  // set all devs unmounted
@@ -330,6 +340,20 @@ void DiskList::dfDone()
 }
 
 
+void DiskList::deleteAllMountedAt(const QString &mountpoint)
+{
+
+    for ( DiskEntry *item  = disks->first(); item;  )
+    {
+        if (item->mountPoint() == mountpoint ) {
+            kdDebug() << "delete " << item->deviceName() << endl;
+            disks->remove(item);
+            item = disks->current();
+        } else
+            item = disks->next();
+    }
+}
+
 /***************************************************************************
   * updates or creates a new DiskEntry in the KDFList and TabListBox
 **/
