@@ -51,6 +51,13 @@ KDiskFreeWidget::~KDiskFreeWidget()
   mKdf->applySettings();
 }
 
+QString KDiskFreeWidget::quickHelp() const
+{
+    return i18n("<h3>Hardware Information</h3><br> All the information modules return information"
+    " about a certain aspect of your computer hardware or your operating system."
+    " Not all modules are available on all hardware architectures and/or operating systems.");
+}
+
 extern "C"
 {
   KCModule* create_kdf( QWidget *parent, const char * /*name*/ )
