@@ -1,6 +1,6 @@
   /*
 
-    $Id: kedit.cpp,v 1.157 2002/02/26 16:08:29 coolo Exp $
+    $Id: kedit.cpp,v 1.165 2002/09/30 14:37:08 dnaber Exp $
 
     Copyright (C) 1997 Bernd Johannes Wuebben
                        wuebben@math.cornell.edu
@@ -124,6 +124,9 @@ void TopLevel::setupEditWidget()
 	  SLOT(setEnabled(bool)));
   connect(eframe, SIGNAL(copyAvailable(bool)),copyAction,
 	  SLOT(setEnabled(bool)));
+  connect( eframe, SIGNAL(selectionChanged()),this,
+     SLOT(slotSelectionChanged()));
+
 
   undoAction->setEnabled(false);
   redoAction->setEnabled(false);
@@ -138,7 +141,7 @@ void TopLevel::setupEditWidget()
     eframe->setWordWrap(QMultiLineEdit::FixedColumnWidth);
     eframe->setWrapColumnOrWidth(mOptionState.misc.wrapColumn);
   }
-  else if( mOptionState.misc.wrapMode == SMiscState::dynamicWrap )
+  else if( mOptionState.misc.wrapMode == SMiscState::softWrap )
   {
     eframe->setWordWrap(QMultiLineEdit::WidgetWidth);
   }
@@ -175,6 +178,13 @@ void TopLevel::setupEditWidget()
   */
 }
 
+void TopLevel::slotSelectionChanged()
+{
+  bool state = eframe->hasSelectedText();
+  cutAction->setEnabled( state );
+  copyAction->setEnabled( state );
+}
+
 
 void TopLevel::setupActions()
 {
@@ -202,9 +212,9 @@ void TopLevel::setupActions()
     KStdAction::findNext(this, SLOT(search_again()), actionCollection());
     KStdAction::replace(this, SLOT(replace()), actionCollection());
 
-    (void)new KAction(i18n("&Insert File"), 0, this, SLOT(file_insert()),
+    (void)new KAction(i18n("&Insert File..."), 0, this, SLOT(file_insert()),
                       actionCollection(), "insert_file");
-    (void)new KAction(i18n("I&nsert Date"), 0, this, SLOT(insertDate()),
+    (void)new KAction(i18n("In&sert Date"), 0, this, SLOT(insertDate()),
                       actionCollection(), "insert_date");
     (void)new KAction(i18n("Cl&ean Spaces"), 0, this, SLOT(clean_space()),
                       actionCollection(), "clean_spaces");
@@ -863,7 +873,7 @@ void TopLevel::setMiscOption( const SMiscState &misc )
     eframe->setWordWrap(QMultiLineEdit::FixedColumnWidth);
     eframe->setWrapColumnOrWidth(mOptionState.misc.wrapColumn);
   }
-  else if( mOptionState.misc.wrapMode == SMiscState::dynamicWrap )
+  else if( mOptionState.misc.wrapMode == SMiscState::softWrap )
   {
     eframe->setWordWrap(QMultiLineEdit::WidgetWidth);
   }
@@ -992,7 +1002,7 @@ void TopLevel::print()
         dlg->setMainWidget(dlg_lbl);
         dlg->setInitialSize(QSize(300,120));
         dlg->show();
-     
+
         while(true) {
            QString lbl_txt = i18n("Printing page %1...").arg(page);
            dlg_lbl->setText(lbl_txt);
@@ -1005,7 +1015,7 @@ void TopLevel::print()
                printer->abort();
                break;
            }
-           headerRight = QString("#%1").arg(page); 
+           headerRight = QString("#%1").arg(page);
            dy = headerFontMetrics.lineSpacing();
            QRect body( 0, dy*2,  metrics.width(), metrics.height()-dy*2);
 
@@ -1017,26 +1027,28 @@ void TopLevel::print()
            pen.setWidth(3);
            p->setPen(pen);
 
-           p->drawLine(0, dy+dy/2, metrics.width(), dy+dy/2);    
+           p->drawLine(0, dy+dy/2, metrics.width(), dy+dy/2);
 
            int y = dy*2;
            while(lineCount < maxLineCount) {
               QString text = eframe->textLine(lineCount);
-              QRect r = p->boundingRect(0, y, body.width(), body.height(), 
+              if( text == "" )
+                text = " ";	// don't ignore empty lines
+              QRect r = p->boundingRect(0, y, body.width(), body.height(),
 			QPainter::ExpandTabs | QPainter::WordBreak, text);
 
               dy = r.height();
 
               if (y+dy > metrics.height()) break;
 
-              p->drawText(0, y, metrics.width(), metrics.height() - y, 
+              p->drawText(0, y, metrics.width(), metrics.height() - y,
                         QPainter::ExpandTabs | QPainter::WordBreak, text);
 
               y += dy;
               lineCount++;
            }
            if (lineCount >= maxLineCount)
-              break;  
+              break;
 
            printer->newPage();
            page++;
@@ -1233,6 +1245,7 @@ static bool backupFile( const QString &qFilename)
 int TopLevel::saveFile( const QString& _filename, bool backup, const QString& encoding )
 {
   QFileInfo info(_filename);
+  bool bSoftWrap = (mOptionState.misc.wrapMode == SMiscState::softWrap);
 
   if(info.isDir())
   {
@@ -1267,7 +1280,7 @@ int TopLevel::saveFile( const QString& _filename, bool backup, const QString& en
     codec = QTextCodec::codecForLocale();
   textStream.setCodec(codec);
 
-  eframe->saveText( &textStream );
+  eframe->saveText( &textStream, bSoftWrap );
   file.close();
 
   if(file.status())
@@ -1300,7 +1313,7 @@ void TopLevel::openURL( const KURL& _url, int _mode )
     else
     {
       if (_mode & OPEN_NEW == 0)
-      {     
+      {
          KMessageBox::error(this, i18n("Cannot download file!"));
          return;
       }
@@ -1498,6 +1511,7 @@ static const char *description=I18N_NOOP("A KDE Text Editor");
 
 static const KCmdLineOptions options[] =
 {
+	{ "encoding <encoding>", I18N_NOOP("Encoding to use for the following documents"), 0 },
 	{ "+file", I18N_NOOP("File or URL to Open"), 0 },
 	{ 0, 0, 0}
 };
@@ -1533,6 +1547,10 @@ int main (int argc, char **argv)
 		have_top_window = false;
 		KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
+		const QString encoding = args->getOption("encoding");
+		const bool doEncoding = args->isSet("encoding") &&
+		                        QTextCodec::codecForName(encoding.latin1());
+
 		for(int i = 0; i < args->count(); i++)
 		{
 			TopLevel *t = new TopLevel;
@@ -1540,6 +1558,10 @@ int main (int argc, char **argv)
 			have_top_window = true;
 
 			KURL url = args->url(i);
+
+			if(doEncoding)
+				url.setFileEncoding(encoding);
+
 			t->openURL( url, default_open | TopLevel::OPEN_NEW );
 		}
 		args->clear();
