@@ -1,7 +1,7 @@
 
 /*
 
-    $Id: floppy.cpp,v 1.48.2.1 2002/04/19 14:40:58 coolo Exp $
+    $Id: floppy.cpp,v 1.56 2002/07/20 12:15:40 lukas Exp $
 
     Copyright (C) 1997 Bernd Johannes Wuebben
                        wuebben@math.cornell.edu
@@ -33,7 +33,7 @@
 #include <kapplication.h>
 #include <kstandarddirs.h>
 #include <kmessagebox.h>
-
+#include <kdebug.h>
 
 FloppyData::FloppyData(QWidget * parent, const char * name)
  : KDialog( parent, name )
@@ -57,7 +57,7 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
         QGridLayout* g1 = new QGridLayout( v1, 3, 2 );
 
         label1 = new QLabel(this);
-	label1->setText(i18n("Floppy Drive:"));
+	label1->setText(i18n("Floppy drive:"));
         g1->addWidget( label1, 0, 0, AlignLeft );
 
 
@@ -81,13 +81,13 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
 
 
         label3 = new QLabel(this);
-	label3->setText(i18n("File System:"));
+	label3->setText(i18n("File system:"));
         g1->addWidget( label3, 2, 0, AlignLeft );
 
 	filesystemComboBox = new QComboBox( FALSE, this, "ComboBox_2" );
 	g1->addWidget( filesystemComboBox, 2, 1, AlignLeft );
 
-	filesystemComboBox->insertItem(i18n("Dos"));
+	filesystemComboBox->insertItem(i18n("DOS"));
 	filesystemComboBox->insertItem(i18n("ext2"));
 
         v1->addSpacing( 10 );
@@ -99,21 +99,21 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
         QVBoxLayout* v2 = new QVBoxLayout( buttongroup, 10 );
 
 	quick = new QRadioButton( buttongroup, "RadioButton_2" );
-	quick->setText(i18n( "Q&uick Format") );
+	quick->setText(i18n( "Q&uick format") );
         v2->addWidget( quick, AlignLeft );
 
 	fullformat = new QRadioButton( buttongroup, "RadioButton_3" );
-	fullformat->setText(i18n( "Fu&ll Format") );
+	fullformat->setText(i18n( "Fu&ll format") );
 	fullformat->setChecked(TRUE);
         v2->addWidget( fullformat, AlignLeft );
 
 	verifylabel = new QCheckBox( buttongroup, "RadioButton_4" );
-	verifylabel->setText(i18n( "&Verify Integrity" ));
+	verifylabel->setText(i18n( "&Verify integrity" ));
 	verifylabel->setChecked(TRUE);
 	v2->addWidget( verifylabel, AlignLeft );
 
 	labellabel = new QCheckBox( buttongroup, "RadioButton_4" );
-	labellabel->setText(i18n( "Volume &Label:") );
+	labellabel->setText(i18n( "Volume &label:") );
 	labellabel->setChecked(TRUE);
         v2->addWidget( labellabel, AlignLeft );
 
@@ -130,7 +130,7 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
 
 	QVBoxLayout* v3 = new QVBoxLayout( h1 );
 
-	formatbutton = new QPushButton( this, "PushButton_3" );
+	formatbutton = new KPushButton( this, "PushButton_3" );
 	formatbutton->setText(i18n( "&Format") );
 	formatbutton->setAutoRepeat( FALSE );
 	connect(formatbutton,SIGNAL(clicked()),this,SLOT(format()));
@@ -141,14 +141,12 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
 	//Setup the Help Menu
 	helpMenu = new KHelpMenu(this, KGlobal::instance()->aboutData(), false);
 
-	helpbutton = new QPushButton( this, "PushButton_4" );
-	helpbutton->setText(i18n( "&Help") );
+	helpbutton = new KPushButton( KStdGuiItem::help(), this );
 	helpbutton->setAutoRepeat( FALSE );
 	helpbutton->setPopup(helpMenu->menu());
 	v3->addWidget( helpbutton );
 
-	quitbutton = new QPushButton( this, "PushButton_1" );
-	quitbutton->setText(i18n( "&Quit") );
+	quitbutton = new KPushButton( KGuiItem( i18n( "&Quit" ), "exit" ), this );
 	quitbutton->setAutoRepeat( FALSE );
 	connect(quitbutton,SIGNAL(clicked()),this,SLOT(quit()));
 	 v3->addWidget( quitbutton );
@@ -201,6 +199,17 @@ void FloppyData::closeEvent(QCloseEvent*){
 
 }
 
+void FloppyData::keyPressEvent(QKeyEvent *e) {
+	switch(e->key()) {
+	case Qt::Key_F1:
+		kapp->invokeHelp();
+		break;
+	default:
+		KDialog::keyPressEvent(e);
+		return;
+	}
+}
+
 void FloppyData::show() {
   setCaption(i18n("KDE Floppy Formatter"));
   KDialog::show();
@@ -369,8 +378,8 @@ void FloppyData::format(){
     return;
   }
   if (!formating) {
-        if (KMessageBox::warningContinueCancel(0, "Formatting will erase all data on the disk.\n"
-        "Are you sure you wish to proceed?", "Proceed?" ) == KMessageBox::Continue)
+        if (KMessageBox::warningContinueCancel(0, i18n("Formatting will erase all data on the disk.\n"
+        "Are you sure you wish to proceed?"), i18n("Proceed?") ) == KMessageBox::Continue)
         {
 
   formatbutton->setText(i18n("A&bort"));
@@ -403,7 +412,7 @@ void FloppyData::format(){
     return;
   }
 
-  frame->setText(i18n("Formatting ..."));
+  frame->setText(i18n("Formatting..."));
   badblocks = 0;
   abort = false;
   formating = true;
@@ -478,9 +487,8 @@ void FloppyData::readStdout(KProcess *, char *buffer, int buflen)
     counter ++;
     progress->setValue(counter);     
   }
-#ifdef MY_DEBUG
-    printf("STDOUT:%s\n",mybuffer);
-#endif 
+
+  kdDebug(2002) << "STDOUT: " << formatstring << endl;
 }
 
 void FloppyData::readStderr(KProcess *, char *buffer, int buflen){
@@ -502,9 +510,8 @@ void FloppyData::readStderr(KProcess *, char *buffer, int buflen){
 
 
   errtimer->start(300,true);
-#ifdef MY_DEBUG
-  printf("STDERR:%s\n",mybuffer);
-#endif
+
+  kdDebug(2002) << "STDERR: " << mybuffer << endl;
 }
 
 void FloppyData::errslot(){
@@ -559,14 +566,12 @@ void FloppyData::readfsStdout(KProcess *, char *buffer, int buflen){
     QString mystring;
     mystring = newstring.left(i);
 
-#ifdef MY_DEBUG
-printf("NEWLINE:%s\n",mystring.data());
-#endif
+    kdDebug(2002) << "NEWLINE: " << mystring.data() << endl;
 
     if(findKeyWord(mystring,"BBF ")){
       int bblock = mystring.left(8).toInt();
       QString mstr;
-      mstr = i18n("Block %1 is bad. Continuing ...").arg(bblock);
+      mstr = i18n("Block %1 is bad. Continuing...").arg(bblock);
       frame->setText(mstr);
     }
 
@@ -577,9 +582,9 @@ printf("NEWLINE:%s\n",mystring.data());
   }
 
   counter += findKeyWord(fsstring,"BLOCK");
-#ifdef MY_DEBUG
-printf("Block Counter: %d\n",counter);  
-#endif
+
+  kdDebug(2002) << "Block Counter: " << counter << endl;
+
   if(quickerase){
 
     if(findKeyWord(fsstring,"START"))
@@ -594,9 +599,8 @@ printf("Block Counter: %d\n",counter);
   fsstring = newstring;
 
   progress->setValue(counter);     
-#ifdef MY_DEBUG
-  printf("STDOUT:%s\n",mybuffer);
-#endif
+
+  kdDebug(2002) << "STDOUT: " << mybuffer << endl;
 }
 
 
@@ -619,7 +623,6 @@ void FloppyData::readfsStderr(KProcess *, char *buffer, int buflen){
   if (fserrstring.isEmpty() && strncmp(mybuffer, "mke2fs", 6) == 0)
     {
       pos = QString(mybuffer).find('\n');
-      //printf("pos=%d, len=%d\n", pos, amount);
       if (pos+1 == amount)
 	return;
       pos++;
@@ -627,23 +630,18 @@ void FloppyData::readfsStderr(KProcess *, char *buffer, int buflen){
   if (fserrstring.isEmpty() && strncmp(mybuffer, "/sbin/mkdosfs", 13) == 0)
     {
       pos = QString(mybuffer).find('\n');
-      //printf("pos=%d, len=%d\n", pos, amount);
       if (pos+1 == amount)
 	return;
       pos++;
     }
 
-  //printf("ERR: <%s>\n", mybuffer);
-  //printf("pos=%d, len=%d\n", pos, amount);
-
   abort = true;
   fserrstring += mybuffer+pos;
 
   // the timers are put in so that I get all of the error message.
   fserrtimer->start(300,true);
-#ifdef MY_DEBUG
-  printf("STDERR:%s\n",mybuffer);
-#endif
+
+  kdDebug(2002) << "STDOUT: " << mybuffer << endl;
 }
 
 void FloppyData::fserrslot(){
@@ -732,11 +730,11 @@ void FloppyData::createfilesystem()
   fsstring = "";
   fserrstring = "";
 
-  frame->setText(i18n("Creating Filesystem ..."));
+  frame->setText(i18n("Creating Filesystem..."));
 
   proc = new KProcess;
 
-  if (filesystemComboBox->currentText() == i18n("Dos")){
+  if (filesystemComboBox->currentItem() == 0){
 
         *proc << mkdosfs;
 	if(labellabel->isChecked())
