@@ -18,11 +18,8 @@
  *
  */
 
-#include <qkeycode.h>
 #include <qpainter.h>
  
-#include <kapp.h>
-#include <kglobal.h>
 #include <kglobalsettings.h>
 
 #include "bitswapwidget.h"
@@ -101,13 +98,13 @@ void CDigitLabel::drawContents( QPainter *p )
 
   if( hasFocus() == true )
   {
-    p->fillRect( cr, palette().normal().highlight() );
-    p->setPen( palette().normal().highlightedText() );
+    p->fillRect( cr, palette().active().highlight() );
+    p->setPen( palette().active().highlightedText() );
   }
   else
   {
-    p->fillRect( cr, palette().normal().base() );
-    p->setPen( palette().normal().text() );
+    p->fillRect( cr, palette().active().base() );
+    p->setPen( palette().active().text() );
   }
 
   if( mDotPosition != 0 )
@@ -323,3 +320,4 @@ bool CByteWidget::flag( QByteArray &buf )
 }
 
 
+#include "bitswapwidget.moc"
