@@ -38,7 +38,7 @@
 #include "hexeditorwidget.h"
 #include "hexerror.h"
 #include "optiondialog.h"
-#include "printerdialog.h"
+#include "printdialogpage.h"
 #include "stringdialog.h"
 
 
@@ -78,7 +78,6 @@ CHexEditorWidget::CHexEditorWidget( QWidget *parent, const char *name )
   mInsertDialog    = 0;
   mFilterDialog    = 0;
   mOptionDialog    = 0;
-  mPrintDialog     = 0;
   mStringDialog    = 0;
   mCharTableDialog = 0;
   mFileInfoDialog  = 0;
@@ -97,7 +96,6 @@ CHexEditorWidget::~CHexEditorWidget( void )
   delete mInsertDialog;
   delete mFilterDialog;
   delete mOptionDialog;
-  delete mPrintDialog;
   delete mStringDialog;
   delete mCharTableDialog;
   delete mFileInfoDialog;
@@ -212,11 +210,6 @@ void CHexEditorWidget::writeConfiguration( KConfig &config )
   config.writeEntry( "ShowBookmarkInOffsetColumn", misc.bookmarkOffsetColumn );
   config.writeEntry( "ShowBookmarkInEditor", misc.bookmarkEditor );
 
-  if( mPrintDialog != 0 )
-  {
-    mPrintDialog->writeConfiguration();
-  }
-
   if( mExportDialog != 0 )
   {
     mExportDialog->writeConfiguration();
@@ -609,7 +602,7 @@ void CHexEditorWidget::newFile( void )
   if( errCode != Err_Success )
   {
     QString msg = i18n("Unable to create new document.");
-    KMessageBox::sorry( topLevelWidget(), msg, i18n("Operation failed") );
+    KMessageBox::sorry( topLevelWidget(), msg, i18n("Operation Failed") );
     return;
   }
 
@@ -1060,16 +1053,42 @@ void CHexEditorWidget::reload( void )
 
 void CHexEditorWidget::print( void )
 {
-  if( mPrintDialog == 0 )
+  CHexPrinter prt;
+  prt.addDialogPage( new LayoutDialogPage() );
+  prt.setPageSelection( KPrinter::SystemSide );
+
+  if (prt.setup(topLevelWidget()))
   {
-    mPrintDialog = new CPrinterDialog( topLevelWidget(), 0, false );
-    if( mPrintDialog == 0 ) { return; }
-    connect( mPrintDialog, SIGNAL( printPostscript(CHexPrinter &)),
-	     SLOT( printPostscript( CHexPrinter &)) );
-    connect( mPrintDialog, SIGNAL( printText(CHexPrinter & )),
-	     SLOT( printText( CHexPrinter & )) );
+     prt.setAsText( false  );
+     prt.setFullPage( true ); // I use my own marings
+     prt.setPrintBackWhite( false );
+     prt.setScaleToFit( true );
+
+     prt.setTopMarginMM( prt.option("kde-khexedit-topmarginmm").toInt() );
+     prt.setBottomMarginMM( prt.option("kde-khexedit-bottommarginmm").toInt() );
+     prt.setLeftMarginMM( prt.option("kde-khexedit-leftmarginmm").toInt() );
+     prt.setRightMarginMM( prt.option("kde-khexedit-rightmarginmm").toInt() );
+
+     prt.setPageHeader( (prt.option("kde-khexedit-headercheck") == "true"),
+			  prt.option("kde-khexedit-headercombo0").toInt(),
+			  prt.option("kde-khexedit-headercombo1").toInt(),
+			  prt.option("kde-khexedit-headercombo2").toInt(),
+			  prt.option("kde-khexedit-headercombo3").toInt() );
+
+     prt.setPageFooter( (prt.option("kde-khexedit-footercheck") == "true"),
+			  prt.option("kde-khexedit-footercombo0").toInt(),
+			  prt.option("kde-khexedit-footercombo1").toInt(),
+			  prt.option("kde-khexedit-footercombo2").toInt(),
+			  prt.option("kde-khexedit-footercombo3").toInt() );
+
+     prt.setAll( true );
+     prt.setSelection( false );
+     prt.setRange( false );
+     prt.setFromTo( prt.minPage(), prt.maxPage() );
+
+     printPostscript(prt);
   }
-  mPrintDialog->show();
+
 }
 
 
@@ -1108,58 +1127,6 @@ void CHexEditorWidget::printPostscript( CHexPrinter &printer )
 }
 
 
-void CHexEditorWidget::printText( CHexPrinter &printer )
-{
-  if( confirmPrintPageNumber( printer ) == false )
-  {
-    return;
-  }
-
-  SExportRange range;
-  if( printer.all() == true )
-  {
-    range.mode = SExportRange::All;
-  }
-  else if( printer.selection() == true )
-  {
-    range.mode = SExportRange::Selection;
-  }
-  else
-  {
-    range.mode  = SExportRange::Range;
-    range.start = printer.startRange();
-    range.stop  = printer.stopRange();
-  }
-
-  if( printer.outputToFile() == false )
-  {
-    QString msg = i18n(""
-      "Not available yet!\n"
-      "Print plain text to printer" );
-    KMessageBox::sorry( topLevelWidget(), msg, i18n("Print") );
-    return;
-  }
-
-  SExportText ex;
-  ex.range    = range;
-  ex.destFile = printer.outputFileName();
-
-  int errCode = prepareProgressData( pg_print );
-  if( errCode == Err_Success )
-  {
-    errCode = mHexView->exportText( ex, mProgressData );
-  }
-
-  if( errCode != Err_Success )
-  {
-    QString msg = i18n("Unable to write data.\n");
-    msg += hexError( errCode );
-    KMessageBox::sorry( topLevelWidget(), msg, i18n("Print") );
-  }
-
-}
-
-
 bool CHexEditorWidget::confirmPrintPageNumber( CHexPrinter &printer )
 {
   if( mDisplayState.misc.confirmThreshold == true )
@@ -1168,9 +1135,13 @@ bool CHexEditorWidget::confirmPrintPageNumber( CHexPrinter &printer )
     if( numPage > mDisplayState.misc.thresholdValue )
     {
       QString msg = i18n(
-        "Print threshold excceded.\n"
-        "You are about to print %1 pages.\n"
-	"Procceed?").arg( numPage );
+        "<qt>Print threshold exceeded.<br>"
+        "You are about to print one page.<br>"
+	"Proceed?</qt>",
+        "<qt>Print threshold exceeded.<br>"
+        "You are about to print %n pages.<br>"
+	"Proceed?</qt>",
+	numPage );
       int reply = KMessageBox::warningYesNo( topLevelWidget(), msg,
 					     i18n("Print") );
       if( reply != KMessageBox::Yes )
@@ -1783,24 +1754,13 @@ void CHexEditorWidget::replaceResult( SSearchControl &sc )
     {
       msg += i18n( "Search key not found in document." );
     }
-    KMessageBox::information( topLevelWidget(), msg, i18n("Find and replace"));
+    KMessageBox::information( topLevelWidget(), msg, i18n("Find and Replace"));
   }
   else
   {
     QString msg( i18n( "Operation complete.\n\n" ) );
-    if( sc.numReplace == 0 )
-    {
-      msg += i18n( "No replacements were made.");
-    }
-    else if( sc.numReplace == 1 )
-    {
-      msg += i18n( "One replacement was made.");
-    }
-    else
-    {
-      msg += i18n( "%1 replacements were made.").arg(sc.numReplace);
-    }
-    KMessageBox::information( topLevelWidget(), msg, i18n("Find and replace"));
+    msg += i18n( "One replacement was made.","%n replacements were made.",sc.numReplace);
+    KMessageBox::information( topLevelWidget(), msg, i18n("Find and Replace"));
   }
 }
 
@@ -1858,7 +1818,7 @@ void CHexEditorWidget::collectStrings( void )
   {
     QString msg = i18n("Could not collect strings.\n");
     msg += hexError( errCode );
-    KMessageBox::sorry( topLevelWidget(), msg, i18n("Collect strings") );
+    KMessageBox::sorry( topLevelWidget(), msg, i18n("Collect Strings") );
   }
 
 }
@@ -1870,7 +1830,7 @@ void CHexEditorWidget::recordView( void )
   QString msg = i18n(""
    "Not available yet!\n"
    "Define a record (structure) and fill it with data from the document." );
-  KMessageBox::sorry( topLevelWidget(), msg, i18n("Record viewer") );
+  KMessageBox::sorry( topLevelWidget(), msg, i18n("Record Viewer") );
 }
 
 void CHexEditorWidget::filter( void )
@@ -1945,7 +1905,7 @@ void CHexEditorWidget::collectStatistics( SStatisticControl &sc )
     QString msg = i18n("Could not collect document statistics.\n");
     msg += hexError( errCode );
     KMessageBox::sorry( topLevelWidget(), msg,
-			i18n("Collect document statistics") );
+			i18n("Collect Document Statistics") );
   }
 
 }
@@ -1991,7 +1951,6 @@ void CHexEditorWidget::favorites( void )
 }
 
 
-
 int CHexEditorWidget::readURL( const QString &url, bool insert )
 {
   //
@@ -2035,7 +1994,8 @@ int CHexEditorWidget::readURL( const QString &url, bool insert )
     QString symbolicName( kurl.url() );
 //    KURL::decode( symbolicName );
 
-    bool success = readFile( kurl.path(), symbolicName, insert );
+    kurl.setProtocol( QString::null );
+    bool success = readFile( KURL::decode_string( kurl.url() ), symbolicName, insert );
     return( success == true ? Err_Success : Err_ReadFailed );
   }
   else
@@ -2261,14 +2221,14 @@ bool CHexEditorWidget::writeFile( QString &diskPath )
     if( info.isDir() == true )
     {
       QString msg = i18n("You have specified a directory.");
-      KMessageBox::sorry( topLevelWidget(), msg, i18n("Write failure") );
+      KMessageBox::sorry( topLevelWidget(), msg, i18n("Write Failure") );
       return( false );
     }
 
     if( info.isWritable() == false )
     {
       QString msg = i18n("You do not have write permission.");
-      KMessageBox::sorry( topLevelWidget(), msg, i18n("Write failure") );
+      KMessageBox::sorry( topLevelWidget(), msg, i18n("Write Failure") );
       return( false );
     }
   }
@@ -2277,7 +2237,7 @@ bool CHexEditorWidget::writeFile( QString &diskPath )
   if( file.open( IO_WriteOnly | IO_Raw | IO_Truncate ) == false )
   {
     QString msg = i18n("An error occured while trying to open the file.");
-    KMessageBox::sorry( topLevelWidget(), msg, i18n("Write failure") );
+    KMessageBox::sorry( topLevelWidget(), msg, i18n("Write Failure") );
     return( false );
   }
 
@@ -2290,7 +2250,7 @@ bool CHexEditorWidget::writeFile( QString &diskPath )
   {
     QString msg = i18n("Could not write data to disk.\n");
     msg += hexError( errCode );
-    KMessageBox::sorry( topLevelWidget(), msg, i18n("Write failure") );
+    KMessageBox::sorry( topLevelWidget(), msg, i18n("Write Failure") );
   }
 
   file.close();
@@ -2372,7 +2332,7 @@ bool CHexEditorWidget::createBuffer( void )
   {
     QString msg = i18n( "Can not create text buffer.\n" );
     msg += hexError( Err_NoMemory );
-    KMessageBox::error( topLevelWidget(), msg, i18n("Loading failed" ) );
+    KMessageBox::error( topLevelWidget(), msg, i18n("Loading Failed" ) );
     return( false );
   }
 
