@@ -21,7 +21,7 @@
 #ifndef _HEX_PRINTER_H_
 #define _HEX_PRINTER_H_
 
-#include <kprinter.h> 
+#include <kprinter.h>
 #include <qpaintdevicemetrics.h> 
 
 struct SPageSize
@@ -68,12 +68,11 @@ class CHexPrinter : public KPrinter
 {
   public:
     CHexPrinter( void );
-  
+
     void setAsText( bool state );
     void setAll( bool state );
     void setSelection( bool state );
     void setRange( bool state, uint start=0, uint stop=0 );
-    void setOutputToStdout( bool state );
     void setScaleToFit( bool state );
     void setPrintBackWhite( bool state );
     void setPageMarginMM( uint top, uint bottom, int right, int left );
@@ -107,7 +106,6 @@ class CHexPrinter : public KPrinter
     bool mAll;
     bool mInSelection;
     bool mInRange;
-    bool mOutputToStdout;
     bool mScaleToFit;
     bool mPrintBlackWhite;
     uint mStartOffset;
@@ -142,17 +140,12 @@ inline bool CHexPrinter::range( void )
 
 inline uint CHexPrinter::startRange( void )
 {
-  return( mStartOffset );
+  return( fromPage() /*mStartOffset*/ );
 }
 
 inline uint CHexPrinter::stopRange( void )
 {
-  return( mStopOffset );
-}
-
-bool CHexPrinter::outputToStdout( void )
-{
-  return( mOutputToStdout );
+  return( toPage() /*mStopOffset*/ );
 }
 
 inline bool CHexPrinter::scaleToFit( void )
