@@ -1130,7 +1130,7 @@ void CHexViewWidget::removeBookmark( bool all )
   }
   else
   {
-    int position = bookmarkMenu( QString(i18n("Remove bookmark")) );
+    int position = bookmarkMenu( QString(i18n("Remove Bookmark")) );
     if( position < 0 )
     {
       return;
@@ -1160,7 +1160,7 @@ void CHexViewWidget::replaceBookmark( void )
     return;
   }
 
-  int position = bookmarkMenu( QString(i18n("Replace bookmark")) );
+  int position = bookmarkMenu( QString(i18n("Replace Bookmark")) );
   if( position < 0 )
   {
     return;
