@@ -31,7 +31,7 @@
 #include <qpopupmenu.h> 
 #include <qscrollbar.h> 
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kcmenumngr.h>
 
 #include "hexclipboard.h"
