@@ -30,7 +30,7 @@
 #include "version.h" // Contains khexedit name string and version string
 
 
-static const char *description = 
+static const char *description =
 	I18N_NOOP("KDE Hex editor");
 
 static const char *version = APP_VERSION_STRING;
@@ -47,16 +47,26 @@ static uint parseDecimalOrHexadecimal( char *buf );
 int main( int argc, char **argv )
 {
   KAboutData aboutData("khexedit", I18N_NOOP("KHexEdit"),
-    version, description, KAboutData::License_GPL,
-    "(c) 1999-2000, Espen Sand",
-    I18N_NOOP("This is a work in progress. If you\n\n"
-    "1. have a suggestion for improvement\n"
-    "2. have found a bug\n"
-    "3. want to contribute with something\n"
-    "4. just want to tell me how nice or useful khexedit is\n\n"
-    "then feel free to send me a mail.") );
-  aboutData.addAuthor("Espen Sand",0, "espensa@online.no", 
+    version, description, KAboutData::License_GPL_V2,
+    "(c) 1999-2000, Espen Sand");
+  aboutData.addAuthor("Espen Sand",0, "espensa@online.no",
 		      "http://home.sol.no/~espensa/khexedit/" );
+  aboutData.addCredit("",I18N_NOOP("\n"
+    "This program uses modified code and techniques from other KDE programs,\n"
+    "specifically kwrite, kiconedit and ksysv. Credit goes to authors\n"
+    "and maintainers.\n"
+    "\n"
+    "Leon Lessing, leon@lrlabs.com, has made parts of the bit swapping\n"
+    "functionality.\n"
+    "\n"
+    "Craig Graham, c_graham@hinge.mistral.co.uk, has made parts of\n"
+    "the bit stream functionality of the conversion field.\n"
+    "\n"
+    "Dima Rogozin, dima@mercury.co.il, has extended the string dialog\n"
+    "list capabilities.\n"
+    "\n"
+    "Edward Livingston-Blade, sbcs@bigfoot.com, has given me very good\n"
+    "reports which removed some nasty bugs.\n"));
   KCmdLineArgs::init( argc, argv, &aboutData );
   KCmdLineArgs::addCmdLineOptions( option );
 
