@@ -34,7 +34,6 @@
 #include <ktoolbarbutton.h>
 #include <kdebug.h>
 
-#include "aboutdialog.h"
 #include "dialog.h"
 #include "draglabel.h"
 #include "hexerror.h"
@@ -44,7 +43,7 @@
 QPtrList<KHexEdit> KHexEdit::mWindowList;
 
 KHexEdit::KHexEdit( void )
-  : KMainWindow(0, "toplevel"), mStartupOffset(0), mAboutKHexEdit(0),
+  : KMainWindow(0, "toplevel"), mStartupOffset(0),
   mIsModified(0)
 {
   mWindowList.append( this );
@@ -114,7 +113,6 @@ KHexEdit::KHexEdit( void )
 
 KHexEdit::~KHexEdit( void )
 {
-  delete mAboutKHexEdit;
   delete mManager;
 }
 
@@ -169,9 +167,9 @@ void KHexEdit::setupActions( void )
 
   mAction.copyAsText = new KAction( i18n("Copy as &Text"), 0,
     editor(), SLOT(copyText()), actionCollection() );
-  mAction.pasteToNewFile = new KAction( i18n("Paste Into New &File"), 0,
+  mAction.pasteToNewFile = new KAction( i18n("Paste into New &File"), 0,
     editor(), SLOT(pasteNewFile()), actionCollection() );
-  mAction.pasteToNewWindow = new KAction( i18n("Paste Into New &Window"), 0,
+  mAction.pasteToNewWindow = new KAction( i18n("Paste into New &Window"), 0,
     this, SLOT(pasteNewWindow()), actionCollection() );
 
   mAction.insert->setAccel( CTRL+Key_I );
@@ -219,31 +217,31 @@ void KHexEdit::setupActions( void )
 
   mAction.strings = new KAction( i18n("&Extract Strings..."), 0,
     editor(), SLOT(strings()), actionCollection() );
-  mAction.recordViewer = new KAction( i18n("&Record Viewer..."), 0,
+  mAction.recordViewer = new KAction( i18n("&Record Viewer"), 0,
     editor(), SLOT(recordView()), actionCollection() );
   mAction.filter = new KAction( i18n("&Binary Filter..."), 0,
     editor(), SLOT(filter()), actionCollection() );
-  mAction.characterTable = new KAction( i18n("&Character Table..."), 0,
+  mAction.characterTable = new KAction( i18n("&Character Table"), 0,
     editor(), SLOT(chart()), actionCollection() );
-  mAction.converter = new KAction( i18n("C&onverter..."), 0,
+  mAction.converter = new KAction( i18n("C&onverter"), 0,
     editor(), SLOT(converter()), actionCollection() );
-  mAction.statistics = new KAction( i18n("&Statistics..."), 0,
+  mAction.statistics = new KAction( i18n("&Statistics"), 0,
     editor(), SLOT(statistics()), actionCollection() );
 
   mAction.addBookmark = KStdAction::addBookmark( editor(),
     SLOT(addBookmark()), actionCollection() );
   mAction.replaceBookmark = new KAction( i18n("&Replace Bookmark"), CTRL+Key_E,
-    editor(), SLOT(replaceBookmark()), actionCollection() );
+    editor(), SLOT(replaceBookmark()), actionCollection(), "replace_bookmark");
   mAction.removeBookmark = new KAction( i18n("R&emove Bookmark"), CTRL+Key_U,
-    editor(), SLOT(removeBookmark()), actionCollection() );
+    editor(), SLOT(removeBookmark()), actionCollection(), "remove_bookmark" );
   mAction.removeAllBookmark = new KAction( i18n("Re&move All"), 0,
     editor(), SLOT(removeAllBookmark()), actionCollection() );
   mAction.nextBookmark = new KAction( i18n("Goto &Next Bookmark"),
 				      ALT+Key_Down, editor(),
-				      SLOT(gotoNextBookmark()), actionCollection() );
+				      SLOT(gotoNextBookmark()), actionCollection(), "next_bookmark" );
   mAction.prevBookmark = new KAction( i18n("Goto &Previous Bookmark"),
 				      ALT+Key_Up, editor(),
-				      SLOT(gotoPrevBookmark()), actionCollection() );
+				      SLOT(gotoPrevBookmark()), actionCollection(), "prev_bookmark" );
 
   mAction.showToolBar = KStdAction::showToolbar( this, SLOT(showToolBar()),
     actionCollection() );
@@ -403,8 +401,8 @@ void KHexEdit::setupActions( void )
   mAction.encodingMenu->insert( mAction.defaultEncoding );
   mAction.encodingMenu->insert( mAction.usAsciiEncoding );
   mAction.encodingMenu->insert( mAction.ebcdicEncoding );
-  mAction.encodingMenu->insert( mAction.separator );
-  mAction.encodingMenu->insert( mAction.customEncoding );
+//  mAction.encodingMenu->insert( mAction.separator );
+//  mAction.encodingMenu->insert( mAction.customEncoding );
   // View-encoding-Stop
   mAction.viewMenu->insert( mAction.encodingMenu );
 
@@ -469,7 +467,7 @@ void KHexEdit::setupActions( void )
   mAction.documentsMenu->plug( menuBar() );
   mAction.settingsMenu->plug( menuBar() );
   mAction.separator->plug( menuBar() );
-  menuBar()->insertItem( i18n("&Help"), customHelpMenu() );
+  menuBar()->insertItem( i18n("&Help"), helpMenu(0, false) );
 
   //
   // Make the toolbar
@@ -1675,25 +1673,6 @@ void KHexEdit::searchBarClosed( void )
 }
 
 
-void KHexEdit::showAboutApplication( void )
-{
-  if( mAboutKHexEdit == 0 )
-  {
-    mAboutKHexEdit = new CAboutKHexEdit( topLevelWidget(), 0, false );
-    if( mAboutKHexEdit == 0 ) { return; }
-  }
-
-  if( mAboutKHexEdit->isVisible() == false )
-  {
-    mAboutKHexEdit->show();
-  }
-  else
-  {
-    mAboutKHexEdit->raise();
-  }
-}
-
-
 bool KHexEdit::eventFilter( QObject *o, QEvent *event )
 {
   if( event->type() == QEvent::DragEnter )
