@@ -19,10 +19,14 @@
 //  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qobjectlist.h>
-#include <qclipboard.h>
-#include <qtimer.h>
+#include <qbuttongroup.h>
 #include <qcursor.h>
+#include <qobjectlist.h>
+#include <qdatetime.h>
+#include <qlabel.h>
+#include <qpainter.h>
+#include <qpaintdevicemetrics.h>
+#include <qtimer.h>
 
 #include <kaccel.h>
 #include <kaction.h>
@@ -33,26 +37,23 @@
 #include <kdebug.h>
 #include <kpopupmenu.h>
 #include <kkeydialog.h>
+#include <klineeditdlg.h>
 #include <klocale.h>
 #include <kmenubar.h>
 #include <kmessagebox.h>
 #include <kopenwith.h>
+#include <kpopupmenu.h>
 #include <krun.h>
 #include <kstandarddirs.h>
 #include <kurl.h>
-
-extern "C" {
-#include <unistd.h>
-#include <stdlib.h>
-};
+#include <keditcl.h>
+#include <klocale.h>
+#include <kprinter.h>
+#include <kglobal.h>
 
 #include "KJotsMain.h"
 #include "SubjList.h"
-// #include "ReadListConf.h"
-#include "cpopmenu.h"
 #include "optiondialog.h"
-#include <klocale.h>
-#include <qlabel.h>
 
 
 #define KJOTSVERSION "0.4"
@@ -61,127 +62,166 @@ const unsigned int HOT_LIST_SIZE = 8;
 const unsigned int BUTTON_WIDTH = 56;
 
 
-//----------------------------------------------------------------------
-// ASKFILENAME
-//----------------------------------------------------------------------
-AskFileName::AskFileName(QWidget* parent, const char* name)
-  : KDialogBase( parent, name, TRUE, i18n("New Book"), Ok|Cancel, Ok )
-{
-  QFrame *page = makeMainWidget();
-  QVBoxLayout *vlay = new QVBoxLayout( page, 0, spacingHint() );
-
-  QLabel *label = new QLabel( i18n("Book name:"), page );
-  vlay->addWidget(label);
-
-  i_name = new QLineEdit( page );
-  i_name->setMinimumWidth( fontMetrics().maxWidth()*20 );
-  i_name->setFocus();
-  vlay->addWidget(i_name );
-  connect(i_name, SIGNAL(textChanged(const QString &)),
-	  this, SLOT(textChanged(const QString &)));
-
-  vlay->addStretch( 10 );
-
-  enableButtonOK( false );
-}
-
-void AskFileName::textChanged(const QString &s)
-{
-  enableButtonOK( s.length() > 0 );
-}
-
-
 //----------------------------------------------------------------------
 // MYMULTIEDIT
 //----------------------------------------------------------------------
 MyMultiEdit::MyMultiEdit (QWidget* parent, const char* name)
-  : KEdit(parent, name)
+  : KTextEdit(parent, name),
+   mSearchDialog(0),
+   mReplaceDialog(0)
 {
   setWordWrap(QTextEdit::WidgetWidth);
-  web_menu = new CPopupMenu;
+  web_menu = new KPopupMenu(this);;
   web_menu->insertItem(i18n("Open URL"), this, SLOT(openUrl()) );
 }
 
-void MyMultiEdit::keyPressEvent( QKeyEvent *e )
+MyMultiEdit::~MyMultiEdit ()
 {
-  if( e->key() == Key_Tab )
+  delete mReplaceDialog;
+}
+
+void MyMultiEdit::search()
+{
+    if (!mSearchDialog)
     {
-      int line, col;
-      getCursorPosition(&line, &col);
-      KEdit::insertAt("\t", line, col);
-      return;
+        mSearchDialog = new KEdFind(this);
+        connect(mSearchDialog, SIGNAL(search()), this, SLOT(slotSearch()));
+    }
+    mSearchDialog->show();
+}
+
+void MyMultiEdit::repeatSearch()
+{
+    if (mSearchFor == QString::null)
+    {
+        return;
+    }
+    
+    int para = 0;
+    int index = 0;
+    getCursorPosition(&para, &index);
+    removeSelection();
+
+    if (find(mSearchFor, mSearchDialog->case_sensitive(), false, !mSearchDialog->get_direction(), &para, &index))
+    {
+        setSelection(para, index, para, index + mSearchFor.length());
+    }
+    else
+    {
+        if (KMessageBox::questionYesNo(this, i18n("End of page reached.\n\nContinue from beginning of page?")) == KMessageBox::Yes)
+        {
+            setCursorPosition(0, 0);
+            repeatSearch();
+        }
+    }
+ }
+
+void MyMultiEdit::slotSearch()
+{
+    int para = 0;
+    int index = 0;
+    getCursorPosition(&para, &index);
+    mSearchFor = mSearchDialog->getText();
+    removeSelection();
+
+    if (find(mSearchFor, mSearchDialog->case_sensitive(), false, !mSearchDialog->get_direction(), &para, &index))
+    {
+         setSelection(para, index, para, index + mSearchFor.length());
+    }
+    else
+    {
+        if (KMessageBox::questionYesNo(this, i18n("End of page reached.\n\nContinue from beginning of page?")) == KMessageBox::Yes)
+        {
+            setCursorPosition(0, 0);
+            slotSearch();
+        }
+        else
+        {
+            mSearchDialog->hide();
+        }
     }
-  KEdit::keyPressEvent(e);
-  return;
 }
 
 void MyMultiEdit::mousePressEvent( QMouseEvent *e )
 {
-  if(e->button() == RightButton)
+  if(e->button() == RightButton &&
+     hasSelectedText())
   {
-    if(hasMarkedText())
-  	{
-      KURL url(markedText());
+      KURL url(selectedText());
 
       if(url.isValid())
       {
-  	    web_menu->popup(QCursor::pos());
-	    }
+         web_menu->popup(QCursor::pos());
+     }
       
       return;
-  	}
   }
 
-  KEdit::mousePressEvent(e);
+  KTextEdit::mousePressEvent(e);
 }
 
 void MyMultiEdit::openUrl()
 {
-  if(hasMarkedText())
+  if (hasSelectedText())
   {
-    KURL url(markedText());
+    KURL url(selectedText());
     if(url.isValid())
     {
-	     KFileOpenWithHandler fowh;	  
-      (void) new KRun(url);
+      KFileOpenWithHandler fowh;  
+      new KRun(url);
     }
   }
 }
 
-//----------------------------------------------------------------------
-// MYBUTTONGROUP
-//----------------------------------------------------------------------
-
-MyButtonGroup::MyButtonGroup (QWidget* parent, const char* name)
-  : QButtonGroup(parent, name)
+void MyMultiEdit::print(QString title)
 {
-}
+    KPrinter printer;
+    printer.setDocName(title);
+    printer.setFullPage(false);
+    printer.setCreator("KJots");
 
-void MyButtonGroup::resizeEvent( QResizeEvent * )
-{
-  int x = width()-2;
-  QObjectList  *list = queryList( "QPushButton" );
-  QObjectListIt it( *list );
-  while ( it.current() ) {
-    x -= (BUTTON_WIDTH+4);
-    ((QPushButton *) it.current())->move(x, 4);
-    ++it;
-  }
-  delete list;
+    if (printer.setup(this))
+    {
+        QFont printFont = font();
+        QPainter painter( &printer );
+        QPaintDeviceMetrics metrics( &printer );
+        int y = 0;
+        int maxWidth = metrics.width();
+        int maxHeight = metrics.height();
+        QString currentParagraph;
+
+        for (int paragraphCount = 0; paragraphCount < paragraphs(); ++paragraphCount )
+        {
+            currentParagraph = text(paragraphCount);
+            QRect r = painter.boundingRect(0, y, maxWidth, maxHeight,
+                                                                QPainter::ExpandTabs | QPainter::WordBreak, currentParagraph);
+
+            if ((y + r.height()) > maxHeight)
+            {
+                printer.newPage();
+                y = 0;
+            }
+
+            painter.drawText(0, y, maxWidth, maxHeight - y,
+                                        QPainter::ExpandTabs | QPainter::WordBreak, currentParagraph);
+            y += r.height();
+        }
+        painter.end();
+    }
 }
 
 //----------------------------------------------------------------------
 // KJOTSMAIN
 //----------------------------------------------------------------------
-
 KJotsMain::KJotsMain(const char* name)
-  : KMainWindow( 0, name )
+  : KMainWindow( 0, name ),
+    current(0),
+    currentFolder(0),
+    currentFolderID(0),
+    folderOpen(false),
+    unique_id(0),
+    mOptionDialog(0)
 {
-  mOptionDialog = 0;
-  folderOpen    = FALSE;
-  current       = 0;
-  unique_id     = 0;
-
   //
   // Main widget
   //
@@ -214,49 +254,62 @@ KJotsMain::KJotsMain(const char* name)
   me_text = new MyMultiEdit( f_text, "me_text" );
   me_text->setMinimumWidth( fontMetrics().maxWidth()*40 );
   me_text->setFocusPolicy(QWidget::StrongFocus);
-  me_text->setEnabled(FALSE);
-
+  me_text->setEnabled(false);
+  
+  QLabel* l_book = new QLabel( f_labels, "l_book" );
+  l_book->setText(i18n("Book:"));
+  
   l_folder = new QLabel( f_labels, "Label_4" );
   l_folder->setFrameStyle( QFrame::WinPanel | QFrame::Sunken );
   QFont font_label(l_folder->fontInfo().family());
-  font_label.setBold(TRUE);
+  font_label.setBold(true);
   l_folder->setFont(font_label);
 
+  QLabel* l_subject = new QLabel( f_labels, "l_subject" );
+  l_subject->setText(i18n("Page title:"));
   le_subject = new QLineEdit( f_labels, "le_subject" );
   le_subject->setFocusPolicy(QWidget::ClickFocus);
-  le_subject->setEnabled(FALSE);
+  le_subject->setEnabled(false);
 
   l_folder->setMinimumWidth( fontMetrics().maxWidth()*8 );
   l_folder->setFixedHeight( le_subject->sizeHint().height() );
 
-  bg_top = new MyButtonGroup( f_main, "ButtonGroup_2" );
-  QPushButton tp(0, "Test");
-  bg_top->setFixedHeight( tp.sizeHint().height()+8 );
-  bg_top->setMinimumWidth( HOT_LIST_SIZE * (BUTTON_WIDTH+4) + 6 );
+  // create the hotlist
+  QPushButton tp(0, "Test Button");
+  bg_top = new QButtonGroup(i18n("Hotlist"), f_main, "ButtonGroup_2");
   bg_top->setFrameStyle( QFrame::Box | QFrame::Sunken );
-  bg_top->setExclusive(TRUE);
+  bg_top->setExclusive(true);
+  bg_top->setMinimumHeight( tp.sizeHint().height() + 6 );
 
+  // set up the layout for the hotlist
+  QHBoxLayout* tempLayout = new QHBoxLayout(bg_top, KDialog::spacingHint());
+  bg_top_layout = new QHBoxLayout(bg_top, KDialog::spacingHint());
+  bg_top_layout->setMargin(KDialog::marginHint());
+  tempLayout->addLayout(bg_top_layout);
+  tempLayout->addItem(new QSpacerItem(30, 20, QSizePolicy::Expanding, QSizePolicy::Minimum ));
   //
   // Put data widgets into layouts
   //
   QVBoxLayout *l1 = new QVBoxLayout(f_text, 0, 0);
   l1->addWidget(me_text);
-
+  
   QHBoxLayout *l2 = new QHBoxLayout(f_labels);
+  l2->addWidget(l_book);
   l2->addWidget(l_folder);
+  l2->addItem(new QSpacerItem(30, 20, QSizePolicy::Fixed, QSizePolicy::Minimum ));
+  l2->addWidget(l_subject);
   l2->addWidget(le_subject, 1 );
 
   QVBoxLayout *tl = new QVBoxLayout(f_main, 4);
+  tl->addWidget(f_labels);
   tl->addWidget(f_text, 1);
   tl->addWidget(s_bar);
   tl->addWidget(bg_top);
-  tl->addWidget(f_labels);
 
 
-
-  entrylist.setAutoDelete(TRUE);
+  entrylist.setAutoDelete(true);
   entrylist.append(new TextEntry);
-  button_list.setAutoDelete(TRUE);
+  button_list.setAutoDelete(true);
 
   subj_list = new SubjList( topLevelWidget(), 0, false );
   connect( this, SIGNAL(folderChanged(QPtrList<TextEntry> *)),
@@ -284,7 +337,7 @@ KJotsMain::KJotsMain(const char* name)
   QStringList files = dir.entryList(QDir::Files |  QDir::Readable); // config->readListEntry( "Folders" );
 
   // create hotlist buttons and hotlist menu
-  folders_menu = new QPopupMenu;
+  folders_menu = new QPopupMenu(this);
   QPushButton *temp_button;
   for ( QStringList::Iterator it = files.begin();
         it != files.end();
@@ -304,16 +357,21 @@ KJotsMain::KJotsMain(const char* name)
       continue;
     }
     
-    QString decodedFilename = KURL::decode_string(*it);
+    QString decodedFilename = QFile::decodeName((*it).utf8());
     folder_list.push_back(decodedFilename);
     folders_menu->insertItem(decodedFilename, unique_id);
     if(hotlist.contains(decodedFilename))
     {
+      if (decodedFilename.length() > 15)
+      {
+        decodedFilename.truncate(12);
+        decodedFilename += "...";
+      }
+
       temp_button = new QPushButton(decodedFilename, bg_top);
-      temp_button->setFocusPolicy(QWidget::ClickFocus);
-      temp_button->setToggleButton(TRUE);
-      temp_button->setFixedSize(BUTTON_WIDTH, temp_button->sizeHint().height());
+      temp_button->setToggleButton(true);
       bg_top->insert(temp_button, unique_id);
+      bg_top_layout->addWidget(temp_button);
       button_list.append(temp_button);
     }
  
@@ -338,33 +396,30 @@ KJotsMain::KJotsMain(const char* name)
   keys->connectItem( "MoveFocus", this, SLOT(moveFocus()) );
 
   // create menu
-  int id;
   KAction *action;
-  QPopupMenu *file_menu = new QPopupMenu;
+  QPopupMenu *file_menu = new QPopupMenu(this);
   
   // New Book
   action = KStdAction::action(KStdAction::New, this, SLOT(createFolder()), actionCollection());
   action->setText(i18n("&New Book..."));
   action->plug(file_menu);
 
-  // added more actionized items and toolbar (antonio)
-  action = new KAction(i18n("New P&age"), "filenew", CTRL+Key_A, this,
+  // New Page
+  action = new KAction(i18n("New P&age"), "filenew", CTRL+SHIFT+Key_N, this,
                        SLOT(newEntry()), actionCollection(), "new_page");
   action->plug(file_menu);
   action->plug(toolBar(0));
   action->plugAccel(keys);
-
-  file_menu->insertSeparator();
-  
+ 
   // Save Book
   action = KStdAction::action(KStdAction::Save, this, SLOT(saveFolder()), actionCollection());
   action->setText(i18n("Save Current Book"));
   action->plug(file_menu);
   
-  id_f_save_book_ascii = file_menu->insertItem(i18n("Save Book to ASCII File"),
-					                                     this, SLOT(writeBook()));
-  id_f_save_page_ascii = file_menu->insertItem(i18n("Save Page to ASCII File"),
-					                                     this, SLOT(writePage()));
+  id_f_save_book_ascii = file_menu->insertItem(i18n("Save Book to ASCII File..."),
+                                                                              this, SLOT(writeBook()));
+  id_f_save_page_ascii = file_menu->insertItem(i18n("Save Page to ASCII File..."),
+                                                                              this, SLOT(writePage()));
 
   file_menu->insertSeparator();
 
@@ -381,11 +436,19 @@ KJotsMain::KJotsMain(const char* name)
 
   file_menu->insertSeparator();
 
+  // Print
+  action = KStdAction::action(KStdAction::Print, this, SLOT(slotPrintPage()), actionCollection());
+  action->plug(file_menu);
+  action->plug(toolBar(0));
+  action->plugAccel(keys);
+
+  file_menu->insertSeparator();
+
   // Quit
   action = KStdAction::action(KStdAction::Quit, this, SLOT(slotQuit()), actionCollection());
   action->plug(file_menu);
 
-  QPopupMenu *edit_menu = new QPopupMenu;
+  QPopupMenu *edit_menu = new QPopupMenu(this);
 
   action = KStdAction::action(KStdAction::Cut, me_text, SLOT(cut()), actionCollection());
   action->plug(edit_menu);
@@ -393,7 +456,7 @@ KJotsMain::KJotsMain(const char* name)
   action  = KStdAction::action(KStdAction::Copy, me_text, SLOT(copy()), actionCollection());
   action->plug(edit_menu);
 
-  action = new KAction(i18n("Copy &Into Page Title"), "editcopy", CTRL+Key_T, this,
+  action = new KAction(i18n("Copy &into Page Title"), "editcopy", CTRL+Key_T, this,
                        SLOT(copySelection()), actionCollection(), "copyIntoTitle");
   action->plug(edit_menu);
   action->plugAccel(keys);
@@ -411,28 +474,33 @@ KJotsMain::KJotsMain(const char* name)
   action = KStdAction::replace( this, SLOT( slotReplace() ), actionCollection() );
   action->plug( edit_menu );
   edit_menu->insertSeparator();
-
+  action = new KAction(i18n("Rename Book..."), KShortcut(), this,
+                       SLOT(slotEditBookTitle()), actionCollection(), "edit_folderName");
+  action->plug(edit_menu);
+  action->plugAccel( keys );
   action = new KAction(i18n("Insert Date"), "date", CTRL+Key_I, this,
                        SLOT(insertDate()), actionCollection(), "insert_date");
   action->plug(edit_menu);
   action->plug(toolBar(0));
   action->plugAccel( keys );
-  edit_menu->insertSeparator();
 
-  action = new KAction(i18n("Previous Page"), "back", CTRL+Key_J, this,
-                       SLOT(prevEntry()), actionCollection(), "prev_page");
-  action->plug( edit_menu );
+  QPopupMenu *go_menu = new QPopupMenu(this);
+
+  action = KStdAction::prior(this, SLOT(prevEntry()), actionCollection());
+  action->plug( go_menu );
   action->plug( toolBar(0) );
   action->plugAccel( keys );
-  action = new KAction(i18n("Next Page"), "forward", CTRL+Key_K, this,
-                       SLOT(nextEntry()), actionCollection(), "next_page");
-  action->plug( edit_menu );
+  action = KStdAction::next(this, SLOT(nextEntry()), actionCollection());
+  action->plug( go_menu );
+  action->plug( toolBar(0) );
+  action->plugAccel( keys );
+  action = KStdAction::gotoPage(this, SLOT(toggleSubjList()), actionCollection());
+  action->setAccel(CTRL + Key_L);
+  action->plug( go_menu );
   action->plug( toolBar(0) );
   action->plugAccel( keys );
 
-  toolBar(0)->insertSeparator();
-
-  QPopupMenu *options_menu = new QPopupMenu;
+  QPopupMenu *options_menu = new QPopupMenu(this);
   action = KStdAction::keyBindings(this, SLOT(configureKeys()), actionCollection());
   action->plug(options_menu);
   /*
@@ -442,37 +510,26 @@ KJotsMain::KJotsMain(const char* name)
   action = KStdAction::preferences(this, SLOT(configure()), actionCollection());
   action->plug(options_menu);
 
-  QPopupMenu *hotlist_menu = new QPopupMenu;
+  QPopupMenu *hotlist_menu = new QPopupMenu(this);
   id_fav_add = hotlist_menu->insertItem(i18n("Add Current Book to Hotlist"),
 				                                this, SLOT(addToHotlist()) );
-  id_fav_del = hotlist_menu->insertItem(i18n("Remove Current Book from Hotlist"),
+  id_fav_del = hotlist_menu->insertItem(i18n("Remove Current Book From Hotlist"),
 				                                this, SLOT(removeFromHotlist()) );
-
-  action=new KAction(i18n("Subject List"), "view_detailed", CTRL+Key_L, this,
-        SLOT(toggleSubjList()), actionCollection(), "subject_list");
-  action->plug(hotlist_menu);
-  action->plug(toolBar(0));
-  action->plugAccel(keys);
-
   menuBar()->insertItem( i18n("&File"), file_menu );
   menuBar()->insertItem( i18n("&Edit"), edit_menu );
+  menuBar()->insertItem( i18n("&Go"), go_menu );
   menuBar()->insertItem( i18n("&Books"), folders_menu );
   menuBar()->insertItem( i18n("Hot&list"), hotlist_menu );
   menuBar()->insertItem( i18n("&Settings"), options_menu );
   menuBar()->insertSeparator();
   menuBar()->insertItem( i18n("&Help"), helpMenu() );
 
-  int nr = folder_list.findIndex(KURL::decode_string(config->readEntry("LastOpenFolder")));
+  int nr = folder_list.findIndex(QFile::decodeName(config->readEntry("LastOpenFolder").utf8()));
   if( nr >= 0 )
   {
     openFolder(nr);
   }
 
-  //
-  // Set minimum size of main widget
-  //
-  f_main->setMinimumSize( f_main->sizeHint() );
-
   //
   // Set startup size.
   //
@@ -484,6 +541,11 @@ KJotsMain::KJotsMain(const char* name)
 
   keys->readSettings();
   updateMenu();
+  
+  if (folder_list.count() == 0)
+  {
+    QTimer::singleShot(0, this, SLOT(createFolder())); 
+  }
 }
 
 
@@ -497,19 +559,19 @@ KJotsMain::~KJotsMain()
 
 void KJotsMain::saveProperties( void )
 {
-  KConfig &config = *kapp->config();
-  config.setGroup("kjots");
+  KConfig* config = kapp->config();
+  config->setGroup("kjots");
   button_list.clear();
   if( folderOpen )
   {
     QFileInfo fi(current_folder_name);
-    config.writeEntry("LastOpenFolder", fi.fileName());
+    config->writeEntry("LastOpenFolder", fi.fileName());
   }
   saveFolder();
-  config.writeEntry("Width", width());
-  config.writeEntry("Height", height());
-  config.writeEntry("ToolBarPos", (int)toolBar(0)->barPos() );
-  config.sync();
+  config->writeEntry("Width", width());
+  config->writeEntry("Height", height());
+  toolBar(0)->saveSettings(config, "MainToolbar");
+  config->sync();
 }
 
 int KJotsMain::readFile( QString name )
@@ -607,15 +669,17 @@ void KJotsMain::openFolder(int id)
  
   QPushButton *but;
   for( but = button_list.first(); but != NULL; but = button_list.next() )
-    but->setOn(FALSE);
-  but = (QPushButton *) bg_top->find(id);
+    but->setOn(false);
+  but = static_cast<QPushButton *>(bg_top->find(id));
   if( but )
-    but->setOn(TRUE);
+    but->setOn(true);
 
+  currentFolder = folders_menu->indexOf(id);
+  currentFolderID = id;
   QDir dir = QDir( locateLocal("appdata", "") );
   QString file_name = dir.absPath();
   file_name += '/';
-  file_name += KURL::encode_string_no_slash(*folder_list.at(folders_menu->indexOf(id)));
+  file_name += QFile::encodeName(*folder_list.at(currentFolder));
   if( current_folder_name == file_name )
     return;
 
@@ -625,21 +689,21 @@ void KJotsMain::openFolder(int id)
 
   if( readFile(current_folder_name) < 0)
     {
-      folderOpen = FALSE;
+      folderOpen = false;
       kdDebug() << "Unable to open folder" << endl;
       return;
     }
 
   current = 0;
-  me_text->deselect();
+  me_text->removeSelection();
   me_text->setText(entrylist.first()->text);
   emit folderChanged(&entrylist);
   emit entryMoved(current);
   le_subject->setText(entrylist.first()->subject);
-  folderOpen = TRUE;
+  folderOpen = true;
   l_folder->setText( *folder_list.at(folders_menu->indexOf(id)) );
-  me_text->setEnabled(TRUE);
-  le_subject->setEnabled(TRUE);
+  me_text->setEnabled(true);
+  le_subject->setEnabled(true);
   me_text->setFocus();
   s_bar->setValue(0);
   s_bar->setRange(0,entrylist.count()-1);
@@ -650,14 +714,12 @@ void KJotsMain::openFolder(int id)
 
 void KJotsMain::createFolder()
 {
-  AskFileName *ask = new AskFileName(this);
-  if( ask->exec() == QDialog::Rejected )
-  {
-    delete ask;
+  KLineEditDlg dlg(i18n("Book name:"), QString::null, this);
+  dlg.setCaption(i18n("New Book"));
+  if (!dlg.exec())
     return;
-  }
-  QString name = ask->getName();
-  delete ask;
+  QString name = dlg.text();
+  
   if( folder_list.contains(name) )
   {
     QString msg = i18n("A book with this name already exists.");
@@ -666,12 +728,12 @@ void KJotsMain::createFolder()
   }
   saveFolder();
   entrylist.clear();
-  folderOpen = TRUE;
-  me_text->setEnabled(TRUE);
-  le_subject->setEnabled(TRUE);
+  folderOpen = true;
+  me_text->setEnabled(true);
+  le_subject->setEnabled(true);
   me_text->setFocus();
   me_text->clear();
-  me_text->deselect();
+  me_text->removeSelection();
   TextEntry *new_entry = new TextEntry;
   entrylist.append(new_entry);
   new_entry->subject = "";
@@ -683,19 +745,18 @@ void KJotsMain::createFolder()
   le_subject->setText(entrylist.first()->subject);
   folder_list.append(name);
 
-  // TODO: this does not work with qt 2.0. Why?
-//     if( folders->text(folders->idAt(0)) == 0 )
-//      folders->removeItemAt(0);
-
-  folders_menu->insertItem(name, unique_id++);
+  ++unique_id;
+  currentFolderID = unique_id;
+  folders_menu->insertItem(name, currentFolder);
+  currentFolder = folders_menu->indexOf(currentFolderID);
   QDir dir = QDir( locateLocal("appdata", "") );
   current_folder_name = dir.absPath();
   current_folder_name += '/';
-  current_folder_name += KURL::encode_string_no_slash(name);
+  current_folder_name += QFile::encodeName(name);
   l_folder->setText(name);
   QPushButton *but;
   for( but = button_list.first(); but != 0; but = button_list.next() )
-    but->setOn(FALSE);
+    but->setOn(false);
 
   updateMenu();
 }
@@ -706,14 +767,14 @@ void KJotsMain::deleteFolder()
     return;
 
   QString msg = i18n("Are you sure you want to delete the current book?");
-  int result = KMessageBox::warningYesNo( topLevelWidget(), msg );
+  int result = KMessageBox::warningYesNo( topLevelWidget(), msg, i18n("Delete Book") );
   if( result != KMessageBox::Yes )
   {
     return;
   }
 
   QFileInfo fi(current_folder_name);
-  QDir dir = fi.dir(TRUE);
+  QDir dir = fi.dir(true);
   QString name = fi.fileName();
   int index = folder_list.findIndex(name);
   if( index < 0 )
@@ -737,17 +798,19 @@ void KJotsMain::deleteFolder()
   config->sync();
   entrylist.clear();
   current_folder_name = "";
-  folderOpen = FALSE;
-  me_text->setEnabled(FALSE);
+  currentFolder = 0;
+  currentFolderID = 0;
+  folderOpen = false;
+  me_text->setEnabled(false);
   me_text->clear();
-  me_text->deselect();
-  le_subject->setEnabled(FALSE);
+  me_text->removeSelection();
+  le_subject->setEnabled(false);
   le_subject->clear();
   emit folderChanged(&entrylist);
   s_bar->setValue(0);
   s_bar->setRange(0,0);
   l_folder->clear();
-  subj_list->repaint(TRUE);
+  subj_list->repaint(true);
 
   openFolder(folders_menu->idAt(0));
   updateMenu();
@@ -771,7 +834,7 @@ void KJotsMain::nextEntry()
   entrylist.at(current)->text = me_text->text();
   entrylist.at(current)->subject = le_subject->text();
   me_text->setText( entrylist.at(++current)->text );
-  me_text->deselect();
+  me_text->removeSelection();
   me_text->repaint();
   emit entryMoved(current);
   le_subject->setText( entrylist.at(current)->subject );
@@ -789,7 +852,7 @@ void KJotsMain::prevEntry()
   entrylist.at(current)->text = me_text->text();
   entrylist.at(current)->subject = le_subject->text();
   me_text->setText( entrylist.at(--current)->text );
-  me_text->deselect();
+  me_text->removeSelection();
   me_text->repaint();
   emit entryMoved(current);
   le_subject->setText( entrylist.at(current)->subject );
@@ -824,7 +887,17 @@ void KJotsMain::deleteEntry()
     return;
   if( entrylist.count() == 0 )
     return;
-  else if( entrylist.count() == 1 )
+  if (KMessageBox::warningYesNo(this, 
+                                i18n("Are you sure you want to delete the current page?"),
+                                i18n("Delete Page"),
+                                KStdGuiItem::yes(),
+                                KStdGuiItem::no(),
+                                "deletePageWarning") != KMessageBox::Yes)
+  {
+    return;
+  }
+
+  if( entrylist.count() == 1 )
     {
       entrylist.at(0)->text = "";
       entrylist.at(0)->subject = "";
@@ -860,7 +933,7 @@ void KJotsMain::barMoved( int new_value )
   entrylist.at(current)->subject = le_subject->text();
   current = new_value;
   me_text->setText( entrylist.at(current)->text );
-  me_text->deselect();
+  me_text->removeSelection();
   me_text->repaint();
   emit entryMoved(current);
   le_subject->setText( entrylist.at(current)->subject );
@@ -882,19 +955,23 @@ void KJotsMain::addToHotlist()
   if( index < 0 )
     return;
   int id = folders_menu->idAt(index);
-  QPushButton *but = new QPushButton(name, bg_top);
+  QString buttonLabel = name;
+  if (buttonLabel.length() > 15)
+  {
+    buttonLabel.truncate(12);
+    buttonLabel += "...";
+  }
+  QPushButton *but = new QPushButton(buttonLabel, bg_top);
   button_list.append(but);
   bg_top->insert(but, id);
+  bg_top_layout->addWidget(but);
   KConfig *config = KApplication::kApplication()->config();
   config->setGroup("kjots");
   config->writeEntry( "Hotlist", hotlist );
   config->sync();
-  but->setFocusPolicy(QWidget::ClickFocus);
-  but->setToggleButton(TRUE);
-  but->setFixedSize(BUTTON_WIDTH, but->sizeHint().height());
+  but->setToggleButton(true);
   but->show();
-  but->setOn(TRUE);
-  bg_top->forceResize();
+  but->setOn(true);
 }
 
 void KJotsMain::removeFromHotlist()
@@ -915,7 +992,6 @@ void KJotsMain::removeFromHotlist()
   config->setGroup("kjots");
   config->writeEntry( "Hotlist", hotlist );
   config->sync();
-  bg_top->forceResize();
 }
 
 void KJotsMain::toggleSubjList()
@@ -976,14 +1052,15 @@ void KJotsMain::slotReplace()
 
 void KJotsMain::updateConfiguration()
 {
-  KConfig &config = *kapp->config();
+  KConfig* config = kapp->config();
 
-  config.setGroup("kjots");
-  QFont font( config.readEntry("EFontFamily"),
-	      config.readNumEntry("EFontSize"),
-	      config.readNumEntry("EFontWeight"),
-	      config.readNumEntry("EFontItalic"));
+  config->setGroup("kjots");
+  QFont font( config->readEntry("EFontFamily"),
+                     config->readNumEntry("EFontSize"),
+                    config->readNumEntry("EFontWeight"),
+                    config->readNumEntry("EFontItalic"));
   me_text->setFont(font);
+  toolBar(0)->applySettings(config, "MainToolbar");
 }
 
 void KJotsMain::writeBook()
@@ -1103,12 +1180,22 @@ void KJotsMain::configureKeys()
 
 void KJotsMain::copySelection()
 {
-  if(me_text->hasMarkedText())
+  if(me_text->hasSelectedText())
   {
-    le_subject->setText(me_text->markedText());
+    le_subject->setText(me_text->selectedText());
   }
 }
 
+void KJotsMain::slotPrintPage()
+{
+    QString docName = current_folder_name;
+    if (le_subject->text() != QString::null)
+    {
+        docName += ": " + le_subject->text();
+    }
+    me_text->print(docName);
+ }
+
 void KJotsMain::slotQuit() 
 {
     // just save on exit...
@@ -1116,33 +1203,77 @@ void KJotsMain::slotQuit()
     close();
 }
 
+void KJotsMain::slotEditBookTitle()
+{
+  if (!folderOpen)
+  {
+    return;
+  }
+  
+  bool accepted(false);
+  QString newName = KLineEditDlg::getText(i18n("Rename Book"), i18n("Title of this book:"),
+                                          l_folder->text(), &accepted, this);
+  if (accepted)
+  {
+    QFileInfo folderInfo(current_folder_name);
+    QString temp = folderInfo.dirPath(true);
+    QDir dir(temp);
+    temp += "/" + QFile::encodeName(newName);
+    
+    if (QFile::exists(temp))
+    {
+        KMessageBox::sorry(this, i18n("A book by that name already exists."), i18n("Rename Book")) ;
+        return;
+    }
+    
+    dir.rename(current_folder_name, temp);
+    current_folder_name = temp;
+    
+    if (hotlist.contains(l_folder->text()))
+    {
+        (*hotlist.find(l_folder->text())) = newName;
+         KConfig *config = KApplication::kApplication()->config();
+         config->setGroup("kjots");
+         config->writeEntry( "Hotlist", hotlist );
+         config->sync();
+    }
+    
+    l_folder->setText(newName);
+    (*folder_list.at(currentFolder)) = newName;
+    QPushButton* but = dynamic_cast<QPushButton*>(bg_top->find(currentFolderID));
+    if (but)
+    {
+        if (newName.length() > 15)
+        {
+            newName.truncate(12);
+            newName += "...";
+        }
+        but->setText(newName);
+    }
+  }
+}
+
 void KJotsMain::insertDate()
 {
-  KLocale locale("kjots");
-  QString* date = new QString(locale.formatDateTime(QDateTime::currentDateTime(), true) + " ");
-  QTextStream* dateStream = new QTextStream(date, IO_ReadOnly);
-  me_text->insertText(dateStream);
-  delete dateStream;
-  delete date;
+  me_text->insert(KGlobal::locale()->formatDateTime(QDateTime::currentDateTime(), true) + " ");
 }
 
 void KJotsMain::updateMenu()
 {
-  bool activeBook = folderOpen;
+  actionCollection()->action("del_folder")->setEnabled(folderOpen);
+  actionCollection()->action("del_page")->setEnabled(folderOpen);
+  actionCollection()->action("new_page")->setEnabled(folderOpen);
+  actionCollection()->action("edit_folderName")->setEnabled(folderOpen);
 
-  actionCollection()->action("del_folder")->setEnabled(activeBook);
-  actionCollection()->action("del_page")->setEnabled(activeBook);
-  actionCollection()->action("new_page")->setEnabled(activeBook);
+  actionCollection()->action(KStdAction::stdName(KStdAction::Save))->setEnabled(folderOpen);
+  menuBar()->setItemEnabled(id_f_save_book_ascii, folderOpen);
+  menuBar()->setItemEnabled(id_f_save_page_ascii, folderOpen);
 
-  actionCollection()->action(KStdAction::stdName(KStdAction::Save))->setEnabled(activeBook);
-  menuBar()->setItemEnabled(id_f_save_book_ascii, activeBook);
-  menuBar()->setItemEnabled(id_f_save_page_ascii, activeBook);
+  actionCollection()->action(KStdAction::stdName(KStdAction::Cut))->setEnabled(folderOpen);
+  actionCollection()->action(KStdAction::stdName(KStdAction::Copy))->setEnabled(folderOpen);
+  actionCollection()->action(KStdAction::stdName(KStdAction::Paste))->setEnabled(folderOpen);
 
-  actionCollection()->action(KStdAction::stdName(KStdAction::Cut))->setEnabled(activeBook);
-  actionCollection()->action(KStdAction::stdName(KStdAction::Copy))->setEnabled(activeBook);
-  actionCollection()->action(KStdAction::stdName(KStdAction::Paste))->setEnabled(activeBook);
-
-  menuBar()->setItemEnabled(id_fav_add, activeBook);
-  menuBar()->setItemEnabled(id_fav_del, activeBook);
+  menuBar()->setItemEnabled(id_fav_add, folderOpen);
+  menuBar()->setItemEnabled(id_fav_del, folderOpen);
 }
 #include "KJotsMain.moc"
