@@ -59,13 +59,12 @@ BatteryConfig::BatteryConfig (QWidget * parent, const char *name)
 					       KDialog::spacingHint() );
 
     // do we show the monitor
-    runMonitor = new QCheckBox( i18n("&Show Battery Monitor"), this );
+    runMonitor = new QCheckBox( i18n("&Show battery monitor"), this );
     top_layout->addWidget( runMonitor );
     connect( runMonitor, SIGNAL(clicked()), this, SLOT(configChanged()) );
 
     if (!apm) {
       top_layout->addWidget( laptop_portable::no_power_management_explanation(this) );
-      top_layout->addStretch( 1 );
     } else {
       iconloader = new KIconLoader("klaptopdaemon");
 
@@ -74,7 +73,7 @@ BatteryConfig::BatteryConfig (QWidget * parent, const char *name)
       hb->setSpacing( KDialog::spacingHint() );
       top_layout->addWidget( hb );
 
-      QLabel* poll_label = new QLabel( i18n("&Check status every"), hb );
+      QLabel* poll_label = new QLabel( i18n("&Check status every:"), hb );
       editPoll = new QSpinBox( 1, 3600, 1, hb ); // min,max,step
       editPoll->setSuffix( i18n("keep short, unit in spinbox", "sec") );
       poll_label->setBuddy( editPoll );
@@ -84,7 +83,7 @@ BatteryConfig::BatteryConfig (QWidget * parent, const char *name)
       hb->setStretchFactor( spacer, 1 );
 
       // group box to hold the icons together
-      QVGroupBox* icons_groupbox = new QVGroupBox( i18n("Icons:"), this );
+      QVGroupBox* icons_groupbox = new QVGroupBox( i18n("Icons"), this );
       icons_groupbox->layout()->setSpacing( KDialog::spacingHint() );
       top_layout->addWidget( icons_groupbox, 0, Qt::AlignLeft );
 
@@ -104,22 +103,26 @@ BatteryConfig::BatteryConfig (QWidget * parent, const char *name)
 
       QLabel* explain = new QLabel( i18n("This panel controls whether the battery status\nmonitor appears in the dock and what it looks like."), this);
       top_layout->addWidget(explain, 0);
-
-      top_layout->addStretch(1);
-      top_layout->addWidget( new QLabel( i18n("Version: %1").arg(LAPTOP_VERSION), this), 0, Qt::AlignRight );
+      laptop_portable::extra_config(this, config, top_layout);
     }
 
-    load();      
+    top_layout->addStretch(1);
+    top_layout->addWidget( new QLabel( i18n("Version: %1").arg(LAPTOP_VERSION), this), 0, Qt::AlignRight );
+
+
+    load();
 }
 
 BatteryConfig::~BatteryConfig()
 {
+  delete config;
 }
 
 
 void BatteryConfig::save()
 {
         enablemonitor = runMonitor->isChecked();
+
         if (apm) {
                 poll_time = editPoll->value();
                 nobattery =  buttonNoBattery->icon();
@@ -133,7 +136,7 @@ void BatteryConfig::save()
         config->writeEntry("NoBatteryPixmap", nobattery);
         config->writeEntry("ChargePixmap", chargebattery);
         config->writeEntry("NoChargePixmap", nochargebattery);
-	config->sync();      
+	config->sync();
         changed(false);
         kapp->startServiceByDesktopName("klaptopdaemon");
 }
@@ -158,14 +161,14 @@ void BatteryConfig::load()
 		//buttonCharge->setPixmap(kapp->iconLoader()->loadIcon(chargebattery));
 	        buttonNoBattery->setIcon(nobattery);
                 //buttonNoBattery->setPixmap(kapp->iconLoader()->loadIcon(nobattery));
-        }                                                 
+        }
         changed(false);
 }
 
 void BatteryConfig::defaults()
 {
         poll_time = 20;
-        enablemonitor = false;
+        enablemonitor = true;
 
         nobattery = "laptop_nobattery";
         nochargebattery = "laptop_nocharge";
@@ -180,7 +183,7 @@ void BatteryConfig::defaults()
                 //buttonCharge->setPixmap(kapp->iconLoader()->loadIcon(chargebattery));
                 buttonNoBattery->setIcon(nobattery);
                 //buttonNoBattery->setPixmap(kapp->iconLoader()->loadIcon(nobattery));
-        }          
+        }
         changed(false);
 }
 
