@@ -4,7 +4,7 @@
  *
  * This file contains the docked widget for the laptop battery monitor
  *
- * $Id: daemondock.cpp,v 1.27 2002/02/26 20:54:52 staikos Exp $
+ * $Id: daemondock.cpp,v 1.32 2002/09/25 13:07:22 cumming Exp $
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -31,12 +31,14 @@
 #include "kpcmciainfo.h"
 #include "daemondock.h"
 #include "portable.h"
-#include <iostream.h>
+#include <kiconloader.h>
 #include <kprocess.h>
 #include <kstandarddirs.h>
+#include <kconfig.h>
+#include <kmessagebox.h>
 
-laptop_dock::laptop_dock( laptop_daemon* parent)
-  : KDockWindow()
+laptop_dock::laptop_dock( laptop_daemon* parent )
+  : KSystemTray()
 {
 
     _pcmcia = NULL;
@@ -48,7 +50,7 @@ laptop_dock::laptop_dock( laptop_daemon* parent)
     int can_standby = laptop_portable::has_standby();
     int can_suspend = laptop_portable::has_suspend();
     int can_hibernate = laptop_portable::has_hibernation();
-    popup->insertItem(i18n("Setup..."), this, SLOT(invokeSetup()));
+    popup->insertItem(SmallIcon("configure"), i18n("&Configure KLaptop..."), this, SLOT(invokeSetup()));
 
     if (can_standby || can_suspend || can_hibernate) {
     	popup->insertSeparator();
@@ -60,7 +62,7 @@ laptop_dock::laptop_dock( laptop_daemon* parent)
     }
 
     popup->insertSeparator();
-    popup->insertItem(i18n("Quit"), this, SLOT(slotQuit()));
+    popup->insertItem(SmallIcon("exit"), i18n("&Quit"), this, SLOT(slotQuit()));
 }
 
 
@@ -80,7 +82,20 @@ void laptop_dock::slotGoRoot(int /*id*/) {
 
 
 void laptop_dock::slotQuit() {
-	exit(0);
+	int confirm = KMessageBox::questionYesNo(0, i18n("Are you sure you want to quit the battery monitor?"), QString::null, KStdGuiItem::yes(), KStdGuiItem::no(), "quitConfirm");
+
+	if (confirm != KMessageBox::Yes)
+		return;
+
+	// just tell ourselves to hide the battery
+	KConfig *config = new KConfig("kcmlaptoprc");
+	if (config) {
+        	config->setGroup("BatteryDefault");
+        	config->writeEntry("Enable", false);
+        	config->sync();
+		delete config;
+	}
+        kapp->startServiceByDesktopName("klaptopdaemon");
 }
 
 
@@ -187,7 +202,7 @@ void laptop_dock::mousePressEvent( QMouseEvent *event )
                    _suspendActions.clear();
                    _resumeActions.clear();
                    _displayActions.clear();
-                   id = popup->insertItem(i18n("Card slots..."), this, SLOT(slotDisplayAction(int)));
+                   id = popup->insertItem(i18n("Card Slots..."), this, SLOT(slotDisplayAction(int)));
                    _displayActions.insert(id, _pcmcia->getCard(0));
                    for (int i = 0; i < _pcmcia->getCardCount(); i++) {
                       KPCMCIACard *thiscard;
@@ -301,7 +316,7 @@ void laptop_dock::invokeLockSuspend()
 
 void laptop_dock::invokeSetup()
 {
-	::system("kcmshell battery&");
+	::system("kcmshell laptop&");
 }
 
 laptop_dock::~laptop_dock() {
