@@ -21,8 +21,6 @@
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <iostream.h> 
-
 #include <sys/types.h>
 #include <unistd.h>
 #include <sys/stat.h>
@@ -98,6 +96,18 @@ void PcmciaConfig::defaults()
 }
 
 
+const KAboutData* PcmciaConfig::aboutData() const
+{
+    KAboutData *about =
+    new KAboutData(I18N_NOOP("kcmlaptop"),
+		I18N_NOOP("KDE Panel System Information Control Module"),
+		0, 0, KAboutData::License_GPL,
+		I18N_NOOP("(c) 1999 - 2002 Paul Campbell"));
+    about->addAuthor("Paul Campbell", 0, "paul@taniwha.com");
+    return about;
+}
+
+
 void PcmciaConfig::changed()
 {
   emit KCModule::changed(true);
