@@ -1,6 +1,8 @@
 /*
  * portable.cpp
  *
+ * $Id: portable.cpp,v 1.30.2.3 2002/12/06 15:13:05 lunakl Exp $
+ *
  * Copyright (c) 1999 Paul Campbell <paul@taniwha.com>
  *
  * Requires the Qt widget libraries, available at no cost at
@@ -33,53 +35,80 @@
 //
 //	then tag an extra '#endif' at the end
 //
+// There is support for the following OSsen right now:
+//
+//	Linux 		(#if __linux__)
+//	FreeBSD		(#elif __FreeBSD__)
+//	NetBSD		(#elif __NetBSD_APM__)
+//	generic nothing	(#else)
+//
+//
+//
+//
 //	If you have any problems, questions, whatever please get in touch
 //
 //		Paul Campbell
 //		paul@taniwha.com
 //		
 //
+//	Thanks to Cajus Pollmeier <C.Pollmeier@gmx.net>
+//	and Robert Ellis Parrott <parrott@fas.harvard.edu>
+//	who both provided ACPI support
+//
 
 #include <klocale.h>
 #include <stdio.h>
 #include "portable.h"
 
 #ifdef __linux__
+
+/*
+** This is the Linux-specific laptop code.
+*/
 #include <sys/types.h>
 #include <unistd.h>
 #include <sys/stat.h>
 #include <stdlib.h>
+#include <dirent.h>
+#include <qpushbutton.h>
+#include <qobject.h>
+#include <kactivelabel.h>
+#include "acpi_config.h"
+
+static acpi_config *panel_start=0;
+
 
 //
 //	here's the Linux specific laptop control panel stuff
 //
 
 typedef struct apm_info {
-   int        apm_flags;
-   int        ac_line_status;
-   int        battery_percentage;
-   int        battery_time;
+   unsigned int apm_flags;
+   unsigned int ac_line_status;
+   int          battery_percentage;
+   int          battery_time;
 } apm_info;
  
 static int
 apm_read(apm_info *ap)
 {
-   	FILE	*f;
+   	FILE	*f = 0;
    	char	tmp2[10];
 	int	tmp, s;
+	unsigned int utmp;
 	char 	version[256];
 
 	f = fopen("/proc/apm", "r");
 	if (f == NULL)
 		return(1);
-	s = fscanf(f, "%s %d.%d %x %x %x %x %d%% %d %s\n",
+	s = fscanf(f, "%255s %d.%d %x %x %x %x %d%% %d %s\n",
 		version,
 		&tmp,
 		&tmp,
 		&ap->apm_flags,
 	   	&ap->ac_line_status,
-		&tmp,
-		&tmp,
+		&utmp,
+		&utmp,
 	   	&ap->battery_percentage,
 	   	&ap->battery_time,
 	   	tmp2);
@@ -97,22 +126,21 @@ apm_read(apm_info *ap)
 	return(0);
 }
 
-static const char * const batt_info[] = {
-	"/proc/acpi/battery/0/info",
-	"/proc/acpi/battery/1/info",
-	"/proc/acpi/battery/2/info",
-	"/proc/acpi/battery/3/info",
-};
+#define MAX_BATTERIES 4
+static int acpi_num_batteries = 0;
+static char acpi_batt_info0[NAME_MAX+50];
+static char acpi_batt_info1[NAME_MAX+50];
+static char acpi_batt_info2[NAME_MAX+50];
+static char acpi_batt_info3[NAME_MAX+50];
+static char acpi_batt_status0[NAME_MAX+50];
+static char acpi_batt_status1[NAME_MAX+50];
+static char acpi_batt_status2[NAME_MAX+50];
+static char acpi_batt_status3[NAME_MAX+50];
+static char *acpi_batt_info[MAX_BATTERIES] = {acpi_batt_info0, acpi_batt_info1, acpi_batt_info2, acpi_batt_info3};
+static char *acpi_batt_status[MAX_BATTERIES] = {acpi_batt_status0, acpi_batt_status1, acpi_batt_status2, acpi_batt_status3};
 
-static const char * const batt_status[] = {
-	"/proc/acpi/battery/0/status",
-	"/proc/acpi/battery/1/status",
-	"/proc/acpi/battery/2/status",
-	"/proc/acpi/battery/3/status",
-};
 
 
-static unsigned char acpi_batt_ok[4];
 static unsigned char acpi_ac_ok;
 
 static int
@@ -155,58 +183,128 @@ getint(char *s)
 //
 //		for the moment we prefer APM
 //
+
+static int
+acpi_ac_status()
+{
+	DIR *dfd;
+	struct dirent *dp;
+	FILE *f = NULL;
+	static char buff[NAME_MAX+50];
+	static bool inited=0;
+	static bool bad=0;
+	
+	if (inited) {
+		if (bad)
+			return(-1);
+		f = fopen(buff, "r");
+		goto readit;
+	}
+	inited = 1;
+
+	dfd = opendir("/proc/acpi/ac_adapter/");
+	if (dfd) {
+		for (;;) {
+			dp = readdir(dfd);
+			if (dp == 0)
+				break;
+			if (strcmp(dp->d_name, ".") == 0 ||
+		            strcmp(dp->d_name, "..") == 0)
+				continue;
+			strcpy(buff, "/proc/acpi/ac_adapter/");
+			strcat(buff, dp->d_name);
+			strcat(buff, "/status");
+			f = fopen(buff, "r");
+			if (!f) {
+				strcpy(buff, "/proc/acpi/ac_adapter/");
+				strcat(buff, dp->d_name);
+				strcat(buff, "/state");
+				f = fopen(buff, "r");
+			}
+			if (f)
+				break;
+		}
+		closedir(dfd);
+readit:
+		if (f) {
+			for (;;) {
+				char buff2[1024];
+				if (fgets(buff2, sizeof(buff), f) == NULL)
+					break;
+				if (strstr(buff2, "Status:") != NULL ||
+			    	    strstr(buff2, "state:") != NULL) {
+					if (strstr(buff2, "on-line") != NULL) {
+						fclose(f);
+						return(1);
+					}
+				}
+			}
+			fclose(f);
+			return(0);
+		}
+	}
+	bad=1;
+	return(-1);
+}
+
 static int
 acpi_read(apm_info *ap)
 {
-   	FILE	*f;
 	int	v, i;
 	int rate, part, total; 
 	int ret = 1;
 	char buff[1024];
-	static int ratecount=0;
-	static int ratetotal=0;
+	FILE *f;
 
 	part = 0;
 	total = 0;
 	rate = 0;
-	for (i = 0; i < 4; i++)
-	if (acpi_batt_ok[i]) {
+	for (i = 0; i < acpi_num_batteries; i++) {
 		int remaining = 0;
 		int caplow = 0;
 		int cap = 0;
 		int first=1;
 
-		f = fopen(batt_info[i], "r");
+		if (acpi_batt_info[i][0]) {
+			f = fopen(acpi_batt_info[i], "r");
+		} else {
+			f = 0;
+		}
 again:
 		if (f == NULL) {
-			if (!first)
+			if (!first || !acpi_batt_status[i][0])
 				continue;
 			first = 0;
-			f = fopen(batt_status[i], "r");
+			f = fopen(acpi_batt_status[i], "r");
 			goto again;
 		}
 		for (;;) {
 			if (fgets(buff, sizeof(buff), f) == NULL)
 				break;
-			if (strstr(buff, "Design Capacity Low:") != NULL) {
+			if (strstr(buff, "Design Capacity Low:") != NULL ||
+			    strstr(buff, "design capacity low:") != NULL) {
 				caplow = getint(buff);
 			} else
-			if (strstr(buff, "Present Rate:") != NULL) {
+			if (strstr(buff, "Present Rate:") != NULL ||
+			    strstr(buff, "present rate:") != NULL) {
 				v = getint(buff);
 				if (v < 0)
 					v = 0;
+				rate += v;
 			} else
-			if (strstr(buff, "Last Full Capacity:") != NULL) {
+			if (strstr(buff, "Last Full Capacity:") != NULL ||
+			    strstr(buff, "last full capacity:") != NULL) {
 				cap = getint(buff);
 			} else
-			if (strstr(buff, "Remaining Capacity:") != NULL) {
+			if (strstr(buff, "Remaining Capacity:") != NULL ||
+			    strstr(buff, "remaining capacity:") != NULL) {
 				remaining = getint(buff);
 			} 
 		}
    		fclose(f);
-		if (first) {
+		if (first && acpi_batt_status[i][0]) {
 			first = 0;
-			f = fopen(batt_status[i], "r");
+			f = fopen(acpi_batt_status[i], "r");
 			goto again;
 		}
 		ret = 0;
@@ -221,31 +319,56 @@ again:
 		total += cap;
 		part += remaining;
 	}
-	if (ratecount == 16) {	// about 5 mins with a 20 sec poll
-		ratecount /= 2;
-		ratetotal /= 2;
-	}
-	ratecount++;
-	ratetotal += v;
-	rate = ratetotal/ratecount;
-	ap->battery_percentage = (total==0?0:100*part/total);
-	//ap->battery_time = (rate==0||part==0?0 : part/rate);
-	ap->battery_time = -1;
+
+	static int nrates = 0;
+	static int saved_rate[8];
+	static unsigned char ignore_next = 1;	// ignore the first
+	
 	ap->ac_line_status = 0;
-	ap->apm_flags = 0;
-	f = fopen("/proc/acpi/ac_adapter/0/status", "r");
-	if (f) {
-		for (;;) {
-			if (fgets(buff, sizeof(buff), f) == NULL)
-				break;
-			if (strstr(buff, "Status:") != NULL) {
-				if (strstr(buff, "on-line") != NULL) 
-					ap->ac_line_status |= 1;
-				break;
-			}
+	//
+	//	ACPI (unlike nice systems like some APM implementations) doesn't
+	//	tell us how much battery TIME we have left - here we
+	//	do a weighted average of the discharge rate (in mW) and
+	//	figure out how long we have left by dividing it into the 
+	//	remaining capacity
+	//
+	//	because some ACPI implementations return bogus 
+	//	rates when charging we can't estimate the battery life
+	//	so we only collect discharge rate data when we're actually
+	//	discharging
+	//
+	if (acpi_ac_status() == 1) {
+		ap->ac_line_status |= 1;
+		ignore_next = 1;
+	} else {
+		// after switching from power to unpowered we often get
+		// a bad reading from ACPI resulting in bizarre
+		// readings
+		if (!ignore_next) {
+			if (nrates < 8)				// smooth the power flow
+				nrates++;			// simple box filter
+			for (int i = 8-1; i > 0; i--) 
+				saved_rate[i] = saved_rate[i-1];
+			saved_rate[0] = rate;
 		}
-		fclose(f);
+		ignore_next = 0;
 	}
+	//
+	//	if we haven't got any discharge rate data yet don't return a
+	//	battery time - probably happens when you start up with the
+	//	ac adaptor plugged in
+	//
+	if (nrates == 0) {
+		ap->battery_time = -1;
+	} else {
+		rate = 0;
+		for (int i = 0; i < nrates; i++)
+			rate += saved_rate[i];
+		rate = (rate+2*saved_rate[0])/(nrates+2);		// weight it slighly
+		ap->battery_time = (rate==0||part==0?0 : 60*part/rate);
+	}
+	ap->battery_percentage = (total==0?0:100*part/total);
+	ap->apm_flags = 0;
 	return(ret);
 }
 
@@ -270,30 +393,69 @@ has_apm()
         return(val);
 }
 
+static int x_acpi_init = 0;
 static int
 has_acpi()
 {
-	static int init = 0;
-	static int val;
 	int i;
+	bool ok;
+	DIR *dfd;
+	struct dirent *dp;
+	static int val;
 
-	if (init)
+	if (x_acpi_init)
 		return(val);
-	init = 1;
+	x_acpi_init = 1;
 	val = 0;
-	if (::access("/proc/acpi/ac_adapter/0/status", R_OK) == 0)
+	
+	if (acpi_ac_status() >= 0)
 		acpi_ac_ok = 1;
-	for (i = 0; i < 4; i++) {
-		if (::access(batt_status[i], R_OK) == 0 ||
-		    ::access(batt_info[i], R_OK) == 0)
-			acpi_batt_ok[i] = 1;
+
+	dfd = opendir("/proc/acpi/battery");
+	if (!dfd)
+		return(val = 0);
+	i = 0;
+	acpi_num_batteries = 0;
+	for (dp = readdir(dfd);dp && i < MAX_BATTERIES;dp = readdir(dfd)) {
+		if (strcmp(dp->d_name, ".") == 0 ||
+		    strcmp(dp->d_name, "..") == 0)
+			continue;
+		strcpy(acpi_batt_status[i], "/proc/acpi/battery/");
+		strcat(acpi_batt_status[i], dp->d_name);
+		strcpy(acpi_batt_info[i], acpi_batt_status[i]);
+		ok = 0;
+		strcat(acpi_batt_status[i], "/state");
+		if (::access(acpi_batt_status[i], R_OK) != 0) {
+			strcpy(acpi_batt_status[i], acpi_batt_info[i]);
+			strcat(acpi_batt_status[i], "/status");
+			if (::access(acpi_batt_status[i], R_OK) == 0) {
+				ok = 1;
+			} else {
+				acpi_batt_status[i][0] = 0;
+			}
+		} else {
+			ok = 1;
+		}
+		strcat(acpi_batt_info[i], "/info");
+		if (::access(acpi_batt_info[i], R_OK) == 0) {
+			ok = 1;
+		} else {
+			acpi_batt_info[i][0] = 0;
+		}
+		if (ok) {
+			acpi_num_batteries++;
+			i++;
+			val = 1;
+		}
+	}
+	closedir(dfd);
+	if (!acpi_ac_ok) 
+		val = 0;
+	if (val && panel_start == 0) {
+		KConfig *c = new KConfig("kcmlaptoprc");
+		panel_start = new acpi_config(c);
+		delete c;
 	}
-	if (acpi_ac_ok &&
-		(acpi_batt_ok[0] ||
-		 acpi_batt_ok[1] ||
-		 acpi_batt_ok[2] ||
-		 acpi_batt_ok[3]))
-		val = 1;
 	return(val);
 }
  
@@ -303,6 +465,20 @@ apm_has_time()
         return(!apm_no_time);
 }
 
+//
+//	something changed maybe we need to check out environment again
+//
+void
+laptop_portable::power_management_restart()
+{
+	if (panel_start) {
+		delete panel_start;
+		panel_start = 0;
+	}
+	x_acpi_init = 0;
+	acpi_num_batteries = 0;
+}
+
 //
 //	returns 1 if we support power management
 //
@@ -318,7 +494,7 @@ int laptop_portable::has_power_management()
 int laptop_portable::has_battery_time()
 {
 	if (::has_acpi())
-		return(0);
+		return(1);
 	return (::apm_has_time());
 }
 //
@@ -328,8 +504,9 @@ int laptop_portable::has_battery_time()
 int laptop_portable::has_suspend()
 {
 	struct stat s;
-	if (::has_acpi())
-		return(0);
+	if (::has_acpi()) {
+		return(panel_start && panel_start->has_suspend());
+	}
         if (stat("/usr/bin/apm", &s) || !(getuid() == 0 || s.st_mode&S_ISUID)) 
 		return(0);
 	return(1);
@@ -342,7 +519,7 @@ int laptop_portable::has_standby()
 {
 	struct stat s;
 	if (::has_acpi())
-		return(0);
+		return(panel_start && panel_start->has_sleep());
         if (stat("/usr/bin/apm", &s) || !(getuid() == 0 || s.st_mode&S_ISUID)) 
 		return(0);
 	return(1);
@@ -357,6 +534,8 @@ int laptop_portable::has_hibernation()
 {
 	struct stat s;
 
+	if (::has_acpi())
+		return(panel_start && panel_start->has_hibernate());
 	hiber_type = 0;
         if (stat("/usr/local/bin/tpctl", &s) == 0 && (getuid() == 0 || s.st_mode&S_ISUID))  {
 		hiber_type = 1;
@@ -370,15 +549,17 @@ int laptop_portable::has_hibernation()
 //	to get any software they lack
 //
 
-QLabel *laptop_portable::no_power_management_explanation(QWidget *parent)
+KActiveLabel *laptop_portable::no_power_management_explanation(QWidget *parent)
 {
 	if (access("/proc/acpi", F_OK) == 0) {	// probably has default kernel ACPI installed
-		QLabel* explain = new QLabel(i18n("Your computer seems to have a partial ACPI installation\nprobably ACPI was enabled, but some of the sub-options\nwere not enabled - you need to enable at least 'AC Adaptor'\nand 'Control Method Battery' and rebuild your kernel"), parent);
+		KActiveLabel* explain = new KActiveLabel(i18n("Your computer seems to have a partial ACPI installation. ACPI was probably enabled, but some of the sub-options were not - you need to enable at least 'AC Adaptor' and 'Control Method Battery' and then rebuild your kernel."), parent);
       		explain->setMinimumSize(explain->sizeHint());       
 		return(explain);
 	}
-	QLabel* explain = new QLabel(i18n("Your computer doesn't have the Linux APM (Advanced\nPower Management) or ACPI software installed, or doesn't have\nthe APM kernel drivers installed - check out the Linux Laptop-HOWTO\ndocument for information how to install APM\nit is available at http://www.linuxdoc.org/HOWTO/Laptop-HOWTO.html"), parent);
-      	explain->setMinimumSize(explain->sizeHint());       
+
+	KActiveLabel* explain = new KActiveLabel(i18n("Your computer doesn't have the Linux APM (Advanced Power Management) or ACPI software installed, or doesn't have the APM kernel drivers installed - check out the <a href=\"http://www.linuxdoc.org/HOWTO/Laptop-HOWTO.html\">Linux Laptop-HOWTO</a> document for information on how to install APM."), parent);
+ 
+     	explain->setMinimumSize(explain->sizeHint());       
 	return(explain);
 }
 
@@ -410,20 +591,23 @@ void get_pcmcia_info()
       FILE *f = fopen("/var/lib/pcmcia/stab", "r");
       if (!f) f = fopen("/var/run/stab", "r");
       if (f) {
-	char c, *cp;
+	int c;
+	char *cp;
 
 	present = 1;
 	cp = tmp0;
 	for (;;) {
-		c = getc(f);
+		c = fgetc(f);
 		if (c == EOF || c == '\n')
 			break;
 		if (c == ':') {
-			while ((c = getc(f)) == ' ')
+			while ((c = fgetc(f)) == ' ')
 				;
+			if (c == EOF)
+				break;
 			for (;;) {
 				*cp++ = c;
-				c = getc(f);
+				c = fgetc(f);
 				if (c == EOF || c == '\n')
 					break;
 			}
@@ -432,25 +616,28 @@ void get_pcmcia_info()
 	}
 	*cp = 0;
 
-	cp = tmp1;
-	for (;;) {
-		c = getc(f);
-		if (c == EOF)
-			break;
-		if (c == ':') {
-			while ((c = getc(f)) == ' ')
-				;
-			for (;;) {
-				*cp++ = c;
-				c = getc(f);
-				if (c == EOF || c == '\n')
+	if (c != EOF) {
+		cp = tmp1;
+		for (;;) {
+			c = fgetc(f);
+			if (c == EOF)
+				break;
+			if (c == ':') {
+				while ((c = fgetc(f)) == ' ')
+					;
+				if (c == EOF)
 					break;
+				for (;;) {
+					*cp++ = c;
+					c = fgetc(f);
+					if (c == EOF || c == '\n')
+						break;
+				}
+				break;
 			}
-			break;
 		}
+		*cp = 0;
 	}
-	*cp = 0;
-
 	fclose(f);
       } else {
 	present = 0;
@@ -484,7 +671,12 @@ QLabel *laptop_portable::pcmcia_info(int x, QWidget *parent)
 //
 void laptop_portable::invoke_standby()
 {
-	 ::system("/usr/bin/apm --standby");    
+	if (::has_acpi()) {
+		if(panel_start)
+			panel_start->do_sleep();
+	} else {
+	 	::system("/usr/bin/apm --standby");    
+	}
 }
 
 //
@@ -492,7 +684,12 @@ void laptop_portable::invoke_standby()
 //
 void laptop_portable::invoke_suspend()
 {
-	 ::system("/usr/bin/apm --suspend");    
+	if (::has_acpi()) {
+		if(panel_start)
+			panel_start->do_suspend();
+	} else {
+	 	::system("/usr/bin/apm --suspend");    
+	}
 }
 
 //
@@ -500,6 +697,10 @@ void laptop_portable::invoke_suspend()
 //
 void laptop_portable::invoke_hibernation()
 {
+	if (::has_acpi()) {
+		if(panel_start)
+			panel_start->do_hibernate();
+	} else 
 	switch (hiber_type) {
 	case 1:
 	 	::system("/usr/local/bin/tpctl --hibernate");    
@@ -508,6 +709,17 @@ void laptop_portable::invoke_hibernation()
 	}
 }
 
+void
+laptop_portable::extra_config(QWidget *parent, KConfig *config, QVBoxLayout *layout)
+{
+	if (::has_acpi()) {
+		if (panel_start)
+			delete panel_start;
+		panel_start = new acpi_config(parent, config, layout);
+		return;
+	}
+	
+}
 
 //
 //	return current battery state
@@ -597,13 +809,22 @@ int laptop_portable::poll_activity()
 
 
 
-#elif __FreeBSD__
+#elif defined(__FreeBSD__)
+
+/*
+** This is the FreeBSD-specific code.
+*/
+
 #include <errno.h>
 #include <fcntl.h>
 #include <unistd.h>
 #include <stdlib.h>
 #include <machine/apm_bios.h>
 #include <sys/stat.h>
+#include <qpushbutton.h>
+#include <qobject.h>
+#include <kactivelabel.h>
+
 #define APMDEV "/dev/apm"
 
 // FreeBSD support by yours truely.  Yay.
@@ -617,6 +838,14 @@ int laptop_portable::poll_activity()
 
 #include <iostream.h>
 
+//
+//	something changed maybe we need to check out environment again
+//
+void
+laptop_portable::power_management_restart()
+{
+}
+
 int
 laptop_portable::has_power_management()
 {
@@ -719,31 +948,31 @@ int laptop_portable::has_hibernation()
 //	explain to the user what they need to do if has_power_management() returned 0
 //	to get any software they lack
 //
-QLabel *laptop_portable::no_power_management_explanation(QWidget *parent)
+KActiveLabel *laptop_portable::no_power_management_explanation(QWidget *parent)
 {
   int fd;
-  QLabel *explain;
+  KActiveLabel *explain;
 
   fd = ::open(APMDEV, O_RDWR);
   if (fd == -1) {
     switch (errno) {
     case ENOENT:
-      explain = new QLabel("There is no /dev/apm file on this system.  Pleae review the FreeBSD handbook on how to create a device node for the apm device driver (man 4 apm)", parent);
+      explain = new KActiveLabel("There is no /dev/apm file on this system.  Pleae review the FreeBSD handbook on how to create a device node for the apm device driver (man 4 apm)", parent);
       break;
     case EACCES:
-      explain = new QLabel("Your system has the proper device node for apm support, however you can't access it.  If you're root right now, you've got a problem, otherwise contact your local sysadmin and beg for read/write access to /dev/apm.", parent);
+      explain = new KActiveLabel("Your system has the proper device node for apm support, however you can't access it.  If you're root right now, you've got a problem, otherwise contact your local sysadmin and beg for read/write access to /dev/apm.", parent);
       break;
     case ENXIO:
-      explain = new QLabel("Your kernel lacks support for Advanced Power Managment.", parent);
+      explain = new KActiveLabel("Your kernel lacks support for Advanced Power Managment.", parent);
       break;
       break;
     default:
-      explain = new QLabel("There was some generic error while opening /dev/apm.  Contact your local supermarket, there's a blue light special on FreeBSD, really.", parent);
+      explain = new KActiveLabel("There was some generic error while opening /dev/apm.  Contact your local supermarket, there's a blue light special on FreeBSD, really.", parent);
       break;
     }
   } else {
     close(fd);
-    explain = new QLabel("APM has most likely been disabled.  Oops", parent);
+    explain = new KActiveLabel("APM has most likely been disabled.  Oops", parent);
   }
   
   explain->setMinimumSize(explain->sizeHint());       
@@ -815,6 +1044,15 @@ void laptop_portable::invoke_hibernation()
 	}
 }
 
+//
+//	adds extra widgets to the battery panel
+//
+void
+laptop_portable::extra_config(QWidget *parent, KConfig *config, QVBoxLayout *layout)
+{
+}
+
+
 
 //
 //	return current battery state
@@ -857,9 +1095,251 @@ int laptop_portable::poll_activity()
 {
 	return(1);
 }
+
+#elif  defined(__NetBSD_APM__)
+
+#include <errno.h>
+#include <fcntl.h>
+#include <unistd.h>
+#include <stdlib.h>
+#include <sys/ioctl.h>
+#include <sys/stat.h>
+#include <machine/apmvar.h>
+#include <iostream.h>
+
+//
+// klaptopdeamon interface to NetBSD 1.5 apm.
+// Scott Presnell, srp@zgi.com, srp@tworoads.net
+// Fri Jun 29 17:21:25 PDT 2001
+// Tested on Dell I4K running NetBSD 1.5R
+//
+#define APMDEV "/dev/apm"
+
+//
+//     Check for apm in kernel by talking to /dev/apm
+//     (opening read only is allowed by any process).
+//     returns 1 if we support power management
+//
+int
+laptop_portable::has_power_management()
+{
+       int ret, fd = ::open(APMDEV, O_RDONLY);
+
+       if (fd == -1) {
+         return 0;
+       }
+
+       struct apm_power_info info;
+       ret=ioctl(fd, APM_IOC_GETPOWER, &info);
+       ::close(fd);
+
+       if (ret == -1) {
+         return 0;
+       }
+
+       return 1;
+}
+
+//
+//     returns 1 if the BIOS returns the time left in the battery rather than a % of full
+//
+int laptop_portable::has_battery_time()
+{
+       int ret, fd = ::open(APMDEV, O_RDONLY);
+
+       if (fd == -1)
+         return 0;
+
+       struct apm_power_info info;
+       ret=ioctl(fd, APM_IOC_GETPOWER, &info);
+       ::close(fd);
+
+       if (ret == -1)
+         return 0;
+
+       return (info.minutes_left != 0xffff);
+}
+
+//
+//     returns 1 if we can perform a change-to-suspend-mode operation for the user
+//     (ust check to see if we have the binary)
+//     (has_power_management() has already returned 1)
+//
+int laptop_portable::has_suspend()
+{
+
+       struct stat s;
+        if (stat("/usr/sbin/apm", &s))
+               return(0);
+       return(1);
+}
+
+//
+//     returns 1 if we can perform a change-to-standby-mode operation for the user
+//     (just check to see if we have the binary)
+//     (has_power_management() has already returned 1)
+//
+int laptop_portable::has_standby()
+{
+
+       struct stat s;
+        if (stat("/usr/sbin/apm", &s))
+               return(0);
+       return(1);
+}
+
+//
+//     returns 1 if we can perform a change-to-hibernate-mode for a user
+//      (has_power_management() has already returned 1)  [hibernate is the save-to-disk mode
+//     not supported by linux - different laptops have their own - the first here is for 
+//     a ThinkPad]
+//     No support in NetBSD at this time.
+//
+int laptop_portable::has_hibernation()
+{
+       return(0);
+}
+
+//
+//     explain to the user what they need to do if has_power_management() returned 0
+//     to get any software they lack
+//
+KActiveLabel *laptop_portable::no_power_management_explanation(QWidget *parent)
+{
+  int fd;
+  KActiveLabel *explain;
+
+  fd = ::open(APMDEV, O_RDONLY);
+  if (fd == -1) {
+    switch (errno) {
+    case ENOENT:
+      explain = new KActiveLabel("There is no /dev/apm file on this system.  Pleae review the NetBSD documentation on how to create a device node for the apm device driver (man 4 apm)", parent);
+      break;
+    case EACCES:
+      explain = new KActiveLabel("Your system has the proper device node for apm support, however you can't access it. If you have apm in the kernel this should not happen", parent);
+      break;
+    case ENXIO:
+      explain = new KActiveLabel("Your kernel lacks support for Advanced Power Managment.", parent);
+      break;
+      break;
+    default:
+      explain = new KActiveLabel("There was some generic error while opening /dev/apm.", parent);
+      break;
+    }
+  } else {
+    close(fd);
+    explain = new KActiveLabel("APM has most likely been disabled.  Oops", parent);
+  }
+  
+  explain->setMinimumSize(explain->sizeHint());       
+  return(explain);
+}
+
+//
+//     explain to the user what they need to do to get suspend/resume to work from user mode
+//
+QLabel *laptop_portable::how_to_do_suspend_resume(QWidget *parent)
+{
+       QLabel* note = new QLabel(i18n(" "), parent);
+        note->setMinimumSize(note->sizeHint()); 
+       return(note);
+}
+
+//
+//     pcmcia support - this will be replaced by better - pcmcia support being worked on by
+//     others
+//
+QLabel *laptop_portable::pcmcia_info(int x, QWidget *parent)
+{
+       if (x == 0)
+               return(new QLabel(i18n("No PCMCIA controller detected"), parent));
+       return(new QLabel(i18n(""), parent));
+}
+
+//
+//     puts us into standby mode
+//     Use apm rather than ioctls in case they are running apmd
+//     (as they should be).
+//
+void laptop_portable::invoke_standby()
+{
+       ::system("/usr/sbin/apm -S");    
+}
+
+//
+//     puts us into suspend mode
+//     Use apm rather than ioctls in case they are running apmd
+//     (as they should be).
+//
+void laptop_portable::invoke_suspend()
+{
+
+       ::system("/usr/sbin/apm -z");    
+}
+
+//
+//     puts us into hibernate mode
+//     No hibernate mode for NetBSD.
+//
+void laptop_portable::invoke_hibernation()
+{
+       return;
+}
+
+
+//
+//     return current battery state
+//
+struct power_result laptop_portable::poll_battery_state()
+{
+       struct power_result p;
+               int ret;
+
+               int fd = ::open(APMDEV, O_RDONLY);
+
+               if (fd == -1)
+               goto bad;
+
+               struct apm_power_info info;
+               ret=ioctl(fd, APM_IOC_GETPOWER, &info);
+               ::close(fd);
+       
+               if (ret == -1)
+               goto bad;
+
+               p.powered = (info.ac_state == APM_AC_ON);
+               p.percentage = (info.battery_life==255 ? 100 : info.battery_life);
+               p.time = (info.minutes_left != 0xffff ? info.minutes_left : -1);
+               return(p);
+
+bad:
+               p.powered = 1; 
+       p.percentage = 100;
+       p.time = 0;
+       return(p);
+}
+
+//
+//
+//     returns true if any mouse or kdb activity has been detected
+//     
+int laptop_portable::poll_activity()
+{
+       return(1);
+}
 #else
 
-// INSERT HERE
+/*
+** This is utterly generic code.
+*/
+
+//
+//	something changed maybe we need to check out environment again
+//
+void
+laptop_portable::power_management_restart()
+{
+}
 
 //
 //	returns 1 if we support power management
@@ -907,9 +1387,9 @@ int laptop_portable::has_hibernation()
 //	explain to the user what they need to do if has_power_management() returned 0
 //	to get any software they lack
 //
-QLabel *laptop_portable::no_power_management_explanation(QWidget *parent)
+KActiveLabel *laptop_portable::no_power_management_explanation(QWidget *parent)
 {
-	QLabel* explain = new QLabel(i18n("Your computer or operating system is not supported by the current version of the\nKDE laptop control panels. If you want help porting these panels to work with it\nplease contact paul@taniwha.com."), parent);
+	KActiveLabel* explain = new KActiveLabel(i18n("Your computer or operating system is not supported by the current version of the\nKDE laptop control panels. If you want help porting these panels to work with it\nplease contact paul@taniwha.com."), parent);
       	explain->setMinimumSize(explain->sizeHint());       
 	return(explain);
 }
@@ -956,6 +1436,14 @@ void laptop_portable::invoke_hibernation()
 }
 
 
+//
+//	adds extra widgets to the battery panel
+//
+void
+laptop_portable::extra_config(QWidget *parent, KConfig *config, QVBoxLayout *layout)
+{
+}
+
 //
 //	return current battery state
 //
