@@ -62,7 +62,7 @@ PowerConfig::PowerConfig (QWidget * parent, const char *name)
     QVBoxLayout *top_layout = new QVBoxLayout(this, KDialog::marginHint(),
 					      KDialog::spacingHint());
 
-    QLabel* explain = laptop_portable::no_power_management_explanation(this);
+    KActiveLabel* explain = laptop_portable::no_power_management_explanation(this);
     top_layout->addWidget(explain);
 
     top_layout->addStretch(1);
@@ -86,7 +86,7 @@ PowerConfig::PowerConfig (QWidget * parent, const char *name)
 						KDialog::spacingHint());
       QHBoxLayout *hlay = new QHBoxLayout( top_layout );
 
-      nopowerBox = new QVButtonGroup(i18n("Not Powered:"), this);
+      nopowerBox = new QVButtonGroup(i18n("Not Powered"), this);
       nopowerBox->layout()->setSpacing( KDialog::spacingHint() );
       hlay->addWidget( nopowerBox );
 
@@ -109,7 +109,7 @@ PowerConfig::PowerConfig (QWidget * parent, const char *name)
       connect( noeditwait, SIGNAL(valueChanged(int)),
 	       this, SLOT(configChanged()));
 
-      powerBox = new QVButtonGroup(i18n("Powered:"), this);
+      powerBox = new QVButtonGroup(i18n("Powered"), this);
       powerBox->layout()->setSpacing( KDialog::spacingHint() );
       hlay->addWidget( powerBox );
 
@@ -134,7 +134,7 @@ PowerConfig::PowerConfig (QWidget * parent, const char *name)
 
       hlay->addStretch(1);
 
-      QLabel* explain = new QLabel(i18n("This panel configures the behavior of the automatic power-down feature - it works as a sort of extreme\nscreensaver. You can configure different timeouts\nand types of behavior depending on whether or not\nyour laptop is plugged in to the mains supply."), this);
+      QLabel* explain = new QLabel(i18n("This panel configures the behavior of the automatic power-down feature - it works as a sort of extreme\nscreen saver. You can configure different timeouts\nand types of behavior depending on whether or not\nyour laptop is plugged in to the mains supply."), this);
       top_layout->addWidget(explain, 0, Qt::AlignLeft);
 
       if (can_standby) {
@@ -151,6 +151,10 @@ PowerConfig::PowerConfig (QWidget * parent, const char *name)
   load();
 }
 
+PowerConfig::~PowerConfig()
+{
+  delete config;
+}
 
 void PowerConfig::save()
 {
